@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GlobalVar.cpp,v 1.19 2008/05/05 12:43:59 bowkenken Exp $
+* $Id: GlobalVar.cpp,v 1.24 2008/09/10 23:10:25 bowkenken Exp $
 ***************************************************************/
 
 #include "GlobalVar.h"
@@ -37,11 +37,17 @@ GuiMessage gGuiMessage;
 GuiStat gGuiStat;
 GuiNum gGuiNum;
 GuiInputString gGuiInpStr;
+GuiWords gGuiWords;
+GuiReplay gGuiReplay;
+GuiClassEdit gGuiClassEdit;
+GuiChrSheet gGuiChrSheet;
 SelMbrGraph *gSelMbrGraph;
 WinPos gWinPos[WIN_KIND_MAX_N];
 
 PcgDun gPcgDun;
 
+GameMusic gMusic;
+
 Key gKey;
 
 MouseMotion gMouseMotion;
