@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GlobalVar.h,v 1.23 2008/05/05 12:43:59 bowkenken Exp $
+* $Id: GlobalVar.h,v 1.28 2008/09/10 23:10:25 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GLOBAL_VAR_H
@@ -58,10 +58,15 @@ typedef long GtkButton;
 #include "GuiStat.h"
 #include "GuiNum.h"
 #include "GuiInputString.h"
+#include "GuiWords.h"
+#include "GuiReplay.h"
+#include "GuiClassEdit.h"
+#include "GuiChrSheet.h"
 #include "SelMbrGraph.h"
 #include "WinPos.h"
 #include "FileList.h"
 #include "PcgDun.h"
+#include "GameMusic.h"
 #include "Key.h"
 #include "MouseMotion.h"
 
@@ -99,6 +104,18 @@ extern GuiNum gGuiNum;
 // ʸϡɥ
 extern GuiInputString gGuiInpStr;
 
+// 쥦ɥ
+extern GuiWords gGuiWords;
+
+// ץ쥤ɥ
+extern GuiReplay gGuiReplay;
+
+// 饹ǥɥ
+extern GuiClassEdit gGuiClassEdit;
+
+// 饯ȡɥ
+extern GuiChrSheet gGuiChrSheet;
+
 // СΥեåѥ
 extern SelMbrGraph *gSelMbrGraph;
 
@@ -108,6 +125,9 @@ extern WinPos gWinPos[WIN_KIND_MAX_N];
 // 󥸥ƤΥ饯ǡ
 extern PcgDun gPcgDun;
 
+// BGM δ
+extern GameMusic gMusic;
+
 // ϴǡ
 extern Key gKey;
 
