@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GraphConf.h,v 1.3 2008/01/11 09:13:16 bowkenken Exp $
+* $Id: GraphConf.h,v 1.4 2008/04/25 04:09:51 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GRAPH_CONF_H
@@ -69,6 +69,8 @@ private:
 	WSCstring pc_patern;
 	WSCstring monster_patern;
 	WSCstring wall_patern;
+	WSCstring town_wall_patern;
+	WSCstring dungeon_wall_patern;
 	WSCstring door_patern;
 	WSCstring signboard_patern;
 	bool text_mode;
