@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GraphConfToken.h,v 1.3 2008/01/11 09:13:16 bowkenken Exp $
+* $Id: GraphConfToken.h,v 1.4 2008/04/25 04:09:51 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GRAPH_CONF_TOKEN_H
@@ -41,6 +41,8 @@ typedef enum {
 	GRAPH_CONF_TOKEN_PC_PATERN,
 	GRAPH_CONF_TOKEN_MONSTER_PATERN,
 	GRAPH_CONF_TOKEN_WALL_PATERN,
+	GRAPH_CONF_TOKEN_TOWN_WALL_PATERN,
+	GRAPH_CONF_TOKEN_DUNGEON_WALL_PATERN,
 	GRAPH_CONF_TOKEN_DOOR_PATERN,
 	GRAPH_CONF_TOKEN_SIGNBOARD_PATERN,
 	GRAPH_CONF_TOKEN_TEXT_MODE,
