@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiInputString.cpp,v 1.18 2008/05/02 12:00:35 bowkenken Exp $
+* $Id: GuiInputString.cpp,v 1.20 2008/08/18 08:25:38 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -55,7 +55,30 @@ void handle_input_string_ok_clicked(
 #endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
-// åʸϥɥν
+// ʸϥɥΥ󥹥ȥ饯
+////////////////////////////////////////////////////////////////
+
+GuiInputString::GuiInputString()
+{
+#ifdef D_GTK
+	mWin = NULL;
+#endif // D_GTK
+
+#ifdef D_MFC
+	mInpStrWin = NULL;
+#endif // D_MFC
+}
+
+////////////////////////////////////////////////////////////////
+// ʸϥɥΥǥȥ饯
+////////////////////////////////////////////////////////////////
+
+GuiInputString::~GuiInputString()
+{
+}
+
+////////////////////////////////////////////////////////////////
+// ʸϥɥν
 ////////////////////////////////////////////////////////////////
 
 void GuiInputString::init()
@@ -182,17 +205,6 @@ void GuiInputString::newWin()
 
 	mInpStrWin = new CInputLineDlg;
 #endif // D_MFC
-
-	// ʸϥɥκɸ
-
-	long ix, iy, iw, ih;
-	if( gWinPos[WIN_KIND_INPUT_STRING].get(
-			WIN_KIND_INPUT_STRING,
-			&ix, &iy, &iw, &ih, true ) ){
-		gWinPos[WIN_KIND_INPUT_STRING].set(
-				WIN_KIND_INPUT_STRING,
-				&ix, &iy, &iw, &ih, true );
-	}
 }
 
 ////////////////////////////////////////////////////////////////
@@ -235,7 +247,7 @@ void GuiInputString::draw( const char *ttl, const char *str, long len )
 	if( mWin == NULL )
 		return;
 
-	((WSCwindow *)mWin)->setVisible( true );
+	gWinPos[WIN_KIND_INPUT_STRING].draw( WIN_KIND_INPUT_STRING );
 #endif // D_WS
 
 #ifdef D_GTK
@@ -264,7 +276,7 @@ void GuiInputString::draw( const char *ttl, const char *str, long len )
 		gtk_entry_set_text( e, str );
 	}
 
-	gtk_widget_show( mWin );
+	gWinPos[WIN_KIND_INPUT_STRING].draw( WIN_KIND_INPUT_STRING );
 #endif // D_GTK
 
 #ifdef D_MFC
@@ -287,19 +299,9 @@ void GuiInputString::draw( const char *ttl, const char *str, long len )
 
 void GuiInputString::wipe()
 {
-#ifdef D_WS
-	if( mWin == NULL )
-		return;
-
-	((WSCwindow *)mWin)->setVisible( false );
-#endif // D_WS
-
-#ifdef D_GTK
-	if( mWin == NULL )
-		return;
-
-	gtk_widget_hide( mWin );
-#endif // D_GTK
+#if ! defined( D_MFC )
+	gWinPos[WIN_KIND_INPUT_STRING].wipe( WIN_KIND_INPUT_STRING );
+#endif
 }
 
 ////////////////////////////////////////////////////////////////
