@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiMenu.cpp,v 1.33 2008/05/02 04:33:03 bowkenken Exp $
+* $Id: GuiMenu.cpp,v 1.37 2008/09/20 22:36:14 bowkenken Exp $
 ***************************************************************/
 
 #include	"gmain.h"
@@ -154,6 +154,31 @@ void handle_menu_button_leave(
 
 #endif // D_GTK
 
+////////////////////////////////////////////////////////////////
+// ˥塼ɥΥ󥹥ȥ饯
+////////////////////////////////////////////////////////////////
+
+GuiMenu::GuiMenu()
+{
+	mMenuWin = NULL;
+	bFlagSetMouseDfltMenu = false;
+
+#ifdef D_GTK
+	vBox = NULL;
+
+	nClickedButton = 0;
+	bFlagEnter = FALSE;
+#endif // D_GTK
+}
+
+////////////////////////////////////////////////////////////////
+// ˥塼ɥΥǥȥ饯
+////////////////////////////////////////////////////////////////
+
+GuiMenu::~GuiMenu()
+{
+}
+
 ////////////////////////////////////////////////////////////////
 // ˥塼ν
 ////////////////////////////////////////////////////////////////
@@ -383,17 +408,6 @@ void GuiMenu::newWin()
 		aBtnMenu[n] = &(mMenuWin->m_aBtn[n]);
 	}
 #endif // D_MFC
-
-	// ˥塼ɥκɸ
-
-	long ix, iy, iw, ih;
-	if( gWinPos[WIN_KIND_MENU].get(
-			WIN_KIND_MENU,
-			&ix, &iy, &iw, &ih, true ) ){
-		gWinPos[WIN_KIND_MENU].set(
-				WIN_KIND_MENU,
-				&ix, &iy, &iw, &ih, true );
-	}
 }
 
 ////////////////////////////////////////////////////////////////
@@ -640,13 +654,17 @@ void GuiMenu::draw( draw_menu_t *data )
 		// ȥ롦ܥΥץѥƥ
 
 #ifdef D_MFC
+		aBtnMenu[i]->SetCheck( false );
+
 		flgGroupSwitch = false;
 		ULONG flgBtn = WS_VISIBLE;
 
 		if( strcmp( data->ls[i]->kind, "<CheckItem>" ) == 0 )
-			flgBtn |= BS_AUTOCHECKBOX;
-		if( strcmp( data->ls[i]->kind, "<RadioItem>" ) == 0 )
-			flgBtn |= BS_AUTORADIOBUTTON;
+			flgBtn |= BS_CHECKBOX;
+		else if( strcmp( data->ls[i]->kind, "<RadioItem>" ) == 0 )
+			flgBtn |= BS_RADIOBUTTON;
+		else
+			flgBtn |= BS_PUSHBUTTON;
 
 		if( strcmp( data->ls[i]->kind, "<RadioItem>" ) == 0 ){
 			if( !flgGroup )
@@ -661,6 +679,13 @@ void GuiMenu::draw( draw_menu_t *data )
 			flgBtn |= WS_GROUP;
 
 		aBtnMenu[i]->SetButtonStyle( flgBtn, TRUE );
+
+		if( chk_flg( data->ls[i]->flg, FLG_MENU_CHK_ON ) )
+			aBtnMenu[i]->SetCheck( true );
+		else if( chk_flg( data->ls[i]->flg, FLG_MENU_CHK_OFF ) )
+			aBtnMenu[i]->SetCheck( false );
+		else
+			aBtnMenu[i]->SetCheck( false );
 #endif // D_MFC
 
 		// ˥塼ܥΥץѥƥ
@@ -764,6 +789,12 @@ void GuiMenu::draw( draw_menu_t *data )
 	}
 #endif // D_MFC
 
+	// ˥塼ɥɽ
+
+	gWinPos[WIN_KIND_MENU].get( WIN_KIND_MENU,
+			NULL, NULL, NULL, NULL );
+	gWinPos[WIN_KIND_MENU].draw( WIN_KIND_MENU );
+
 	// ɥΥܥ˹碌
 
 #ifdef D_MFC
@@ -789,21 +820,6 @@ void GuiMenu::draw( draw_menu_t *data )
 				TRUE );
 	}
 #endif // D_MFC
-
-	// ˥塼ɥɽ
-
-#ifdef D_WS
-	MenuWin->setVisible( true );
-#endif // D_WS
-
-#ifdef D_GTK
-	showWin( mMenuWin, &nWinX, &nWinY, NULL, NULL );
-#endif // D_GTK
-
-#ifdef D_MFC
-	mMenuWin->ShowWindow( SW_SHOW );
-	mMenuWin->UpdateWindow();
-#endif // D_MFC
 }
 
 ////////////////////////////////////////////////////////////////
@@ -812,24 +828,7 @@ void GuiMenu::draw( draw_menu_t *data )
 
 void GuiMenu::wipe()
 {
-#ifdef D_WS
-	if( mMenuWin == NULL )
-		return;
-
-	MenuWin->setVisible( false );
-#endif // D_WS
-
-#ifdef D_GTK
-	wipeWin( mMenuWin, &nWinX, &nWinY, &nWinW, &nWinH );
-#endif // D_GTK
-
-#ifdef D_MFC
-	if( mMenuWin == NULL )
-		return;
-
-	mMenuWin->ShowWindow( SW_HIDE );
-	mMenuWin->UpdateWindow();
-#endif // D_MFC
+	gWinPos[WIN_KIND_MENU].wipe( WIN_KIND_MENU );
 }
 
 ////////////////////////////////////////////////////////////////
