@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiMenu.h,v 1.18 2008/01/11 09:13:16 bowkenken Exp $
+* $Id: GuiMenu.h,v 1.19 2008/08/17 11:51:30 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GUI_MENU_H
@@ -77,7 +77,6 @@ private:
 #endif // D_WS
 
 #ifdef D_GTK
-	gint nWinX, nWinY, nWinW, nWinH;
 	GtkWidget *vBox;
 	GtkWidget *aBtnMenu[MENU_MAX_N_PER_PAGE];
 	GtkWidget *btnMenuPrevPage;
@@ -111,27 +110,8 @@ public:
 // ѥ֥åСؿ
 public:
 
-	GuiMenu()
-	{
-		mMenuWin = NULL;
-		bFlagSetMouseDfltMenu = false;
-
-#ifdef D_GTK
-		nWinX = -1;
-		nWinY = -1;
-		nWinW = -1;
-		nWinH = -1;
-
-		vBox = NULL;
-
-		nClickedButton = 0;
-		bFlagEnter = FALSE;
-#endif // D_GTK
-	}
-	~GuiMenu()
-	{
-	}
-
+	GuiMenu();
+	~GuiMenu();
 	void init();
 	void destroy();
 
