@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiMessage.cpp,v 1.44 2008/05/02 12:00:35 bowkenken Exp $
+* $Id: GuiMessage.cpp,v 1.47 2008/09/20 22:36:14 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -85,15 +85,13 @@ void handle_message_scroll_changed(
 
 GuiMessage::GuiMessage()
 {
+	mMessageWin = NULL;
+
 	flagMore = FALSE;
+	mLsMessageDrawBeginN = 0;
+	mLsMessageDrawN = 0;
 
 #ifdef D_GTK
-	nPreX = -1;
-	nPreY = -1;
-	nPreW = -1;
-	nPreH = -1;
-
-	mMessageWin = NULL;
 	mMessageDrawingArea = NULL;
 	mMessageHScrollBarAdjustment = NULL;
 	mMessageVScrollBarAdjustment = NULL;
@@ -106,9 +104,6 @@ GuiMessage::GuiMessage()
 #ifdef D_MFC
 	pDc = NULL;
 #endif // D_MFC
-
-	mLsMessageDrawBeginN = 0;
-	mLsMessageDrawN = 0;
 }
 
 ////////////////////////////////////////////////////////////////
@@ -132,18 +127,12 @@ GuiMessage::~GuiMessage()
 void GuiMessage::init()
 {
 	newWin();
+	redraw();
 
 #ifdef D_GTK
-	gtk_widget_show( mMessageWin );
-
 	gtk_drawing_area_size( GTK_DRAWING_AREA( mMessageDrawingArea ),
 			MESSAGE_WIN_MIN_WIDTH, MESSAGE_WIN_MIN_HEIGHT );
 #endif // D_GTK
-
-#ifdef D_MFC
-	theApp.m_MesWnd.ShowWindow( SW_SHOW );
-	theApp.m_MesWnd.UpdateWindow();
-#endif // D_MFC
 }
 
 ////////////////////////////////////////////////////////////////
@@ -317,16 +306,9 @@ void GuiMessage::newWin()
 	mMessageWin = &(theApp.m_MesWnd);
 #endif // D_MFC
 
-	// åɥκɸ
-
-	long ix, iy, iw, ih;
-	if( gWinPos[WIN_KIND_MESSAGE].get(
-			WIN_KIND_MESSAGE,
-			&ix, &iy, &iw, &ih, true ) ){
-		gWinPos[WIN_KIND_MESSAGE].set(
-				WIN_KIND_MESSAGE,
-				&ix, &iy, &iw, &ih, true );
-	}
+	gWinPos[WIN_KIND_MESSAGE].get( WIN_KIND_MESSAGE,
+			NULL, NULL, NULL, NULL );
+	gWinPos[WIN_KIND_MESSAGE].draw( WIN_KIND_MESSAGE );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -500,11 +482,6 @@ void GuiMessage::draw( bool flagRedraw )
 	long w = mMessageDrawingArea->allocation.width;
 	if( (y + 1) > 0 )
 		gdk_draw_rectangle( gd, mBgGc, TRUE, 0, 0, w, y + 1 );
-
-	// åɥɽ
-
-	gtk_widget_show( mMessageDrawingArea );
-	showWin( mMessageWin, &nPreX, &nPreY, &nPreW, &nPreH );
 #endif // D_GTK
 
 #ifdef D_MFC
@@ -651,12 +628,11 @@ void GuiMessage::draw( bool flagRedraw )
 	g_Dir3d.EndDraw();
 	delete pen;
 	delete brush;
-
-	// åɥɽ
-
-	theApp.m_MesWnd.ShowWindow( SW_SHOW );
-	theApp.m_MesWnd.UpdateWindow();
 #endif // D_MFC
+
+	gWinPos[WIN_KIND_MESSAGE].get( WIN_KIND_MESSAGE,
+			NULL, NULL, NULL, NULL );
+	gWinPos[WIN_KIND_MESSAGE].draw( WIN_KIND_MESSAGE );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -665,21 +641,7 @@ void GuiMessage::draw( bool flagRedraw )
 
 void GuiMessage::wipe()
 {
-#ifdef D_WS
-	if( MessageWin == NULL )
-		return;
-
-	MessageWin->setVisible( false );
-#endif // D_WS
-
-#ifdef D_GTK
-	wipeWin( mMessageWin, &nPreX, &nPreY, &nPreW, &nPreH );
-#endif // D_GTK
-
-#ifdef D_MFC
-	theApp.m_MesWnd.ShowWindow( SW_HIDE );
-	theApp.m_MesWnd.UpdateWindow();
-#endif // D_MFC
+	gWinPos[WIN_KIND_MESSAGE].wipe( WIN_KIND_MESSAGE );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -750,6 +712,7 @@ void GuiMessage::drawScrollBar()
 
 ////////////////////////////////////////////////////////////////
 // åɥʿ
+// long n : 
 ////////////////////////////////////////////////////////////////
 
 void GuiMessage::hScroll( long n )
@@ -771,6 +734,7 @@ void GuiMessage::hScroll( long n )
 
 ////////////////////////////////////////////////////////////////
 // åɥľ
+// long n : 
 ////////////////////////////////////////////////////////////////
 
 void GuiMessage::vScroll( long n )
@@ -792,11 +756,13 @@ void GuiMessage::vScroll( long n )
 
 ////////////////////////////////////////////////////////////////
 // åɥĤΥϥɥ
+// GtkWidget *widget : ơɥ
+// gpointer data : ϿϤ줿
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
 gint handle_message_delete(
-	GtkWidget *widget, gpointer user_data
+	GtkWidget *widget, gpointer data
 )
 {
 	gGuiMessage.wipe();
@@ -807,11 +773,13 @@ gint handle_message_delete(
 
 ////////////////////////////////////////////////////////////////
 // åɥνλΥϥɥ
+// GtkWidget *widget : ơɥ
+// gpointer data : ϿϤ줿
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
 void handle_message_destroy(
-	GtkWidget *widget, gpointer user_data
+	GtkWidget *widget, gpointer data
 )
 {
 	gGuiMessage.destroy();
