@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiNum.cpp,v 1.18 2008/05/02 12:00:35 bowkenken Exp $
+* $Id: GuiNum.cpp,v 1.21 2008/08/18 08:25:38 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -61,6 +61,28 @@ void handle_num_down_clicked( GtkButton *button, gpointer user_data );
 void handle_num_ok_clicked( GtkButton *button, gpointer user_data );
 #endif // D_GTK
 
+////////////////////////////////////////////////////////////////
+// ϥɥΥ󥹥ȥ饯
+////////////////////////////////////////////////////////////////
+
+GuiNum::GuiNum()
+{
+	mNumWin = NULL;
+	mPN = NULL;
+	mOrg = 0;
+	mMin = 0;
+	mMax = 1;
+	mFigure = 1;
+}
+
+////////////////////////////////////////////////////////////////
+// ϥɥΥǥȥ饯
+////////////////////////////////////////////////////////////////
+
+GuiNum::~GuiNum()
+{
+}
+
 ////////////////////////////////////////////////////////////////
 // ϥɥν
 ////////////////////////////////////////////////////////////////
@@ -149,7 +171,7 @@ void GuiNum::newWin()
 		return;
 	}
 	gtk_box_pack_start( GTK_BOX( vBoxWin ), mHscale,
-			TRUE, TRUE, TRUE );
+			TRUE, TRUE, 0 );
 	gtk_widget_show( mHscale );
 
 	// ԥ󡦥ܥĴ
@@ -182,7 +204,7 @@ void GuiNum::newWin()
 		return;
 	}
 	gtk_box_pack_start( GTK_BOX( vBoxWin ), mNumSpin,
-			TRUE, TRUE, TRUE );
+			TRUE, TRUE, 0 );
 	gtk_widget_show( mNumSpin );
 
 	// ܥκ
@@ -297,7 +319,7 @@ void GuiNum::newWin()
 	}
 
 	gtk_box_pack_start( GTK_BOX( vBoxWin ), hBox,
-			TRUE, TRUE, TRUE );
+			TRUE, TRUE, 0 );
 
 	// Ǿܥκ
 
@@ -363,44 +385,29 @@ void GuiNum::newWin()
 	}
 
 	gtk_box_pack_start( GTK_BOX( vBoxOk ), mButtonMin,
-			TRUE, TRUE, TRUE );
+			TRUE, TRUE, 0 );
 	gtk_box_pack_start( GTK_BOX( vBoxOk ), mButtonClear,
-			TRUE, TRUE, TRUE );
+			TRUE, TRUE, 0 );
 	gtk_box_pack_start( GTK_BOX( vBoxOk ), mButtonMax,
-			TRUE, TRUE, TRUE );
+			TRUE, TRUE, 0 );
 	gtk_box_pack_start( GTK_BOX( vBoxOk ), mButtonOk,
-			TRUE, TRUE, TRUE );
+			TRUE, TRUE, 0 );
 
 	gtk_widget_show( vBoxOk );
 
 	// ܥåˤΤ
 
 	gtk_box_pack_start( GTK_BOX( hBoxWin ), vBoxWin,
-			TRUE, TRUE, TRUE );
+			TRUE, TRUE, 0 );
 	gtk_box_pack_start( GTK_BOX( hBoxWin ), vBoxOk,
-			TRUE, TRUE, TRUE );
+			TRUE, TRUE, 0 );
 
 	gtk_container_add( GTK_CONTAINER( mNumWin ), hBoxWin );
-
-	//
-
-	gtk_widget_show( mNumWin );
 #endif	// D_GTK
 
 #ifdef D_MFC
 	mNumWin = new CInputNumDlg;
 #endif // D_MFC
-
-	// ϥɥκɸ
-
-	long ix, iy, iw, ih;
-	if( gWinPos[WIN_KIND_INPUT_NUM].get(
-			WIN_KIND_INPUT_NUM,
-			&ix, &iy, &iw, &ih, true ) ){
-		gWinPos[WIN_KIND_INPUT_NUM].set(
-				WIN_KIND_INPUT_NUM,
-				&ix, &iy, &iw, &ih, true );
-	}
 }
 
 ////////////////////////////////////////////////////////////////
@@ -497,7 +504,8 @@ void GuiNum::redraw()
 	}
 
 	cvUpDownFromN();
-	gtk_widget_show( mNumWin );
+
+	gWinPos[WIN_KIND_INPUT_NUM].draw( WIN_KIND_INPUT_NUM );
 #endif // D_GTK
 
 #ifdef D_MFC
@@ -508,8 +516,6 @@ void GuiNum::redraw()
 	dlg->m_Cur = mPN;
 
 	dlg->DoModal();
-
-	destroy();
 #endif // D_MFC
 }
 
@@ -523,7 +529,7 @@ void GuiNum::wipe()
 	if( mNumWin == NULL )
 		return;
 
-	gtk_widget_hide( mNumWin );
+	gWinPos[WIN_KIND_INPUT_NUM].wipe( WIN_KIND_INPUT_NUM );
 #endif // D_GTK
 
 #ifdef D_MFC
@@ -710,8 +716,6 @@ void GuiNum::cvUpDownFromN()
 		return;
 
 #ifdef D_GTK
-	gtk_widget_show( mNumWin );
-
 	GtkLabel *lbl;
 	gchar str[1 + 1]  = "";
 
