@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiNum.h,v 1.14 2008/05/02 12:00:35 bowkenken Exp $
+* $Id: GuiNum.h,v 1.15 2008/08/17 11:51:30 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GUI_NUM_H
@@ -98,18 +98,8 @@ public:
 	//////// ѥ֥åСؿ ////////
 public:
 
-	GuiNum()
-	{
-		mPN = NULL;
-		mOrg = 0;
-		mMin = 0;
-		mMax = 1;
-		mFigure = 1;
-	}
-	~GuiNum()
-	{
-	}
-
+	GuiNum();
+	~GuiNum();
 	void init();
 	void destroy();
 
