@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiStat.cpp,v 1.14 2008/05/02 04:33:03 bowkenken Exp $
+* $Id: GuiStat.cpp,v 1.20 2008/09/21 22:58:48 bowkenken Exp $
 ***************************************************************/
 
 #define GUI_STAT_CPP
@@ -47,6 +47,9 @@
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
+void handle_stat_win_delete(
+	GtkWidget *widget, gpointer data
+);
 void handle_stat_win_destroy(
 	GtkWidget *widget, gpointer data
 );
@@ -65,6 +68,35 @@ void handle_stat_stat_clicked(
 );
 #endif // D_GTK
 
+////////////////////////////////////////////////////////////////
+// ơΥ󥹥ȥ饯
+////////////////////////////////////////////////////////////////
+
+GuiStat::GuiStat()
+{
+	mStatWin = NULL;
+
+#ifdef D_GTK
+	vBox = NULL;
+	for( long i = 0; i < MBR_MAX_N; i++ ){
+		mFgGcHp[i] = NULL;
+		mBgGcHp[i] = NULL;
+		mFgGcMp[i] = NULL;
+		mBgGcMp[i] = NULL;
+	}
+	mFgGcHpMp = NULL;
+	mBgGcHpMp = NULL;
+#endif // D_GTK
+}
+
+////////////////////////////////////////////////////////////////
+// ơΥǥȥ饯
+////////////////////////////////////////////////////////////////
+
+GuiStat::~GuiStat()
+{
+}
+
 ////////////////////////////////////////////////////////////////
 // ơν
 ////////////////////////////////////////////////////////////////
@@ -97,6 +129,10 @@ void GuiStat::newWin()
 
 	// ơɥؤΥ٥ȡϥɥ
 
+	gtk_signal_connect( GTK_OBJECT( mStatWin ),
+			"delete_event",
+			GTK_SIGNAL_FUNC( handle_stat_win_delete ),
+			this );
 	gtk_signal_connect( GTK_OBJECT( mStatWin ),
 			"destroy",
 			GTK_SIGNAL_FUNC( handle_stat_win_destroy ),
@@ -121,26 +157,15 @@ void GuiStat::newWin()
 	party_t *pty = get_party();
 	for( long i = 0; i < MBR_MAX_N; i++ )
 		newWinMbr( pty->mbr[i], vBox );
-
-	//
-
-	gtk_widget_show( mStatWin );
 #endif // D_GTK
 
 #ifdef D_MFC
 	mStatWin = &(theApp.m_StatWnd);
 #endif // D_MFC
 
-	// ơɥκɸ
-
-	long ix, iy, iw, ih;
-	if( gWinPos[WIN_KIND_STAT].get(
-			WIN_KIND_STAT,
-			&ix, &iy, &iw, &ih, true ) ){
-		gWinPos[WIN_KIND_STAT].set(
-				WIN_KIND_STAT,
-				&ix, &iy, &iw, &ih, true );
-	}
+	gWinPos[WIN_KIND_STAT].get( WIN_KIND_STAT,
+			NULL, NULL, NULL, NULL );
+	gWinPos[WIN_KIND_STAT].draw( WIN_KIND_STAT );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -161,6 +186,8 @@ void GuiStat::newWinMbr( mbr_t *mbr, GtkWidget *vBox )
 
 	// ġ롦С
 
+#if 1
+//@@@
 	handleBox[n] = gtk_handle_box_new();
 	gtk_box_pack_start( GTK_BOX( vBox ), handleBox[n], FALSE, FALSE, 0 );
 	gtk_widget_show( handleBox[n] );
@@ -177,6 +204,20 @@ void GuiStat::newWinMbr( mbr_t *mbr, GtkWidget *vBox )
 	vBox2[n] = gtk_vbox_new( FALSE, 0 );
 	gtk_container_add( GTK_CONTAINER( toolBar[n] ), vBox2[n] );
 	gtk_widget_show( vBox2[n] );
+#elif 0
+//@@@
+	handleBox[n] = gtk_handle_box_new();
+	gtk_box_pack_start( GTK_BOX( vBox ), handleBox[n], FALSE, FALSE, 0 );
+	gtk_widget_show( handleBox[n] );
+
+	vBox2[n] = gtk_vbox_new( FALSE, 0 );
+	gtk_container_add( GTK_CONTAINER( handleBox[n] ), vBox2[n] );
+	gtk_widget_show( vBox2[n] );
+#else
+	vBox2[n] = gtk_vbox_new( FALSE, 0 );
+	gtk_box_pack_start( GTK_BOX( vBox ), vBox2[n], FALSE, FALSE, 0 );
+	gtk_widget_show( vBox2[n] );
+#endif
 
 	// ơܥκ
 
@@ -322,30 +363,33 @@ void GuiStat::destroy()
 
 ////////////////////////////////////////////////////////////////
 // ơɥɽ
-// long mbrN : Сֹ
+// bool flagAdj : 
+// bool flagExpose : 
 ////////////////////////////////////////////////////////////////
 
-void GuiStat::redraw( bool flagAdj )
+void GuiStat::redraw( bool flagAdj, bool flagExpose )
 {
 	for( long i = 0; i < MBR_MAX_N; i++ )
-		draw( i );
+		draw( i, flagExpose );
+
+	gWinPos[WIN_KIND_STAT].get( WIN_KIND_STAT,
+			NULL, NULL, NULL, NULL );
+	if( !flagExpose )
+		gWinPos[WIN_KIND_STAT].draw( WIN_KIND_STAT );
 
 #ifdef D_GTK
 	g_object_set( GTK_WINDOW( mStatWin ),
 			"allow-shrink", FALSE,
 			"allow-grow", FALSE,
 			NULL );
-
-	gtk_widget_show( mStatWin );
 	gtk_widget_show( vBox );
 #endif // D_GTK
 
 #ifdef D_MFC
 	if( mStatWin != NULL ){
-		mStatWin->ShowWindow( SW_SHOW );
-		mStatWin->UpdateWindow();
-		if( flagAdj )
+		if( flagAdj ){
 			mStatWin->AdjustWnd();
+		}
 	}
 #endif // D_MFC
 }
@@ -355,7 +399,7 @@ void GuiStat::redraw( bool flagAdj )
 // long mbrN : Сֹ
 ////////////////////////////////////////////////////////////////
 
-void GuiStat::draw( long n )
+void GuiStat::draw( long n, bool flagExpose )
 {
 	newWin();
 
@@ -436,6 +480,11 @@ void GuiStat::draw( long n )
 	drawHpMp( n, true );
 	drawHpMp( n, false );
 #endif // D_MFC
+
+	gWinPos[WIN_KIND_STAT].get( WIN_KIND_STAT,
+			NULL, NULL, NULL, NULL );
+	if( !flagExpose )
+		gWinPos[WIN_KIND_STAT].draw( WIN_KIND_STAT );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -858,6 +907,21 @@ WSCstring GuiStat::getStatStr( mbr_t *mbr )
 	return str;
 }
 
+////////////////////////////////////////////////////////////////
+// ơɥĤΥϥɥ
+// GtkWidget *widget : ơɥ
+// gpointer data : ϿϤ줿
+////////////////////////////////////////////////////////////////
+
+#ifdef D_GTK
+void handle_stat_win_delete(
+	GtkWidget *widget, gpointer data
+)
+{
+	gWinPos[WIN_KIND_STAT].wipe( WIN_KIND_STAT );
+}
+#endif // D_GTK
+
 ////////////////////////////////////////////////////////////////
 // ơɥκΥ٥ȡϥɥ
 // GtkWidget *widget : ơɥ
@@ -888,7 +952,7 @@ gint handle_stat_win_expose(
 	GtkWidget *widget, GdkEventExpose *event
 )
 {
-	gGuiStat.redraw();
+	gGuiStat.redraw( true );
 
 	return TRUE;
 }
@@ -906,8 +970,6 @@ gint handle_stat_win_configure(
 	GtkWidget *widget, GdkEventConfigure *event
 )
 {
-	gGuiStat.redraw();
-
 	return TRUE;
 }
 #endif // D_GTK
@@ -974,7 +1036,7 @@ void handle_stat_stat_clicked(
 	sCmd += sCmdMbr;
 
 	// 饯Ȥɽ
-//	sCmd += ":/misc/char data\n";
+	// sCmd += ":/misc/info/char data\n";
 	sCmd += "C";
 
 	// ޥɤ
