@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiStat.h,v 1.9 2008/05/02 04:33:03 bowkenken Exp $
+* $Id: GuiStat.h,v 1.11 2008/08/19 04:18:01 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GUI_STAT_H
@@ -94,31 +94,14 @@ public:
 // ѥ֥åСؿ
 public:
 
-	GuiStat()
-	{
-		mStatWin = NULL;
-
-#ifdef D_GTK
-		vBox = NULL;
-		for( long i = 0; i < MBR_MAX_N; i++ ){
-			mFgGcHp[i] = NULL;
-			mBgGcHp[i] = NULL;
-			mFgGcMp[i] = NULL;
-			mBgGcMp[i] = NULL;
-		}
-		mFgGcHpMp = NULL;
-		mBgGcHpMp = NULL;
-#endif // D_GTK
-	}
-	~GuiStat()
-	{
-	}
+	GuiStat();
+	~GuiStat();
 
 	void init();
 	void destroy();
 
-	void redraw( bool flagAdj = true );
-	void draw( long n );
+	void redraw( bool flagAdj = true, bool flagExpose = false );
+	void draw( long n, bool flagExpose = false );
 	WSCstring getStatStr( mbr_t *mbr );
 
 // ץ饤١ȡСؿ
