@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: MouseMotion.cpp,v 1.6 2008/04/18 23:03:54 bowkenken Exp $
+* $Id: MouseMotion.cpp,v 1.7 2008/09/21 02:37:46 bowkenken Exp $
 ***************************************************************/
 
 #include <stdlib.h>
@@ -340,7 +340,22 @@ bool MouseMotion::checkPressAndClick(
 
 bool MouseMotion::move( long x, long y )
 {
-	releaseAll( x, y );
+	bool flgRelease = false;
+	for( long i = nMouseButtonMinN; i < nMouseButtonMaxN; i++ ){
+		if( nBgnX[i] <= -1 )
+			continue;
+		if( nBgnY[i] <= -1 )
+			continue;
+		if( (labs( x - nBgnX[i] ) < nClickXR)
+				&& (labs( y - nBgnY[i] ) < nClickYR) ){
+			continue;
+		}
+
+		flgRelease = true;
+		break;
+	}
+	if( flgRelease )
+		releaseAll( x, y );
 
 	bool flgPoint = true;
 	for( long i = nMouseButtonMinN; i < nMouseButtonMaxN; i++ ){
