@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: Pcg.h,v 1.14 2008/05/08 10:13:42 bowkenken Exp $
+* $Id: Pcg.h,v 1.15 2008/05/13 06:21:21 bowkenken Exp $
 ***************************************************************/
 
 #ifndef PCG_H
@@ -58,6 +58,8 @@ private:
 	// ǽԤκԤ֤Υǥեȡʥߥá
 	static const long nWaitReadyMSecDflt = 100;
 
+	// եåեΥѥ̾
+	WSCstring sPath;
 	// եåѥ
 	WSDimage *pImage;
 
@@ -95,9 +97,13 @@ public:
 	}
 
 	void init( WSCstring path );
+	void load( WSCstring path );
 	void ena();
 	void dis();
 
+	WSCstring getPath();
+	WSCstring getName();
+
 	long getWidth();
 	long getHeight();
 
@@ -119,7 +125,6 @@ public:
 			long offsetX, long offsetY );
 
 private:
-	void load( WSCstring path );
 };
 
 #endif /* PCG_H */
