@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: PcgDun.h,v 1.46 2008/05/10 10:04:38 bowkenken Exp $
+* $Id: PcgDun.h,v 1.56 2008/09/08 01:21:04 bowkenken Exp $
 ***************************************************************/
 
 #ifndef PCG_DUN_H
@@ -43,6 +43,9 @@
 #include "mnstr.h"
 
 #include "GraphConf.h"
+#include "DemoTitle.h"
+#include "DemoGameOver.h"
+#include "DemoEnding.h"
 #include "Pcg.h"
 
 #ifdef D_WS
@@ -60,15 +63,20 @@
 
 ////////////////////////////////////////////////////////////////
 
+// ǥեȤΥǥ쥯ȥ
+#define STR_DEFAULT_GRAPH_DIR_NAME	"xlnl-" VERSION "/"
+// ̥ǥ쥯ȥ
+#define STR_FIX_GRAPH_DIR_NAME	".xlnl/"
+
 // ѥΥե̾γĥ
-#if	defined( D_GTK )
-# define	STR_GRAPH_FILE_EXT	\
-		"png xpm jpg jpeg tif pnm bmp gif " \
-		"PNG XPM JPG JPEG TIF PNM BMP GIF"
-#elif	defined( D_WS )
+#if	defined( D_WS )
 # define	STR_GRAPH_FILE_EXT	\
 		"png jpg jpeg bmp " \
 		"PNG JPG JPEG BMP"
+#elif	defined( D_GTK )
+# define	STR_GRAPH_FILE_EXT	\
+		"png xpm jpg jpeg tif pnm bmp gif " \
+		"PNG XPM JPG JPEG TIF PNM BMP GIF"
 #elif	defined( D_MFC )
 # define	STR_GRAPH_FILE_EXT	\
 		"png jpg jpeg bmp " \
@@ -79,12 +87,6 @@
 		"PNG JPG JPEG BMP"
 #endif
 
-#if 0
-//@@@
-// ѥΥХꥨμ
-typedef char PcgMap;
-#endif
-
 // ѥΥơ֥
 struct PcgTab {
 	// 󥹥ξμ
@@ -114,6 +116,9 @@ typedef enum {
 class PcgDun {
 public:
 	GraphConf *pGraphConf;
+	DemoTitle *pDemoTitle;
+	DemoGameOver *pDemoGameOver;
+	DemoEnding *pDemoEnding;
 
 	// ѥγΨ
 	rate_t nTileSizeRate;
@@ -128,9 +133,6 @@ private:
 	// ѥδॵ
 	long nTileSizeX, nTileSizeY;
 
-	// ȥβ
-	Pcg pcgTitle;
-
 	// ΥѥΥꥹ
 	Pcg pcgNullTown;
 	Pcg pcgNullDun;
@@ -141,6 +143,9 @@ private:
 	Pcg pcgWallTown;
 	Pcg pcgWallDun;
 	Pcg pcgStatue;
+	// ΥѥΥꥹ
+	Pcg pcgStreetlampOn;
+	Pcg pcgStreetlampOff;
 	// ĤΥѥΥꥹ
 	Pcg pcgSignboard;
 	// ʤΥѥΥꥹ
@@ -173,11 +178,6 @@ private:
 	// 󥹥ΥѥΥꥹ
 	Pcg *aPcgMnstr[MNSTR_KIND_MAX_N];
 
-	// Ф줿ȥΥեֹ
-	long nTitleRandmSelN;
-	// ȥΥե
-	long nTitleN;
-
 	// ѥΥХꥨμΥޥå
 	rate_t rateMap[MAP_MAX_Y][MAP_MAX_X];
 
@@ -248,22 +248,6 @@ private:
 	CClientDC *pDc;
 #endif // D_MFC
 
-	//// ȥ ////
-
-#ifdef D_GTK
-	// եȤΥ
-	GtkStyle *pTitleStyle;
-#endif // D_GTK
-
-#ifdef D_MFC
-	// եȤΥ
-	void *pTitleStyle;
-	LOGFONT mTitleFontDesc;
-	CFont *pTitleFont;
-
-	CDir3dText mD3Title;
-#endif // D_MFC
-
 	// ˥ޥåפ褹뤫?
 	bool bFlgEnaDrawTurn;
 	// ̹׵ե饰
@@ -274,8 +258,12 @@ public:
 	~PcgDun();
 
 	void initTitle();
+	void initGameOver();
+	void initEnding();
 	void init( GraphConf *cnf );
 	void reset();
+	void reloadAllMbr();
+	bool reloadMbr( long nLsMbrN, WSCstring path );
 
 	long getTileSizeX( bool flgText = false );
 	long getTileSizeY( bool flgText = false );
@@ -308,10 +296,18 @@ public:
 	);
 	void drawTurn( bool flgForce = false );
 	void flush( long mapX, long mapY, long mapW, long mapH );
+	bool drawString( long scrn_x, long scrn_y, const char *s, ... );
 
 	void setFlgUpdateRequest( bool flg );
 
 	bool drawTitle();
+	bool drawGameOver();
+	bool drawEnding();
+
+	void drawFade(
+		long mapX, long mapY, long mapW, long mapH,
+		long r, long g, long b, long a
+	);
 
 	Pcg *getChrPcg( chr_t *chr );
 	long getChrDrawLeft( chr_t *chr, Pcg *pPcg, bool flagPre );
@@ -335,12 +331,16 @@ public:
 private:
 /*
 	void initTitle();
+	void initGameOver();
+	void initEnding();
 	void init( GraphConf *cnf );
 */
 	void initPcgLsRandm( GraphConf *cnf, Pcg *ls, PcgTab tab[] );
 	void initGraphConf( GraphConf *cnf );
 /*
 	void reset();
+	void reloadAllMbr();
+	bool reloadMbr( long nLsMbrN, WSCstring path );
 */
 	void resetSignboardFont();
 	bool setSignboardFont( long pnt, WSCstring *pFontName );
@@ -390,6 +390,9 @@ private:
 */
 	void initText();
 	bool drawText( long mapX, long mapY, long mapW, long mapH );
+/*
+	bool drawString( long scrn_x, long scrn_y, const char *s, ... );
+*/
 #ifdef D_GTK
 	bool user_select_font( GdkFont **font );
 #endif // D_GTK
@@ -407,16 +410,9 @@ private:
 	bool getUpdateFlg( long mapX, long mapY );
 /*
 	bool drawTitle();
+	bool drawGameOver();
+	bool drawEnding();
 */
-	void drawTitle0( long frame );
-	void drawTitle1( long frame );
-	void drawTitleCharStd( long x, long y, char c );
-#ifdef D_GTK
-	void drawTitleChar( GdkColor color, long x, long y, char c );
-#endif // D_GTK
-#ifdef D_MFC
-	void drawTitleChar( D3DCOLOR color, long x, long y, char c );
-#endif // D_MFC
 	bool drawTile( long mapX, long mapY, bool flgFlush );
 	bool drawObj( long mapX, long mapY );
 	bool drawItemAll( long mapX, long mapY );
@@ -435,6 +431,7 @@ private:
 		bool flagHalfX, bool flagHalfY
 	);
 	bool drawStatue( long mapX, long mapY );
+	bool drawStreetlamp( long mapX, long mapY );
 	bool drawSignboard( long mapX, long mapY );
 	bool drawStairsUp( long mapX, long mapY );
 	bool drawStairsDown( long mapX, long mapY );
@@ -461,6 +458,13 @@ private:
 		bool flagOneTile
 	);
 	void drawNight( long mapX, long mapY, long mapW, long mapH );
+	void drawGameOverFade( long mapX, long mapY, long mapW, long mapH );
+/*
+	void drawFade(
+		long mapX, long mapY, long mapW, long mapH,
+		long r, long g, long b, long a
+	);
+*/
 	bool getGlowColor( long *r, long *g, long *b, long *a );
 /*
 	Pcg *getChrPcg( chr_t *chr );
@@ -477,6 +481,7 @@ private:
 */
 	bool chkDrawWall( long mapX, long mapY );
 	bool chkDrawStatue( long mapX, long mapY );
+	bool chkDrawStreetlamp( long mapX, long mapY );
 	bool chkDrawSignboard( long mapX, long mapY );
 	bool chkDrawSanctuary( long mapX, long mapY, trap_t *trap );
 	bool chkDrawCrsr( long mapX, long mapY );
