@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: PcgDunTab.h,v 1.18 2008/05/08 10:13:42 bowkenken Exp $
+* $Id: PcgDunTab.h,v 1.19 2008/05/13 00:53:05 bowkenken Exp $
 ***************************************************************/
 
 #ifndef PCG_DUN_TAB_H
@@ -179,7 +179,39 @@ PcgTab gPcgTabStatue[] = {
 		MNSTR_KIND_NULL,
 		FACE_MJR_NULL, FACE_MNR_NULL,
 		30,
-		"wall/statue/",
+		"statue/",
+	},
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		-1,
+		"",
+	},
+};
+
+PcgTab gPcgTabStreetlampOn[] = {
+	{
+		// 
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"streetlamp/on",
+	},
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		-1,
+		"",
+	},
+};
+
+PcgTab gPcgTabStreetlampOff[] = {
+	{
+		// 
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"streetlamp/off",
 	},
 	{
 		MNSTR_KIND_NULL,
