@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: WinPos.cpp,v 1.3 2008/05/09 12:53:03 bowkenken Exp $
+* $Id: WinPos.cpp,v 1.11 2008/09/20 01:53:18 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -43,12 +43,11 @@
 
 WinPos::WinPos()
 {
-	pWin = NULL;
-	bFlagEna = false;
+	flagDraw = false;
 	x = 0;
 	y = 0;
-	w = 16;
-	h = 16;
+	w = -1;
+	h = -1;
 }
 
 ////////////////////////////////////////////////////////////////
@@ -60,11 +59,17 @@ WinPos::~WinPos()
 }
 
 ////////////////////////////////////////////////////////////////
-// 
+// ɥ֤
+// win_kind_t kind : ɥμ
+// return : ɥ
 ////////////////////////////////////////////////////////////////
 
 void *WinPos::getWin( win_kind_t kind )
 {
+#ifdef D_WS
+//@@@
+#endif // D_WS
+
 #ifdef D_GTK
 	switch( kind ){
 	case WIN_KIND_NULL:
@@ -90,6 +95,14 @@ void *WinPos::getWin( win_kind_t kind )
 		return gGuiNum.mNumWin;
 	case WIN_KIND_INPUT_STRING:
 		return gGuiInpStr.mWin;
+	case WIN_KIND_WORDS:
+		return gGuiWords.mWordsWin;
+	case WIN_KIND_REPLAY:
+		return gGuiReplay.mReplayWin;
+	case WIN_KIND_CLASS_EDIT:
+		return gGuiClassEdit.mClassEditWin;
+	case WIN_KIND_CHR_SHEET:
+		return gGuiChrSheet.mChrSheetWin;
 	case WIN_KIND_MAX_N:
 		break;
 	}
@@ -120,6 +133,14 @@ void *WinPos::getWin( win_kind_t kind )
 		return gGuiNum.mNumWin;
 	case WIN_KIND_INPUT_STRING:
 		return gGuiInpStr.mInpStrWin;
+	case WIN_KIND_WORDS:
+		return gGuiWords.mWordsWin;
+	case WIN_KIND_REPLAY:
+		return gGuiReplay.mReplayWin;
+	case WIN_KIND_CLASS_EDIT:
+		return gGuiClassEdit.mClassEditWin;
+	case WIN_KIND_CHR_SHEET:
+		return gGuiChrSheet.mChrSheetWin;
 	case WIN_KIND_MAX_N:
 		break;
 	}
@@ -130,20 +151,18 @@ void *WinPos::getWin( win_kind_t kind )
 
 ////////////////////////////////////////////////////////////////
 // ɥκɸ
-// long nx : X ɸ
-// long ny : Y ɸ
-// long nw : 
-// long nh : ⤵
+// win_kind_t kind : ɥμ
+// long *px : X ɸ
+// long *py : Y ɸ
+// long *pw : 
+// long *ph : ⤵
 ////////////////////////////////////////////////////////////////
 
 void WinPos::set(
 	win_kind_t kind,
 	long *px, long *py,
-	long *pw, long *ph,
-	bool flagForce )
+	long *pw, long *ph )
 {
-	bFlagEna = true;
-
 	if( px != NULL )
 		x = *px;
 	if( py != NULL )
@@ -153,104 +172,69 @@ void WinPos::set(
 	if( ph != NULL )
 		h = *ph;
 
-	if( !g_flg_init && !flagForce )
-		return;
-
-	void *pWin = getWin( kind );
-	if( pWin == NULL )
-		return;
-
-#ifdef D_GTK
-	if( (px != NULL) || (py != NULL) )
-		gtk_widget_set_uposition( GTK_WIDGET( pWin ), x, y );
-# if 0
-//@@@
-	if( (pw != NULL) || (ph != NULL) ){
-		gtk_widget_set_usize( GTK_WIDGET( pWin ), w, h );
-		gtk_window_set_resizable( GTK_WINDOW( pWin ), TRUE );
-	}
-# elif 0
-//@@@
-	if( (pw != NULL) || (ph != NULL) ){
-		gtk_widget_set_size_request( GTK_WIDGET( pWin ), w, h );
-		gtk_window_set_resizable( GTK_WINDOW( pWin ), TRUE );
-	}
-# endif
-#endif //D_GTK
-
-#ifdef D_MFC
-	((CWnd *)pWin)->MoveWindow( x, y, w, h );
-#endif //D_MFC
+	if( flagDraw )
+		draw( kind );
 }
 
 ////////////////////////////////////////////////////////////////
 // ɥκɸμ
+// win_kind_t kind : ɥμ
 // long *px : X ɸ
 // long *py : Y ɸ
 // long *pw : 
 // long *ph : ⤵
-// bool flagFromWin : ɥƤФ줿?
 ////////////////////////////////////////////////////////////////
 
-bool WinPos::get(
+void WinPos::get(
 	win_kind_t kind,
 	long *px, long *py,
-	long *pw, long *ph,
-	bool flagFromWin )
+	long *pw, long *ph )
 {
-	if( !flagFromWin ){
-		void *pWin = getWin( kind );
-		if( pWin != NULL ){
+	void *pWin = getWin( kind );
+
+	if( (pWin != NULL) && flagDraw ){
+#ifdef D_WS
+//@@@
+#endif // D_WS
+
 #ifdef D_GTK
-			gint gx, gy, gw, gh;
-			gint bgnX, bgnY, endX, endY;
+		gint gx, gy, gw, gh;
+		gint bgnX, bgnY, endX, endY;
 
-			// ɸ
+		GdkWindow *win = GTK_WIDGET( pWin )->window;
 
-			gdk_window_get_position(
-					GTK_WIDGET( pWin )->window,
-					&gx, &gy );
-			gdk_window_get_root_origin(
-					GTK_WIDGET( pWin )->window,
-					&bgnX, &bgnY );
-			gdk_window_get_origin(
-					GTK_WIDGET( pWin )->window,
-					&endX, &endY );
+		// ɸ
 
-			gx -= endX - bgnX;
-			gy -= endY - bgnY;
+		gdk_window_get_position( win, &gx, &gy );
+		gdk_window_get_root_origin( win, &bgnX, &bgnY );
+		gdk_window_get_origin( win, &endX, &endY );
 
-			// 
+		gx -= endX - bgnX;
+		gy -= endY - bgnY;
 
-			gdk_window_get_size(
-					GTK_WIDGET( pWin )->window,
-					&gw, &gh );
+		// 
 
-			// 
+		gdk_window_get_size( win, &gw, &gh );
 
-			x = gx;
-			y = gy;
-			w = gw;
-			h = gh;
+		// 
+
+		x = gx;
+		y = gy;
+		w = gw;
+		h = gh;
 #endif //D_GTK
 
 #ifdef D_MFC
-			CRect rect;
-			((CWnd *)pWin)->GetWindowRect( &rect );
+		CRect rect;
+		((CWnd *)pWin)->GetWindowRect( &rect );
 
-			x = rect.left;
-			y = rect.top;
-			w = rect.Width();
-			h = rect.Height();
+		x = rect.left;
+		y = rect.top;
+		w = rect.Width();
+		h = rect.Height();
 #endif //D_MFC
-
-			bFlagEna = true;
-		}
 	}
 
-	if( !bFlagEna )
-		return false;
-
 	if( px != NULL )
 		*px = x;
 	if( py != NULL )
@@ -259,6 +243,109 @@ bool WinPos::get(
 		*pw = w;
 	if( ph != NULL )
 		*ph = h;
+}
 
-	return true;
+////////////////////////////////////////////////////////////////
+// ɥɽ
+// win_kind_t kind : ɥμ
+////////////////////////////////////////////////////////////////
+
+void WinPos::draw( win_kind_t kind, bool flagDlg )
+{
+	void *pWin = getWin( kind );
+	if( pWin == NULL )
+		return;
+
+#ifdef D_WS
+	pWin->setVisible( true );
+#endif // D_WS
+
+#ifdef D_GTK
+	gtk_widget_show( GTK_WIDGET( pWin ) );
+
+	gtk_widget_set_uposition( GTK_WIDGET( pWin ), x, y );
+	GTK_WIDGET( pWin )->allocation.width = w;
+	GTK_WIDGET( pWin )->allocation.height = h;
+//@@@	gtk_widget_set_size_request( GTK_WIDGET( pWin ), w, h );
+
+	gdk_window_raise( GTK_WIDGET( pWin )->window );
+#endif //D_GTK
+
+#ifdef D_MFC
+	if( flagDlg ){
+		if( (w > 0) && (h > 0) )
+			((CDialog *)pWin)->MoveWindow( x, y, w, h );
+	} else {
+		((CWnd *)pWin)->ShowWindow( SW_SHOW );
+		if( (w > 0) && (h > 0) )
+			((CWnd *)pWin)->MoveWindow( x, y, w, h );
+		((CWnd *)pWin)->BringWindowToTop();
+		((CWnd *)pWin)->UpdateWindow();
+	}
+#endif //D_MFC
+
+	flagDraw = true;
+}
+
+////////////////////////////////////////////////////////////////
+// ɥĤ
+// win_kind_t kind : ɥμ
+////////////////////////////////////////////////////////////////
+
+void WinPos::wipe( win_kind_t kind, bool flagDlg )
+{
+	void *pWin = getWin( kind );
+	if( pWin == NULL )
+		return;
+
+#ifdef D_WS
+//@@@
+	pWin->setVisible( false );
+#endif // D_WS
+
+#ifdef D_GTK
+	gint gx, gy, gw, gh;
+	gint bgnX, bgnY, endX, endY;
+
+	GdkWindow *win = GTK_WIDGET( pWin )->window;
+
+	// ɸ
+
+	gdk_window_get_position( win, &gx, &gy );
+	gdk_window_get_root_origin( win, &bgnX, &bgnY );
+	gdk_window_get_origin( win, &endX, &endY );
+
+	gx -= endX - bgnX;
+	gy -= endY - bgnY;
+
+	// 
+
+	gdk_window_get_size( win, &gw, &gh );
+
+	// 
+
+	x = gx;
+	y = gy;
+	w = gw;
+	h = gh;
+
+	//
+
+	gtk_widget_hide( GTK_WIDGET( pWin ) );
+#endif //D_GTK
+
+#ifdef D_MFC
+	CRect rect;
+	((CWnd *)pWin)->GetWindowRect( &rect );
+
+	x = rect.left;
+	y = rect.top;
+	w = rect.Width();
+	h = rect.Height();
+
+	if( !flagDlg )
+		((CWnd *)pWin)->ShowWindow( SW_HIDE );
+#endif //D_MFC
+
+	flagDraw = false;
 }
