@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.c,v 1.70 2007/06/05 07:33:35 bowkenken Exp $
+* $Id: amenu.c,v 1.82 2008/09/21 13:00:03 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -43,9 +43,16 @@
 /***************************************************************/
 
 static auto_mark_t	ls_auto_mark[LS_MBR_MAX_N][AUTO_MARK_MAX_N];
+static bool_t	ls_flg_ena_auto_mark[AUTO_MARK_MAX_N];
+
 static auto_mark_t	clip_board_large[LS_MBR_MAX_N];
 static auto_mark_t	clip_board_small;
 
+static auto_mark_appoint_item_t	clip_board_large_item
+		[LS_MBR_MAX_N][AUTO_MARK_APPOINT_ITEM_MAX_N];
+static auto_mark_appoint_item_t	clip_board_small_item
+		[AUTO_MARK_APPOINT_ITEM_MAX_N];
+
 static char	msg_ttl_auto_mark[AUTO_MARK_MAX_N]
 		[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
 static char	clip_board_ttl
@@ -229,22 +236,58 @@ static auto_mark_appoint_item_t	auto_mark_appoint_item_dflt
 
 void	init_auto_menu( void )
 {
-	long	i;
+	long	i, k;
 
 	g_sel_mbr = NULL;
 	auto_mark_cur_n = 0;
 
+	reset_ls_flg_ena_auto_mark();
 	init_auto_mark_all_appoint();
 	init_auto_mark_all_mbr();
 
 	for( i = 0; i < LS_MBR_MAX_N; i++ ){
 		clip_board_large[i] = ls_auto_mark[i][0];
 
-		str_nz_cpy( clip_board_ttl,
-				msg_ttl_auto_mark[0],
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+		for( k = 0; k < AUTO_MARK_APPOINT_ITEM_MAX_N; k++ ){
+			clip_board_large_item[i][k]
+					= auto_mark_appoint_item[i][0][k];
+		}
 	}
+
 	clip_board_small = ls_auto_mark[0][0];
+	str_nz_cpy( clip_board_ttl,
+			msg_ttl_auto_mark[0],
+			MSG_TTL_AUTO_MARK_MAX_LEN );
+}
+
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_auto_menu( void )
+{
+	long	i;
+
+	g_sel_mbr = NULL;
+	auto_mark_cur_n = 0;
+
+	for( i = 0; i < LS_MBR_MAX_N; i++ )
+		clip_board_large[i] = dflt_auto_mark_fight;
+	clip_board_small = dflt_auto_mark_fight;
+	str_nz_cpy( clip_board_ttl, "",
+			MSG_TTL_AUTO_MARK_MAX_LEN );
+}
+
+/***************************************************************
+* ͭե饰ꥻå
+***************************************************************/
+
+void	reset_ls_flg_ena_auto_mark()
+{
+	long	j;
+
+	for( j = 0; j < AUTO_MARK_MAX_N; j++ )
+		ls_flg_ena_auto_mark[j] = FALSE;
 }
 
 /***************************************************************
@@ -307,6 +350,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_CLEAR,
 				MSG_TTL_AUTO_MARK_MAX_LEN );
+		ls_flg_ena_auto_mark[j] = FALSE;
 	}
 
 	j = 0;
@@ -331,6 +375,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 	str_nz_cpy( msg_ttl_auto_mark[j],
 			MSG_NAME_DFLT_AUTO_MARK_FIGHT,
 			MSG_TTL_AUTO_MARK_MAX_LEN );
+	ls_flg_ena_auto_mark[j] = TRUE;
 	j++;
 
 	/* Ʈ() */
@@ -353,6 +398,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 	str_nz_cpy( msg_ttl_auto_mark[j],
 			MSG_NAME_DFLT_AUTO_MARK_FIGHT_PRIO,
 			MSG_TTL_AUTO_MARK_MAX_LEN );
+	ls_flg_ena_auto_mark[j] = TRUE;
 	j++;
 
 	/* ܶƮ(ɲ) */
@@ -373,6 +419,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 	str_nz_cpy( msg_ttl_auto_mark[j],
 			MSG_NAME_DFLT_AUTO_MARK_FIGHT_NO_THROW,
 			MSG_TTL_AUTO_MARK_MAX_LEN );
+	ls_flg_ena_auto_mark[j] = TRUE;
 	j++;
 
 	/* ܶƮ() */
@@ -393,6 +440,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 	str_nz_cpy( msg_ttl_auto_mark[j],
 			MSG_NAME_DFLT_AUTO_MARK_FIGHT_NO_THROW_PRIO,
 			MSG_TTL_AUTO_MARK_MAX_LEN );
+	ls_flg_ena_auto_mark[j] = TRUE;
 	j++;
 
 	/* (ɲ) */
@@ -402,6 +450,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL,
 				MSG_TTL_AUTO_MARK_MAX_LEN );
+		ls_flg_ena_auto_mark[j] = TRUE;
 	}
 	j++;
 
@@ -412,18 +461,38 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL_PRIO,
 				MSG_TTL_AUTO_MARK_MAX_LEN );
+		ls_flg_ena_auto_mark[j] = TRUE;
+	}
+	j++;
+
+	/*  */
+
+	if( j < AUTO_MARK_MAX_N ){
+		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_clear;
+		str_nz_cpy( msg_ttl_auto_mark[j],
+				MSG_NAME_DFLT_AUTO_MARK_CLEAR,
+				MSG_TTL_AUTO_MARK_MAX_LEN );
+		ls_flg_ena_auto_mark[j] = TRUE;
+	}
+	j++;
+
+	if( j < AUTO_MARK_MAX_N ){
+		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_clear;
+		str_nz_cpy( msg_ttl_auto_mark[j],
+				MSG_NAME_DFLT_AUTO_MARK_CLEAR,
+				MSG_TTL_AUTO_MARK_MAX_LEN );
+		ls_flg_ena_auto_mark[j] = TRUE;
 	}
 	j++;
 
 	/* ƤΥƥ */
 
-	j += 2;
-
 	if( j < AUTO_MARK_MAX_N ){
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_item_all;
 		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_ITEM_ALL,
 				MSG_TTL_AUTO_MARK_MAX_LEN );
+		ls_flg_ena_auto_mark[j] = TRUE;
 	}
 	j++;
 
@@ -434,14 +503,9 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_ITEM_OWN,
 				MSG_TTL_AUTO_MARK_MAX_LEN );
+		ls_flg_ena_auto_mark[j] = TRUE;
 	}
 	j++;
-
-	j = AUTO_MARK_MAX_N - 1;
-	ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_clear;
-	str_nz_cpy( msg_ttl_auto_mark[j],
-			MSG_NAME_DFLT_AUTO_MARK_CLEAR,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
 }
 
 /***************************************************************
@@ -594,7 +658,7 @@ void	ver_up_auto_mark_1_1_3( void )
 
 void	cv_msg_ttl_auto_mark( char *ttl )
 {
-	static char	old_split[] = " - ";
+	const char	old_split[] = " - ";
 	char	work_left[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
 	char	work_right[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
 	char	*p;
@@ -722,13 +786,24 @@ void	set_menu_auto_mark( menu_t **dflt )
 
 		kk = k;
 
-		sprintf( buf, "%*s%s%s",
-				(int)left_max_len,
-				get_msg_ttl_auto_mark_info( i ),
-				STR_TTL_AUTO_MARK_SPLIT_NAME,
-				get_msg_ttl_auto_mark_hint( i ) );
+		if( ls_flg_ena_auto_mark[i] ){
+			sn_printf( buf, MSG_TTL_AUTO_MARK_MAX_LEN * 3 + 16,
+					"%*s%s%s",
+					(int)left_max_len,
+					get_msg_ttl_auto_mark_info( i ),
+					STR_TTL_AUTO_MARK_SPLIT_NAME,
+					get_msg_ttl_auto_mark_hint( i ) );
+		} else {
+			sn_printf( buf, MSG_TTL_AUTO_MARK_MAX_LEN * 3 + 16,
+					"%*s%s%s",
+					(int)left_max_len,
+					MSG_MENU_AUTO_MARK_NULL,
+					STR_TTL_AUTO_MARK_SPLIT_NAME,
+					MSG_MENU_AUTO_MARK_NULL );
+		}
 
-		sprintf( p[k].path, "/auto mark/%ld", i );
+		sn_printf( p[k].path, MENU_PATH_MAX_LEN,
+				"/auto mark/%ld", i );
 		str_nz_cpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 		p[k].accel_key = key;
 		p[k].short_key[0] = '\0';
@@ -739,7 +814,8 @@ void	set_menu_auto_mark( menu_t **dflt )
 		k++;
 		key++;
 
-		sprintf( p[k].path, "%s/exec", p[kk].path );
+		sn_printf( p[k].path, MENU_PATH_MAX_LEN,
+				"%s/exec", p[kk].path );
 		str_nz_cpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		p[k].accel_key = 'X';
 		p[k].short_key[0] = '\0';
@@ -750,7 +826,8 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].flg = FLG_NULL;
 		k++;
 
-		sprintf( p[k].path, "%s/edit", p[kk].path );
+		sn_printf( p[k].path, MENU_PATH_MAX_LEN,
+				"%s/edit", p[kk].path );
 		str_nz_cpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 		p[k].accel_key = 'E';
 		p[k].short_key[0] = '\0';
@@ -761,7 +838,8 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].flg = FLG_NULL;
 		k++;
 
-		sprintf( p[k].path, "%s/edit name", p[kk].path );
+		sn_printf( p[k].path, MENU_PATH_MAX_LEN,
+				"%s/edit name", p[kk].path );
 		str_nz_cpy( p[k].kind, "<OpenWinItem>", MENU_KIND_MAX_LEN );
 		p[k].accel_key = 'N';
 		p[k].short_key[0] = '\0';
@@ -772,7 +850,8 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].flg = FLG_NULL;
 		k++;
 
-		sprintf( p[k].path, "%s/copy", p[kk].path );
+		sn_printf( p[k].path, MENU_PATH_MAX_LEN,
+				"%s/copy", p[kk].path );
 		str_nz_cpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		p[k].accel_key = 'W';
 		p[k].short_key[0] = '\0';
@@ -783,7 +862,8 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].flg = FLG_NULL;
 		k++;
 
-		sprintf( p[k].path, "%s/paste", p[kk].path );
+		sn_printf( p[k].path, MENU_PATH_MAX_LEN,
+				"%s/paste", p[kk].path );
 		str_nz_cpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		p[k].accel_key = 'Y';
 		p[k].short_key[0] = '\0';
@@ -794,7 +874,44 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].flg = FLG_NULL;
 		k++;
 
-		sprintf( p[k].path, "%s/arrange top", p[kk].path );
+		sn_printf( p[k].path, MENU_PATH_MAX_LEN,
+				"%s/remove", p[kk].path );
+		str_nz_cpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		p[k].accel_key = 'R';
+		p[k].short_key[0] = '\0';
+		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_REMOVE,
+				MENU_MSG_MAX_LEN );
+		p[k].call_back = cb_menu_auto_mark_remove;
+		p[k].arg = (void *)i;
+		p[k].flg = FLG_NULL;
+		k++;
+
+		sn_printf( p[k].path, MENU_PATH_MAX_LEN,
+				"%s/arrange up", p[kk].path );
+		str_nz_cpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		p[k].accel_key = 'U';
+		p[k].short_key[0] = '\0';
+		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_ARRANGE_UP,
+				MENU_MSG_MAX_LEN );
+		p[k].call_back = cb_menu_auto_mark_arrange_up;
+		p[k].arg = (void *)i;
+		p[k].flg = FLG_NULL;
+		k++;
+
+		sn_printf( p[k].path, MENU_PATH_MAX_LEN,
+				"%s/arrange down", p[kk].path );
+		str_nz_cpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		p[k].accel_key = 'D';
+		p[k].short_key[0] = '\0';
+		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_ARRANGE_DOWN,
+				MENU_MSG_MAX_LEN );
+		p[k].call_back = cb_menu_auto_mark_arrange_down;
+		p[k].arg = (void *)i;
+		p[k].flg = FLG_NULL;
+		k++;
+
+		sn_printf( p[k].path, MENU_PATH_MAX_LEN,
+				"%s/arrange top", p[kk].path );
 		str_nz_cpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		p[k].accel_key = 'T';
 		p[k].short_key[0] = '\0';
@@ -805,7 +922,8 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].flg = FLG_NULL;
 		k++;
 
-		sprintf( p[k].path, "%s/arrange bottom", p[kk].path );
+		sn_printf( p[k].path, MENU_PATH_MAX_LEN,
+				"%s/arrange bottom", p[kk].path );
 		str_nz_cpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		p[k].accel_key = 'B';
 		p[k].short_key[0] = '\0';
@@ -833,6 +951,9 @@ char	*cb_menu_auto_mark_exec( menu_t **pp, menu_t **dflt )
 	long	i;
 
 	n = (long)((*pp)->arg);
+	if( !chk_flg_ena_auto_mark( n ) )
+		return STR_MENU_CANCEL;
+
 	if( auto_mark_cur_n != n ){
 		auto_mark_cur_n = n;
 
@@ -902,13 +1023,16 @@ bool_t	exec_menu_auto_mark( mbr_t *mbr )
 			flg_clr = TRUE;
 		break;
 	case AUTO_MARK_TRGT_TRAP:
+		if( !exec_menu_auto_mark_trap( mbr ) )
+			flg_clr = TRUE;
 		break;
 	case AUTO_MARK_TRGT_MBR:
 		if( !exec_menu_auto_mark_mbr( mbr ) )
 			flg_clr = TRUE;
 		break;
 	case AUTO_MARK_TRGT_UNCHANGE:
-		return TRUE;
+		flg_clr = FALSE;
+		break;
 	case AUTO_MARK_TRGT_CLEAR:
 		flg_clr = TRUE;
 		break;
@@ -985,6 +1109,8 @@ bool_t	exec_menu_auto_mark_mnstr( mbr_t *mbr )
 		break;
 	case AUTO_MARK_COND_STAGGER:
 	case AUTO_MARK_COND_OWN:
+	case AUTO_MARK_COND_IDENTIFIED:
+	case AUTO_MARK_COND_UN_IDENTIFIED:
 		return FALSE;
 	case AUTO_MARK_COND_HP_MIN:
 		mnstr = get_mnstr_hp_min( mbr->x, mbr->y );
@@ -1091,6 +1217,12 @@ bool_t	exec_menu_auto_mark_item( mbr_t *mbr )
 	case AUTO_MARK_COND_OWN:
 		item = get_item_own( mbr, act_kind, TRUE );
 		break;
+	case AUTO_MARK_COND_IDENTIFIED:
+		item = get_item_identified( mbr, act_kind, TRUE );
+		break;
+	case AUTO_MARK_COND_UN_IDENTIFIED:
+		item = get_item_un_identified( mbr, act_kind, TRUE );
+		break;
 	case AUTO_MARK_COND_HP_MIN:
 	case AUTO_MARK_COND_HP_MAX:
 	case AUTO_MARK_COND_MP_MIN:
@@ -1188,6 +1320,8 @@ bool_t	exec_menu_auto_mark_door( mbr_t *mbr )
 		break;
 	case AUTO_MARK_COND_STAGGER:
 	case AUTO_MARK_COND_OWN:
+	case AUTO_MARK_COND_IDENTIFIED:
+	case AUTO_MARK_COND_UN_IDENTIFIED:
 	case AUTO_MARK_COND_HP_MIN:
 	case AUTO_MARK_COND_HP_MAX:
 	case AUTO_MARK_COND_MP_MIN:
@@ -1223,6 +1357,103 @@ bool_t	exec_menu_auto_mark_door( mbr_t *mbr )
 	return TRUE;
 }
 
+/***************************************************************
+* 櫤оݤ˥˥塼¹Ԥ
+* mbr_t *mbr : С
+* return : Ԥ
+***************************************************************/
+
+bool_t	exec_menu_auto_mark_trap( mbr_t *mbr )
+{
+	auto_mark_t	*am;
+	trap_t	*trap;
+	dist_t	dist;
+	act_kind_t	act_kind;
+
+	if( mbr == NULL )
+		return FALSE;
+	am = &(ls_auto_mark[mbr->ls_mbr_n][auto_mark_cur_n]);
+
+	switch( am->act ){
+	case AUTO_MARK_ACT_FIGHT:
+	case AUTO_MARK_ACT_THROW:
+	case AUTO_MARK_ACT_STEAL:
+	case AUTO_MARK_ACT_TAIL:
+	case AUTO_MARK_ACT_PICK_UP:
+	case AUTO_MARK_ACT_OPEN:
+	case AUTO_MARK_ACT_CLOSE:
+	case AUTO_MARK_ACT_JAM:
+		return FALSE;
+	case AUTO_MARK_ACT_DISARM:
+		act_kind = ACT_KIND_TRAP_DISARM;
+		break;
+	case AUTO_MARK_ACT_BREAK:
+		act_kind = ACT_KIND_TRAP_BREAK;
+		break;
+	case AUTO_MARK_ACT_PEEP:
+		return FALSE;
+	case AUTO_MARK_ACT_CHK:
+		act_kind = ACT_KIND_TRAP_CHK;
+		break;
+	default:
+		return FALSE;
+	}
+
+	/* 櫤õ */
+	trap = NULL;
+	switch( am->cond ){
+	case AUTO_MARK_COND_NEAREST:
+		trap = get_trap_nearest( mbr, act_kind );
+		break;
+	case AUTO_MARK_COND_DISPERSE:
+		trap = get_trap_disperse( mbr, act_kind );
+		if( trap == NULL )
+			trap = get_trap_randm( mbr, act_kind );
+		break;
+	case AUTO_MARK_COND_STAGGER:
+	case AUTO_MARK_COND_OWN:
+		return FALSE;
+	case AUTO_MARK_COND_IDENTIFIED:
+		trap = get_trap_identified( mbr, act_kind );
+		break;
+	case AUTO_MARK_COND_UN_IDENTIFIED:
+		trap = get_trap_un_identified( mbr, act_kind );
+		break;
+	case AUTO_MARK_COND_HP_MIN:
+	case AUTO_MARK_COND_HP_MAX:
+	case AUTO_MARK_COND_MP_MIN:
+	case AUTO_MARK_COND_MP_MAX:
+		return FALSE;
+	}
+	if( trap == NULL )
+		return FALSE;
+
+	/* ֹ礤򥻥å */
+	switch( am->dist ){
+	case AUTO_MARK_DIST_NEAR:
+		dist = DIST_NEAR;
+		break;
+	case AUTO_MARK_DIST_MEDIUM:
+		dist = DIST_MEDIUM;
+		break;
+	case AUTO_MARK_DIST_FAR:
+		dist = DIST_FAR;
+		break;
+	default:
+		return FALSE;
+	}
+
+	/* 򥻥å */
+	set_chr_act( mbr, act_kind, NULL, NULL, 0, 0 );
+
+	/* 櫤ޡ */
+	mark_trap( mbr, trap, dist );
+
+	draw_mbr_stat( mbr );
+
+	return TRUE;
+}
+
 /***************************************************************
 * Соݤ˥˥塼¹Ԥ
 * mbr_t *mbr : С
@@ -1255,6 +1486,8 @@ bool_t	exec_menu_auto_mark_mbr( mbr_t *mbr )
 		p = get_mbr_stagger( mbr );
 		break;
 	case AUTO_MARK_COND_OWN:
+	case AUTO_MARK_COND_IDENTIFIED:
+	case AUTO_MARK_COND_UN_IDENTIFIED:
 		return FALSE;
 	case AUTO_MARK_COND_HP_MIN:
 		p = get_mbr_hp_min();
@@ -1337,6 +1570,9 @@ char	*cb_menu_auto_mark_edit( menu_t **pp, menu_t **dflt )
 
 	auto_mark_cur_n = (long)((*pp)->arg);
 
+	ls_flg_ena_auto_mark[auto_mark_cur_n] = TRUE;
+	set_menu_auto_mark( dflt );
+
 	while( 1 ){
 		str_goto = exec_menu_sel_mbr(
 				&g_sel_mbr, NULL, TRUE, FALSE );
@@ -1376,7 +1612,8 @@ char	*cb_menu_auto_mark_edit_init(
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_EDIT,
+	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+			MSG_TTL_MENU_AUTO_MARK_EDIT,
 			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
@@ -1384,28 +1621,32 @@ char	*cb_menu_auto_mark_edit_init(
 	p = srch_menu( *pp, "target" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sprintf( p->msg, MSG_MENU_AUTO_MARK_EDIT_TRGT,
+	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+			MSG_MENU_AUTO_MARK_EDIT_TRGT,
 			get_msg_menu_auto_mark_edit_trgt( g_sel_mbr ) );
 
 	/* ֹ礤 */
 	p = srch_menu( *pp, "dist" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sprintf( p->msg, MSG_MENU_AUTO_MARK_EDIT_DIST,
+	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+			MSG_MENU_AUTO_MARK_EDIT_DIST,
 			get_msg_menu_auto_mark_edit_dist( g_sel_mbr ) );
 
 	/* ư */
 	p = srch_menu( *pp, "action" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sprintf( p->msg, MSG_MENU_AUTO_MARK_EDIT_ACT,
+	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+			MSG_MENU_AUTO_MARK_EDIT_ACT,
 			get_msg_menu_auto_mark_edit_act( g_sel_mbr ) );
 
 	/*  */
 	p = srch_menu( *pp, "condition" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sprintf( p->msg, MSG_MENU_AUTO_MARK_EDIT_COND,
+	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+			MSG_MENU_AUTO_MARK_EDIT_COND,
 			get_msg_menu_auto_mark_edit_cond( g_sel_mbr ) );
 
 	/* ƥ */
@@ -1454,7 +1695,8 @@ char	*cb_menu_auto_mark_trgt_init(
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_TRGT,
+	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+			MSG_TTL_MENU_AUTO_MARK_TRGT,
 			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
@@ -1557,7 +1799,8 @@ char	*cb_menu_auto_mark_dist_init(
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_DIST,
+	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+			MSG_TTL_MENU_AUTO_MARK_DIST,
 			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
@@ -1620,7 +1863,8 @@ char	*cb_menu_auto_mark_act_init( menu_t **pp, menu_t **dflt )
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_ACT,
+	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+			MSG_TTL_MENU_AUTO_MARK_ACT,
 			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
@@ -1668,53 +1912,52 @@ char	*cb_menu_auto_mark_act_init( menu_t **pp, menu_t **dflt )
 
 	/* оݤ˱ƥ˥塼ܤ̵ */
 
+	set_flg_menu( *pp, "fight", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "throw", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "steal", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "tail", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "pick up", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "open", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "close", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "jam", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "disarm", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "break", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "peep", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "search", FLG_MENU_HIDDEN );
+
 	switch( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].trgt ){
 	case AUTO_MARK_TRGT_MNSTR:
-		set_flg_menu( *pp, "pick up", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "open", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "close", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "jam", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "disarm", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "break", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "peep", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "search", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "fight", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "throw", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "steal", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "tail", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_ITEM:
-		set_flg_menu( *pp, "fight", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "throw", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "steal", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "tail", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "close", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "jam", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "peep", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "pick up", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "open", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "disarm", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "break", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "search", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_DOOR:
-		set_flg_menu( *pp, "fight", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "throw", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "steal", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "tail", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "pick up", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "open", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "close", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "jam", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "disarm", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "break", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "peep", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "search", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_TRAP:
-		set_flg_menu( *pp, "fight", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "throw", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "steal", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "tail", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "pick up", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "open", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "close", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "jam", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "peep", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "disarm", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "break", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "search", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_MBR:
-		set_flg_menu( *pp, "pick up", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "open", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "close", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "jam", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "disarm", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "break", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "peep", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "search", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "fight", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "throw", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "steal", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "tail", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_UNCHANGE:
 	case AUTO_MARK_TRGT_CLEAR:
@@ -1770,7 +2013,8 @@ char	*cb_menu_auto_mark_cond_init(
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_COND,
+	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+			MSG_TTL_MENU_AUTO_MARK_COND,
 			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
@@ -1790,6 +2034,12 @@ char	*cb_menu_auto_mark_cond_init(
 	case AUTO_MARK_COND_OWN:
 		s = "own";
 		break;
+	case AUTO_MARK_COND_IDENTIFIED:
+		s = "identified";
+		break;
+	case AUTO_MARK_COND_UN_IDENTIFIED:
+		s = "unidentified";
+		break;
 	case AUTO_MARK_COND_HP_MIN:
 		s = "hp min";
 		break;
@@ -1807,6 +2057,12 @@ char	*cb_menu_auto_mark_cond_init(
 
 	/* оݤ˱ƥ˥塼ܤ̵ */
 
+	set_flg_menu( *pp, "nearest", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp,"disperse",  FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "stagger", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "own", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "identified", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "unidentified", FLG_MENU_HIDDEN );
 	set_flg_menu( *pp, "hp min", FLG_MENU_HIDDEN );
 	set_flg_menu( *pp, "hp max", FLG_MENU_HIDDEN );
 	set_flg_menu( *pp, "mp min", FLG_MENU_HIDDEN );
@@ -1814,23 +2070,34 @@ char	*cb_menu_auto_mark_cond_init(
 
 	switch( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].trgt ){
 	case AUTO_MARK_TRGT_DOOR:
+		clr_flg_menu( *pp, "nearest", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp,"disperse",  FLG_MENU_HIDDEN );
+		break;
 	case AUTO_MARK_TRGT_TRAP:
-		set_flg_menu( *pp, "stagger", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "own", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "nearest", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp,"disperse",  FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "identified", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "unidentified", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_ITEM:
-		set_flg_menu( *pp, "stagger", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "nearest", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp,"disperse",  FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "own", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "identified", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "unidentified", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_MNSTR:
-		set_flg_menu( *pp, "stagger", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "own", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "nearest", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp,"disperse",  FLG_MENU_HIDDEN );
 		clr_flg_menu( *pp, "hp min", FLG_MENU_HIDDEN );
 		clr_flg_menu( *pp, "hp max", FLG_MENU_HIDDEN );
 		clr_flg_menu( *pp, "mp min", FLG_MENU_HIDDEN );
 		clr_flg_menu( *pp, "mp max", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_MBR:
-		set_flg_menu( *pp, "own", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "nearest", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp,"disperse",  FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "stagger", FLG_MENU_HIDDEN );
 		clr_flg_menu( *pp, "hp min", FLG_MENU_HIDDEN );
 		clr_flg_menu( *pp, "hp max", FLG_MENU_HIDDEN );
 		clr_flg_menu( *pp, "mp min", FLG_MENU_HIDDEN );
@@ -1847,7 +2114,8 @@ char	*cb_menu_auto_mark_cond_init(
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_COND,
+	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+			MSG_TTL_MENU_AUTO_MARK_COND,
 			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
@@ -1913,7 +2181,8 @@ char	*cb_menu_auto_mark_appoint_item(
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	sprintf( ls[k].msg, MSG_TTL_MENU_AUTO_MARK_APPOINT_ITEM_MJR,
+	sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+			MSG_TTL_MENU_AUTO_MARK_APPOINT_ITEM_MJR,
 			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
 	ls[k].call_back = NULL;
@@ -1963,7 +2232,8 @@ char	*set_menu_auto_mark_appoint_item(
 
 	mjr = (*apo)->mjr;
 
-	sprintf( ls[*k].path, "/appoint item/%c", mjr );
+	sn_printf( ls[*k].path, MENU_PATH_MAX_LEN,
+			"/appoint item/%c", mjr );
 	str_nz_cpy( ls[*k].kind, "<Branch>",
 			MENU_KIND_MAX_LEN );
 	ls[*k].accel_key = mjr_key;
@@ -1989,7 +2259,8 @@ char	*set_menu_auto_mark_appoint_item(
 		if( strcmp( name, MSG_NULL ) == 0 )
 			continue;
 
-		sprintf( ls[*k].path, "/appoint item/%c/%c",
+		sn_printf( ls[*k].path, MENU_PATH_MAX_LEN,
+				"/appoint item/%c/%c",
 				(*apo)->mjr, (*apo)->mnr );
 		str_nz_cpy( ls[*k].kind, "<CheckItem>",
 				MENU_KIND_MAX_LEN );
@@ -2030,7 +2301,8 @@ char	*cb_menu_auto_mark_appoint_item_init(
 		if( apo->mjr != mjr )
 			break;
 
-		sprintf( sub_path, "%c", apo->mnr );
+		sn_printf( sub_path, MENU_PATH_MAX_LEN,
+				"%c", apo->mnr );
 		if( apo->flg_ena )
 			set_chk_on_menu( *pp, sub_path );
 		else
@@ -2083,7 +2355,9 @@ char	*cb_menu_auto_mark_edit_macro_bind( menu_t **pp, menu_t **dflt )
 
 	/* ץץȤɽ */
 
-	sprintf( msg_cmd, MSG_GETS_AUTO_MARK_EDIT_MACRO_CMD, MACRO_MAX_LEN );
+	sn_printf( msg_cmd, WIN_MSG_DRAW_WIDTH,
+			MSG_GETS_AUTO_MARK_EDIT_MACRO_CMD,
+			MACRO_MAX_LEN );
 	print_msg( FLG_NULL, msg_cmd );
 
 	/* ޥ桼 */
@@ -2214,13 +2488,18 @@ char	*cb_menu_auto_mark_priority( menu_t **pp, menu_t **dflt )
 char	*cb_menu_auto_mark_copy_large( menu_t **pp, menu_t **dflt )
 {
 	long	n;
-	long	i;
+	long	i, k;
 
 	n = (long)((*pp)->arg);
 
 	for( i = 0; i < LS_MBR_MAX_N; i++ ){
 		clip_board_large[i] = ls_auto_mark[i][n];
 
+		for( k = 0; k < AUTO_MARK_APPOINT_ITEM_MAX_N; k++ ){
+			clip_board_large_item[i][k]
+					= auto_mark_appoint_item[i][n][k];
+		}
+
 		str_nz_cpy( clip_board_ttl,
 				msg_ttl_auto_mark[n],
 				MSG_TTL_AUTO_MARK_MAX_LEN );
@@ -2241,17 +2520,23 @@ char	*cb_menu_auto_mark_copy_large( menu_t **pp, menu_t **dflt )
 char	*cb_menu_auto_mark_paste_large( menu_t **pp, menu_t **dflt )
 {
 	long	n;
-	long	i;
+	long	i, k;
 
 	n = (long)((*pp)->arg);
 
 	for( i = 0; i < LS_MBR_MAX_N; i++ ){
 		ls_auto_mark[i][n] = clip_board_large[i];
 
+		for( k = 0; k < AUTO_MARK_APPOINT_ITEM_MAX_N; k++ ){
+			auto_mark_appoint_item[i][n][k]
+					= clip_board_large_item[i][k];
+		}
+
 		str_nz_cpy( msg_ttl_auto_mark[n],
 				clip_board_ttl,
 				MSG_TTL_AUTO_MARK_MAX_LEN );
 	}
+	ls_flg_ena_auto_mark[n] = TRUE;
 
 	set_menu_auto_mark( dflt );
 
@@ -2269,9 +2554,17 @@ char	*cb_menu_auto_mark_paste_large( menu_t **pp, menu_t **dflt )
 
 char	*cb_menu_auto_mark_copy_small( menu_t **pp, menu_t **dflt )
 {
+	long	k;
+
 	clip_board_small = ls_auto_mark[g_sel_mbr->ls_mbr_n]
 			[auto_mark_cur_n];
 
+	for( k = 0; k < AUTO_MARK_APPOINT_ITEM_MAX_N; k++ ){
+		clip_board_small_item[k]
+				= auto_mark_appoint_item
+				[g_sel_mbr->ls_mbr_n][auto_mark_cur_n][k];
+	}
+
 	print_msg( FLG_NULL, MSG_MENU_AUTO_MARK_DONE_COPY );
 
 	return STR_MENU_CANCEL;
@@ -2286,12 +2579,24 @@ char	*cb_menu_auto_mark_copy_small( menu_t **pp, menu_t **dflt )
 
 char	*cb_menu_auto_mark_paste_small( menu_t **pp, menu_t **dflt )
 {
+	long	k;
+
 	ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n]
 			= clip_board_small;
 
+	for( k = 0; k < AUTO_MARK_APPOINT_ITEM_MAX_N; k++ ){
+		auto_mark_appoint_item[g_sel_mbr->ls_mbr_n]
+				[auto_mark_cur_n][k]
+				= clip_board_small_item[k];
+	}
+
+	ls_flg_ena_auto_mark[auto_mark_cur_n] = TRUE;
+
+	set_menu_auto_mark( dflt );
+
 	print_msg( FLG_NULL, MSG_MENU_AUTO_MARK_DONE_PASTE );
 
-	return STR_MENU_CANCEL;
+	return "/edit";
 }
 
 /***************************************************************
@@ -2333,6 +2638,70 @@ char	*cb_menu_auto_mark_edit_name( menu_t **pp, menu_t **dflt )
 	return "/auto mark";
 }
 
+/***************************************************************
+* ˥塼򤷤
+* menu_t **pp : ˥塼
+* menu_t **dflt : ˥塼Υǥե
+* return : ˥塼ΰư
+***************************************************************/
+
+char	*cb_menu_auto_mark_remove( menu_t **pp, menu_t **dflt )
+{
+	ask_t	ask;
+	long	n;
+
+	ask = exec_menu_ask( MSG_TTL_MENU_AUTO_MARK_ASK_REMOVE,
+			ASK_NO, TRUE );
+	if( ask == ASK_ERR )
+		return STR_MENU_ERR;
+	if( ask != ASK_YES )
+		return STR_MENU_CANCEL;
+
+	n = (long)((*pp)->arg);
+	ls_flg_ena_auto_mark[n] = FALSE;
+
+	set_menu_auto_mark( dflt );
+	print_msg( FLG_NULL, MSG_MENU_AUTO_MARK_DONE_REMOVE );
+
+	return STR_MENU_CANCEL;
+}
+
+/***************************************************************
+* 1 ľ¤ٴ˥塼򤷤
+* menu_t **pp : ˥塼
+* menu_t **dflt : ˥塼Υǥե
+* return : ˥塼ΰư
+***************************************************************/
+
+char	*cb_menu_auto_mark_arrange_up( menu_t **pp, menu_t **dflt )
+{
+	char	*ret;
+
+	ret = menu_auto_mark_arrange_1( (long)((*pp)->arg), -1 );
+
+	set_menu_auto_mark( dflt );
+
+	return ret;
+}
+
+/***************************************************************
+* 1 Ĳ¤ٴ˥塼򤷤
+* menu_t **pp : ˥塼
+* menu_t **dflt : ˥塼Υǥե
+* return : ˥塼ΰư
+***************************************************************/
+
+char	*cb_menu_auto_mark_arrange_down( menu_t **pp, menu_t **dflt )
+{
+	char	*ret;
+
+	ret = menu_auto_mark_arrange_1( (long)((*pp)->arg), +1 );
+
+	set_menu_auto_mark( dflt );
+
+	return ret;
+}
+
 /***************************************************************
 * Ƭ¤ٴ˥塼򤷤
 * menu_t **pp : ˥塼
@@ -2369,6 +2738,29 @@ char	*cb_menu_auto_mark_arrange_bottom( menu_t **pp, menu_t **dflt )
 	return ret;
 }
 
+/***************************************************************
+* ˥塼¤ٴ (1 ʬ)
+* long n : ϰ
+* long d : Ƭ(-1)/(+1)
+* return : ˥塼ΰư
+***************************************************************/
+
+char	*menu_auto_mark_arrange_1( long n, long d )
+{
+	if( !arrange_auto_mark_1( n, d ) )
+		return STR_MENU_ERR;
+
+	if( d <= -1 ){
+		print_msg( FLG_NULL,
+				MSG_MENU_AUTO_MARK_DONE_ARRANGE_UP );
+	} else {
+		print_msg( FLG_NULL,
+				MSG_MENU_AUTO_MARK_DONE_ARRANGE_DOWN );
+	}
+
+	return "/auto mark";
+}
+
 /***************************************************************
 * ˥塼¤ٴ
 * long n : ϰ
@@ -2392,6 +2784,75 @@ char	*menu_auto_mark_arrange( long n, long d )
 	return "/auto mark";
 }
 
+/***************************************************************
+* ˥塼¤ٴ (1 ʬ)
+* long n : ϰ
+* long d : Ƭ(-1)/(+1)
+* return : ?
+***************************************************************/
+
+bool_t	arrange_auto_mark_1( long n, long d )
+{
+	long	i, k;
+	bool_t	flg;
+	auto_mark_t	am;
+	auto_mark_appoint_item_t	item[AUTO_MARK_APPOINT_ITEM_MAX_N];
+	const long	max_item = AUTO_MARK_APPOINT_ITEM_MAX_N;
+	char	buf[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+
+	if( d == 0 )
+		return FALSE;
+	if( (n + d) < 0 )
+		return FALSE;
+	if( (n + d) >= AUTO_MARK_MAX_N )
+		return FALSE;
+
+	/**/
+
+	flg = ls_flg_ena_auto_mark[n];
+	ls_flg_ena_auto_mark[n] = ls_flg_ena_auto_mark[n + d];
+	ls_flg_ena_auto_mark[n + d] = flg;
+
+	/**/
+
+	for( i = 0; i < LS_MBR_MAX_N; i++ ){
+		am = ls_auto_mark[i][n];
+		for( k = 0; k < max_item; k++ ){
+			item[k] = auto_mark_appoint_item[i][n][k];
+		}
+
+		ls_auto_mark[i][n] = ls_auto_mark[i][n + d];
+		for( k = 0; k < max_item; k++ ){
+			auto_mark_appoint_item[i][n][k]
+					= auto_mark_appoint_item
+					[i][n + d][k];
+		}
+
+		ls_auto_mark[i][n + d] = am;
+		for( k = 0; k < max_item; k++ ){
+			auto_mark_appoint_item[i][n + d][k] = item[k];
+		}
+	}
+
+	/**/
+
+	str_nz_cpy( buf, get_msg_ttl_auto_mark_code( n ),
+			MSG_TTL_AUTO_MARK_MAX_LEN );
+
+	str_nz_cpy( get_msg_ttl_auto_mark_code( n ),
+			get_msg_ttl_auto_mark_code( n + d ),
+			MSG_TTL_AUTO_MARK_MAX_LEN );
+
+	str_nz_cpy( get_msg_ttl_auto_mark_code( n + d ), buf,
+			MSG_TTL_AUTO_MARK_MAX_LEN );
+
+	/**/
+
+	auto_mark_cur_n = 0;
+
+	return TRUE;
+}
+
 /***************************************************************
 * ˥塼¤ٴ
 * long n : ϰ
@@ -2402,6 +2863,7 @@ char	*menu_auto_mark_arrange( long n, long d )
 bool_t	arrange_auto_mark( long n, long d )
 {
 	long	i, j, k;
+	bool_t	flg;
 	auto_mark_t	am;
 	auto_mark_appoint_item_t	item[AUTO_MARK_APPOINT_ITEM_MAX_N];
 	auto_mark_appoint_item_t	item_tmp;
@@ -2415,6 +2877,28 @@ bool_t	arrange_auto_mark( long n, long d )
 	else
 		return FALSE;
 
+	/**/
+
+	flg = ls_flg_ena_auto_mark[n];
+
+	if( d <= -1 ){
+		for( j = n - 1; j >= 0; j-- ){
+			ls_flg_ena_auto_mark[j + 1]
+					= ls_flg_ena_auto_mark[j];
+		}
+
+		ls_flg_ena_auto_mark[0] = flg;
+	} else {
+		for( j = n + 1; j < AUTO_MARK_MAX_N; j++ ){
+			ls_flg_ena_auto_mark[j - 1]
+					= ls_flg_ena_auto_mark[j];
+		}
+
+		ls_flg_ena_auto_mark[j - 1] = flg;
+	}
+
+	/**/
+
 	for( i = 0; i < LS_MBR_MAX_N; i++ ){
 		am = ls_auto_mark[i][n];
 
@@ -2497,6 +2981,58 @@ bool_t	arrange_auto_mark( long n, long d )
 	return TRUE;
 }
 
+/***************************************************************
+* ˥塼 1 ʬ¤ٴ(Сñ)
+* long ls_mbr_n : С
+* long d : Ƭ(-1)/(+1)
+* return : ?
+***************************************************************/
+
+bool_t	arrange_auto_mark_mbr_1( long n, long d )
+{
+	long	j, k;
+	auto_mark_t	am[AUTO_MARK_MAX_N];
+	auto_mark_appoint_item_t	item
+			[AUTO_MARK_MAX_N]
+			[AUTO_MARK_APPOINT_ITEM_MAX_N];
+	const long	max_item = AUTO_MARK_APPOINT_ITEM_MAX_N;
+
+	if( d == 0 )
+		return FALSE;
+	if( (n + d) < 0 )
+		return FALSE;
+	if( (n + d) >= AUTO_MARK_MAX_N )
+		return FALSE;
+
+	for( j = 0; j < AUTO_MARK_MAX_N; j++ ){
+		am[j] = ls_auto_mark[n][j];
+
+		for( k = 0; k < max_item; k++ ){
+			item[j][k] = auto_mark_appoint_item[n][j][k];
+		}
+	}
+
+	for( j = 0; j < AUTO_MARK_MAX_N; j++ ){
+		ls_auto_mark[n][j] = ls_auto_mark[n + d][j];
+
+		for( k = 0; k < max_item; k++ ){
+			auto_mark_appoint_item[n][j][k]
+					= auto_mark_appoint_item
+					[n + d][j][k];
+		}
+	}
+
+	for( j = 0; j < AUTO_MARK_MAX_N; j++ ){
+		ls_auto_mark[n + d][j] = am[j];
+
+		for( k = 0; k < max_item; k++ ){
+			auto_mark_appoint_item[n + d][j][k] = item[j][k];
+		}
+	}
+
+	return TRUE;
+}
+
 /***************************************************************
 * ˥塼¤ٴ(Сñ)
 * long ls_mbr_n : С
@@ -2513,7 +3049,7 @@ bool_t	arrange_auto_mark_mbr( long ls_mbr_n, long d )
 			[AUTO_MARK_APPOINT_ITEM_MAX_N];
 	auto_mark_appoint_item_t	item_tmp;
 	const long	max_item = AUTO_MARK_APPOINT_ITEM_MAX_N;
-	mbr_t	**ls_mbr = get_ls_mbr();
+	mbr_t	**ls_mbr;
 
 	if( d <= -1 )
 		d = -1;
@@ -2713,6 +3249,10 @@ char	*get_msg_menu_auto_mark_edit_cond( mbr_t *mbr )
 		return MSG_MENU_AUTO_MARK_COND_STAGGER;
 	case AUTO_MARK_COND_OWN:
 		return MSG_MENU_AUTO_MARK_COND_OWN;
+	case AUTO_MARK_COND_IDENTIFIED:
+		return MSG_MENU_AUTO_MARK_COND_IDENTIFIED;
+	case AUTO_MARK_COND_UN_IDENTIFIED:
+		return MSG_MENU_AUTO_MARK_COND_UN_IDENTIFIED;
 	case AUTO_MARK_COND_HP_MIN:
 		return MSG_MENU_AUTO_MARK_COND_HP_MIN;
 	case AUTO_MARK_COND_HP_MAX:
@@ -2755,7 +3295,7 @@ auto_mark_appoint_item_t	*get_auto_mark_appoint_item( mbr_t *mbr )
 
 /***************************************************************
 * ưޡΥȥʸ֤
-* n : ưޡֹ
+* long n : ưޡֹ
 * return : ưޡΥȥʸ
 ***************************************************************/
 
@@ -2766,7 +3306,7 @@ char	*get_msg_ttl_auto_mark_code( long n )
 
 /***************************************************************
 * ưޡΥȥ̾ʸ֤
-* n : ưޡֹ
+* long n : ưޡֹ
 * return : ưޡΥȥ̾ʸ
 ***************************************************************/
 
@@ -2787,7 +3327,7 @@ char	*get_msg_ttl_auto_mark_name( long n )
 
 /***************************************************************
 * ưޡΥȥξܺʸ֤
-* n : ưޡֹ
+* long n : ưޡֹ
 * return : ưޡΥȥξܺʸ
 ***************************************************************/
 
@@ -2818,7 +3358,7 @@ char	*get_msg_ttl_auto_mark_info( long n )
 
 /***************************************************************
 * ưޡΥȥΥҥʸ֤
-* n : ưޡֹ
+* long n : ưޡֹ
 * return : ưޡΥȥΥҥʸ
 ***************************************************************/
 
@@ -2858,6 +3398,38 @@ auto_mark_t	*get_ls_auto_mark( long ls_mbr_n )
 	return( ls_auto_mark[ls_mbr_n] );
 }
 
+/***************************************************************
+* ưޡΥǡͭĴ٤
+* long n : ưޡֹ
+* return : ͭ?
+***************************************************************/
+
+bool_t	chk_flg_ena_auto_mark( long n )
+{
+	if( n < 0 )
+		return FALSE;
+	if( n >= AUTO_MARK_MAX_N )
+		return FALSE;
+
+	return ls_flg_ena_auto_mark[n];
+}
+
+/***************************************************************
+* ưޡΥǡͭꤹ
+* long n : ưޡֹ
+* bool_t flg : ͭ?
+***************************************************************/
+
+void	set_flg_ena_auto_mark( long n, bool_t flg )
+{
+	if( n < 0 )
+		return;
+	if( n >= AUTO_MARK_MAX_N )
+		return;
+
+	ls_flg_ena_auto_mark[n] = flg;
+}
+
 /***************************************************************
 * ưޡΥƥΥǡ֤
 * long ls_mbr_n : СꥹȤֹ
