@@ -4,10 +4,13 @@
 extern "C" {
 #endif
 
+void	gui_begin( void );
+void	gui_end( void );
 bool_t	call_game_thread_create( void *(*func)( void * ) );
 bool_t	call_game_thread_exit(
 	void *(*func)( void * ), long code
 );
+void	call_ena_timer( void );
 void	call_gui_map_cont_exec_set( bool_t flagExec );
 void	call_gui_menu_draw( draw_menu_t *data );
 void	call_gui_menu_wipe( void );
@@ -20,7 +23,19 @@ void	call_gui_input_string_draw(
 	const char *ttl, const char *str, long len
 );
 void	call_gui_input_string_wipe( void );
-void	set_str_dir_sel_graph( char *dir );
+void	call_gui_words_draw( const char *str );
+void	call_gui_words_draw_width( const char *str, long w );
+void	call_gui_words_wipe( void );
+void	call_gui_replay_bgn( void );
+void	call_gui_replay_end( void );
+void	call_gui_replay_draw( void );
+void	call_gui_replay_wipe( void );
+void	call_gui_class_edit_draw( class_t *p );
+void	call_gui_class_edit_wipe( void );
+void	call_gui_chr_sheet_draw( mbr_t *org, mbr_t *mbr );
+void	call_gui_chr_sheet_redraw( mbr_t *org, mbr_t *mbr );
+void	call_gui_chr_sheet_wipe();
+void	call_set_str_dir_sel_graph( char *dir );
 bool_t	call_sel_conf_eval_block_begin( void );
 bool_t	call_sel_conf_eval_block_end( void );
 bool_t	call_sel_conf_eval_set_num( long token, long n );
@@ -28,6 +43,7 @@ bool_t	call_sel_conf_eval_set_str( long token, char *str );
 bool_t	call_sel_mbr_graph_begin( mbr_t *mbr );
 void	call_sel_mbr_graph_end( void );
 void	call_pcg_dun_reset( void );
+void	call_pcg_dun_reload_all_mbr( void );
 void	call_pcg_dun_draw_turn( bool_t flg_first );
 void	call_pcg_dun_redraw( bool_t flgForce );
 void	call_pcg_dun_draw(
@@ -35,6 +51,9 @@ void	call_pcg_dun_draw(
 	long map_w, long map_h,
 	bool_t flagForce
 );
+void	call_pcg_dun_draw_string(
+	long scrn_x, long scrn_y,
+	const char *s, ... );
 void	call_pcg_dun_scroll( long map_x, long map_y );
 long	call_pcg_dun_get_chr_draw_left( chr_t *chr, bool_t flagPre );
 long	call_pcg_dun_get_chr_draw_right( chr_t *chr, bool_t flagPre );
@@ -43,6 +62,8 @@ long	call_pcg_dun_get_chr_draw_bottom( chr_t *chr, bool_t flagPre );
 bool_t	call_pcg_dun_clip_win( long mapX, long mapY );
 bool_t	call_pcg_dun_clip_win_x( long mapX );
 bool_t	call_pcg_dun_clip_win_y( long mapY );
+void	call_game_music_play_scene( void );
+void	call_game_music_play( long kind, long idx );
 void	call_gui_stat_redraw( void );
 void	call_gui_stat_draw( long n );
 void	call_win_pos_set(
