@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: call.cpp,v 1.70 2008/05/10 10:04:26 bowkenken Exp $
+* $Id: call.cpp,v 1.87 2008/09/19 21:15:24 bowkenken Exp $
 ***************************************************************/
 
 #define	CALL_CPP
@@ -35,6 +35,43 @@
 extern WSCwindow *StatWin;
 #endif
 
+/***************************************************************
+* GUI åɤΥå
+***************************************************************/
+
+void	gui_begin( void )
+{
+#ifdef D_WS
+	WSGIappDev()->lock();
+#endif // D_WS
+
+#ifdef D_GTK
+	gdk_threads_enter();
+#endif // D_GTK
+
+#ifdef D_MFC
+#endif // D_MFC
+}
+
+/***************************************************************
+* GUI åɤΥå
+***************************************************************/
+
+void	gui_end( void )
+{
+#ifdef D_WS
+	WSGIappDev()->unlock();
+#endif // D_WS
+
+#ifdef D_GTK
+	gdk_flush();
+	gdk_threads_leave();
+#endif // D_GTK
+
+#ifdef D_MFC
+#endif // D_MFC
+}
+
 /***************************************************************
 * ᥤ󡦥롼פΥåɤڤ
 * void *(*func)( void * ) : 롦Хåؿ
@@ -74,6 +111,17 @@ bool_t	call_game_thread_exit(
 	return TRUE;
 }
 
+/***************************************************************
+* ޡͭˤ
+***************************************************************/
+
+void	call_ena_timer( void )
+{
+#ifdef D_GTK
+	ena_timer();
+#endif // D_GTK
+}
+
 /***************************************************************
 * ޥåסɥϢ³¹ԥܥΥå
 * bool_t flagExec : 
@@ -81,20 +129,13 @@ bool_t	call_game_thread_exit(
 
 void	call_gui_map_cont_exec_set( bool_t flagExec )
 {
-#ifdef D_WS
-	if( !g_flg_init )
-		return;
-	if( !g_flg_gui )
-		return;
-#endif // D_WS
-
 #ifdef D_GTK
 	if( !g_flg_init )
 		return;
 	if( !g_flg_gui )
 		return;
 
-	gdk_threads_enter();
+	gui_begin();
 
 	if( flagExec ){
 		set_label_text_button( GTK_BUTTON( gMapButtonContExec ),
@@ -104,8 +145,7 @@ void	call_gui_map_cont_exec_set( bool_t flagExec )
 				MSG_GUI_MAP_CONT_EXEC_OFF, 0.5, 0.5 );
 	}
 
-	gdk_flush();
-	gdk_threads_leave();
+	gui_end();
 #endif // D_GTK
 }
 
@@ -116,41 +156,18 @@ void	call_gui_map_cont_exec_set( bool_t flagExec )
 
 void	call_gui_menu_draw( draw_menu_t *data )
 {
-#ifdef D_WS
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( !g_flg_init )
 		return;
 	if( !g_flg_gui )
 		return;
 
-	WSGIappDev()->lock();
+	gui_begin();
 
 	gGuiMenu.draw( data );
 
-	WSGIappDev()->unlock();
-#endif // D_WS
-
-#ifdef D_GTK
-	if( !g_flg_init )
-		return;
-	if( !g_flg_gui )
-		return;
-
-	gdk_threads_enter();
-
-	gGuiMenu.draw( data );
-
-	gdk_flush();
-	gdk_threads_leave();
-#endif // D_GTK
-
-#ifdef D_MFC
-	if( !g_flg_init )
-		return;
-	if( !g_flg_gui )
-		return;
-
-	gGuiMenu.draw( data );
-#endif // D_MFC
+	gui_end();
+#endif
 }
 
 /***************************************************************
@@ -159,41 +176,18 @@ void	call_gui_menu_draw( draw_menu_t *data )
 
 void	call_gui_menu_wipe( void )
 {
-#ifdef D_WS
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( !g_flg_init )
 		return;
 	if( !g_flg_gui )
 		return;
 
-	WSGIappDev()->lock();
+	gui_begin();
 
 	gGuiMenu.wipe();
 
-	WSGIappDev()->unlock();
-#endif // D_WS
-
-#ifdef D_GTK
-	if( !g_flg_init )
-		return;
-	if( !g_flg_gui )
-		return;
-
-	gdk_threads_enter();
-
-	gGuiMenu.wipe();
-
-	gdk_flush();
-	gdk_threads_leave();
-#endif // D_GTK
-
-#ifdef D_MFC
-	if( !g_flg_init )
-		return;
-	if( !g_flg_gui )
-		return;
-
-	gGuiMenu.wipe();
-#endif // D_MFC
+	gui_end();
+#endif
 }
 
 /***************************************************************
@@ -203,32 +197,20 @@ void	call_gui_menu_wipe( void )
 
 void	call_set_mouse_dflt_menu( long sel_n )
 {
-#ifdef D_WS
+#ifndef D_MFC
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( !g_flg_init )
 		return;
 	if( !g_flg_gui )
 		return;
 
-	WSGIappDev()->lock();
+	gui_begin();
 
 	gGuiMenu.setMouseDfltMenu( sel_n );
 
-	WSGIappDev()->unlock();
-#endif // D_WS
-
-#ifdef D_GTK
-	if( !g_flg_init )
-		return;
-	if( !g_flg_gui )
-		return;
-
-	gdk_threads_enter();
-
-	gGuiMenu.setMouseDfltMenu( sel_n );
-
-	gdk_flush();
-	gdk_threads_leave();
-#endif // D_GTK
+	gui_end();
+#endif
+#endif // ! D_MFC
 }
 
 /***************************************************************
@@ -237,31 +219,18 @@ void	call_set_mouse_dflt_menu( long sel_n )
 
 void	call_gui_message_set_flag_more( bool_t flag )
 {
-#ifdef D_WS
-#endif // D_WS
-
-#ifdef D_GTK
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( !g_flg_init )
 		return;
 	if( !g_flg_gui )
 		return;
 
-	gdk_threads_enter();
-
-	gGuiMessage.setFlagMore( flag );
-
-	gdk_flush();
-	gdk_threads_leave();
-#endif // D_GTK
-
-#ifdef D_MFC
-	if( !g_flg_init )
-		return;
-	if( !g_flg_gui )
-		return;
+	gui_begin();
 
 	gGuiMessage.setFlagMore( (bool)(flag != FALSE) );
-#endif // D_MFC
+
+	gui_end();
+#endif
 }
 
 /***************************************************************
@@ -270,43 +239,19 @@ void	call_gui_message_set_flag_more( bool_t flag )
 
 void	call_gui_message_draw( void )
 {
-#ifdef D_WS
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( !g_flg_init )
 		return;
 	if( !g_flg_gui )
 		return;
 
-	WSGIappDev()->lock();
-
-//@@@	gGuiMessage.draw();
-
-	WSGIappDev()->unlock();
-#endif // D_WS
-
-#ifdef D_GTK
-	if( !g_flg_init )
-		return;
-	if( !g_flg_gui )
-		return;
-
-	gdk_threads_enter();
+	gui_begin();
 
 	gGuiMessage.draw( false );
 	gGuiMessage.drawScrollBar();
 
-	gdk_flush();
-	gdk_threads_leave();
-#endif // D_GTK
-
-#ifdef D_MFC
-	if( !g_flg_init )
-		return;
-	if( !g_flg_gui )
-		return;
-
-	gGuiMessage.draw( false );
-	gGuiMessage.drawScrollBar();
-#endif // D_MFC
+	gui_end();
+#endif
 }
 
 /***************************************************************
@@ -315,41 +260,18 @@ void	call_gui_message_draw( void )
 
 void	call_gui_num_draw( long *n, long min, long max, long figure )
 {
-#ifdef D_WS
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( !g_flg_init )
 		return;
 	if( !g_flg_gui )
 		return;
 
-	WSGIappDev()->lock();
+	gui_begin();
 
 	gGuiNum.draw( n, min, max, figure );
 
-	WSGIappDev()->unlock();
-#endif // D_WS
-
-#ifdef D_GTK
-	if( !g_flg_init )
-		return;
-	if( !g_flg_gui )
-		return;
-
-	gdk_threads_enter();
-
-	gGuiNum.draw( n, min, max, figure );
-
-	gdk_flush();
-	gdk_threads_leave();
-#endif // D_GTK
-
-#ifdef D_MFC
-	if( !g_flg_init )
-		return;
-	if( !g_flg_gui )
-		return;
-
-	gGuiNum.draw( n, min, max, figure );
-#endif // D_MFC
+	gui_end();
+#endif
 }
 
 /***************************************************************
@@ -358,41 +280,18 @@ void	call_gui_num_draw( long *n, long min, long max, long figure )
 
 void	call_gui_num_wipe( void )
 {
-#ifdef D_WS
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( !g_flg_init )
 		return;
 	if( !g_flg_gui )
 		return;
 
-	WSGIappDev()->lock();
+	gui_begin();
 
 	gGuiNum.wipe();
 
-	WSGIappDev()->unlock();
-#endif // D_WS
-
-#ifdef D_GTK
-	if( !g_flg_init )
-		return;
-	if( !g_flg_gui )
-		return;
-
-	gdk_threads_enter();
-
-	gGuiNum.wipe();
-
-	gdk_flush();
-	gdk_threads_leave();
-#endif // D_GTK
-
-#ifdef D_MFC
-	if( !g_flg_init )
-		return;
-	if( !g_flg_gui )
-		return;
-
-	gGuiNum.wipe();
-#endif // D_MFC
+	gui_end();
+#endif
 }
 
 /***************************************************************
@@ -403,44 +302,18 @@ void	call_gui_input_string_draw(
 	const char *ttl, const char *str, long len
 )
 {
-#ifdef D_WS
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( !g_flg_init )
 		return;
 	if( !g_flg_gui )
 		return;
 
-	WSGIappDev()->lock();
+	gui_begin();
 
 	gGuiInpStr.draw( ttl, str, len );
 
-	WSGIappDev()->unlock();
-#endif // D_WS
-
-#ifdef D_GTK
-	if( !g_flg_init )
-		return;
-	if( !g_flg_gui )
-		return;
-
-	gdk_threads_enter();
-
-#if 0
-//@@@
-	gGuiInpStr.draw( ttl, str, len );
+	gui_end();
 #endif
-
-	gdk_flush();
-	gdk_threads_leave();
-#endif // D_GTK
-
-#ifdef D_MFC
-	if( !g_flg_init )
-		return;
-	if( !g_flg_gui )
-		return;
-
-	gGuiInpStr.draw( ttl, str, len );
-#endif // D_MFC
 }
 
 /***************************************************************
@@ -449,44 +322,261 @@ void	call_gui_input_string_draw(
 
 void	call_gui_input_string_wipe( void )
 {
-#ifdef D_WS
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( !g_flg_init )
 		return;
 	if( !g_flg_gui )
 		return;
 
-	WSGIappDev()->lock();
+	gui_begin();
 
 	gGuiInpStr.wipe();
 
-	WSGIappDev()->unlock();
-#endif // D_WS
-
-#ifdef D_GTK
-	if( !g_flg_init )
-		return;
-	if( !g_flg_gui )
-		return;
-
-	gdk_threads_enter();
-
-#if 0
-//@@@
-	gGuiInpStr.wipe();
+	gui_end();
 #endif
+}
 
-	gdk_flush();
-	gdk_threads_leave();
-#endif // D_GTK
+/***************************************************************
+* 쥦ɥ
+* const char *str : 
+***************************************************************/
 
-#ifdef D_MFC
+void	call_gui_words_draw( const char *str )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( !g_flg_init )
 		return;
 	if( !g_flg_gui )
 		return;
 
-	gGuiInpStr.wipe();
-#endif // D_MFC
+	gui_begin();
+
+	gGuiWords.draw( str );
+
+	gui_end();
+#endif
+}
+
+/***************************************************************
+* 쥦ɥ (ɽ)
+* const char *str : 
+* long w : ɽ
+***************************************************************/
+
+void	call_gui_words_draw_width( const char *str, long w )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gui_begin();
+
+	gGuiWords.draw( str, w );
+
+	gui_end();
+#endif
+}
+
+/***************************************************************
+* 쥦ɥĤ
+***************************************************************/
+
+void	call_gui_words_wipe( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gui_begin();
+
+	gGuiWords.wipe();
+
+	gui_end();
+#endif
+}
+
+/***************************************************************
+* ץ쥤ɥ򳫻
+***************************************************************/
+
+void	call_gui_replay_bgn( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gui_begin();
+
+	gGuiReplay.bgn();
+
+	gui_end();
+#endif
+}
+
+/***************************************************************
+* ץ쥤ɥλ
+***************************************************************/
+
+void	call_gui_replay_end( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gui_begin();
+
+	gGuiReplay.end();
+
+	gui_end();
+#endif
+}
+
+/***************************************************************
+* ץ쥤ɥ
+***************************************************************/
+
+void	call_gui_replay_draw( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gui_begin();
+
+	gGuiReplay.draw();
+
+	gui_end();
+#endif
+}
+
+/***************************************************************
+* ץ쥤ɥĤ
+***************************************************************/
+
+void	call_gui_replay_wipe( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gui_begin();
+
+	gGuiReplay.wipe();
+
+	gui_end();
+#endif
+}
+
+/***************************************************************
+* 饹ǥɥ
+***************************************************************/
+
+void	call_gui_class_edit_draw( class_t *p )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gui_begin();
+
+	gGuiClassEdit.draw( p );
+
+	gui_end();
+#endif
+}
+
+/***************************************************************
+* 饹ǥɥĤ
+***************************************************************/
+
+void	call_gui_class_edit_wipe( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gui_begin();
+
+	gGuiClassEdit.wipe();
+
+	gui_end();
+#endif
+}
+
+/***************************************************************
+* 饯ȡɥ
+***************************************************************/
+
+void	call_gui_chr_sheet_draw( mbr_t *org, mbr_t *mbr )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gui_begin();
+
+	gGuiChrSheet.draw( org, mbr );
+
+	gui_end();
+#endif
+}
+
+/***************************************************************
+* 饯ȡɥ
+***************************************************************/
+
+void	call_gui_chr_sheet_redraw( mbr_t *org, mbr_t *mbr )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gui_begin();
+
+	gGuiChrSheet.redraw();
+
+	gui_end();
+#endif
+}
+
+/***************************************************************
+* 饯ȡɥĤ
+***************************************************************/
+
+void	call_gui_chr_sheet_wipe()
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gui_begin();
+
+	gGuiChrSheet.wipe();
+
+	gui_end();
+#endif
 }
 
 /***************************************************************
@@ -494,7 +584,7 @@ void	call_gui_input_string_wipe( void )
 * char *dir : եåǥ쥯ȥ
 ***************************************************************/
 
-void	set_str_dir_sel_graph( char *dir )
+void	call_set_str_dir_sel_graph( char *dir )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	FileList::setStrDirSelGraph( dir );
@@ -580,48 +670,26 @@ bool_t	call_sel_conf_eval_set_str( long token, char *str )
 
 bool_t	call_sel_mbr_graph_begin( mbr_t *mbr )
 {
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	bool_t flgWait = FALSE;
 
-#ifdef D_WS
 	if( !g_flg_gui )
 		return FALSE;
 
-	WSGIappDev()->lock();
+	gui_begin();
 
 	gSelMbrGraph = new SelMbrGraph;
 	flgWait = gSelMbrGraph->exec( mbr );
 
-	WSGIappDev()->unlock();
-#endif // D_WS
-
-#ifdef D_GTK
-	if( !g_flg_gui )
-		return FALSE;
-
-	gdk_threads_enter();
-
-	gSelMbrGraph = new SelMbrGraph;
-	flgWait = gSelMbrGraph->exec( mbr );
-
-	gdk_flush();
-	gdk_threads_leave();
-#endif // D_GTK
-
-#ifdef D_MFC
-	if( !g_flg_gui )
-		return FALSE;
-
-	TRY {
-		gSelMbrGraph = new SelMbrGraph;
-		flgWait = gSelMbrGraph->exec( mbr );
-	} CATCH( CException, e ){
-	} END_CATCH
-#endif // D_MFC
+	gui_end();
 
 	if( flgWait )
 		return TRUE;
 	else
 		return FALSE;
+#endif
+
+	return FALSE;
 }
 
 /***************************************************************
@@ -630,38 +698,16 @@ bool_t	call_sel_mbr_graph_begin( mbr_t *mbr )
 
 void	call_sel_mbr_graph_end( void )
 {
-#ifdef D_WS
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( !g_flg_gui )
 		return;
 
-	WSGIappDev()->lock();
+	gui_begin();
 
 	delete gSelMbrGraph;
 
-	WSGIappDev()->unlock();
-#endif // D_WS
-
-#ifdef D_GTK
-	if( !g_flg_gui )
-		return;
-
-	gdk_threads_enter();
-
-	delete gSelMbrGraph;
-
-	gdk_flush();
-	gdk_threads_leave();
-#endif // D_GTK
-
-#ifdef D_MFC
-	if( !g_flg_gui )
-		return;
-
-	TRY {
-		delete gSelMbrGraph;
-	} CATCH( CException, e ){
-	} END_CATCH
-#endif // D_MFC
+	gui_end();
+#endif
 }
 
 /***************************************************************
@@ -670,38 +716,34 @@ void	call_sel_mbr_graph_end( void )
 
 void	call_pcg_dun_reset( void )
 {
-#ifdef D_WS
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( !g_flg_gui )
 		return;
 
-	WSGIappDev()->lock();
+	gui_begin();
 
 	gPcgDun.reset();
 
-	WSGIappDev()->unlock();
-#endif // D_WS
+	gui_end();
+#endif
+}
 
-#ifdef D_GTK
+/***************************************************************
+* СΥեåѥΥꥻå
+***************************************************************/
+
+void	call_pcg_dun_reload_all_mbr( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( !g_flg_gui )
 		return;
 
-	gdk_threads_enter();
+	gui_begin();
 
-	gPcgDun.reset();
+	gPcgDun.reloadAllMbr();
 
-	gdk_flush();
-	gdk_threads_leave();
-#endif // D_GTK
-
-#ifdef D_MFC
-	if( !g_flg_gui )
-		return;
-
-	TRY {
-		gPcgDun.reset();
-	} CATCH( CException, e ){
-	} END_CATCH
-#endif // D_MFC
+	gui_end();
+#endif
 }
 
 /***************************************************************
@@ -710,7 +752,7 @@ void	call_pcg_dun_reset( void )
 
 void	call_pcg_dun_draw_turn( bool_t flg_first )
 {
-#ifdef D_WS
+#if	defined( D_WS ) || defined( D_GTK )
 	if( !g_flg_init )
 		return;
 	if( !g_flg_gui )
@@ -719,29 +761,12 @@ void	call_pcg_dun_draw_turn( bool_t flg_first )
 	if( flg_first )
 		gPcgDun.setFlgUpdateRequest( true );
 
-	WSGIappDev()->lock();
+	gui_begin();
 
 	gPcgDun.drawTurn();
 
-	WSGIappDev()->unlock();
-#endif // D_WS
-
-#ifdef D_GTK
-	if( !g_flg_init )
-		return;
-	if( !g_flg_gui )
-		return;
-
-	if( flg_first )
-		gPcgDun.setFlgUpdateRequest( true );
-
-	gdk_threads_enter();
-
-	gPcgDun.drawTurn();
-
-	gdk_flush();
-	gdk_threads_leave();
-#endif // D_GTK
+	gui_end();
+#endif
 
 #ifdef D_MFC
 	if( !g_flg_init )
@@ -774,32 +799,18 @@ void	call_pcg_dun_redraw( bool_t flgForce )
 	else
 		bFlagForce = false;
 
-#ifdef D_WS
+#if	defined( D_WS ) || defined( D_GTK )
 	if( !g_flg_init )
 		return;
 	if( !g_flg_gui )
 		return;
 
-	WSGIappDev()->lock();
+	gui_begin();
 
 	gPcgDun.redraw( bFlagForce );
 
-	WSGIappDev()->unlock();
-#endif // D_WS
-
-#ifdef D_GTK
-	if( !g_flg_init )
-		return;
-	if( !g_flg_gui )
-		return;
-
-	gdk_threads_enter();
-
-	gPcgDun.redraw( bFlagForce );
-
-	gdk_flush();
-	gdk_threads_leave();
-#endif // D_GTK
+	gui_end();
+#endif
 
 #ifdef D_MFC
 	if( !g_flg_init )
@@ -838,32 +849,18 @@ void	call_pcg_dun_draw(
 	else
 		bFlagForce = false;
 
-#ifdef D_WS
+#if	defined( D_WS ) || defined( D_GTK )
 	if( !g_flg_init )
 		return;
 	if( !g_flg_gui )
 		return;
 
-	WSGIappDev()->lock();
+	gui_begin();
 
 	gPcgDun.draw( map_x, map_y, map_w, map_h, bFlagForce );
 
-	WSGIappDev()->unlock();
-#endif // D_WS
-
-#ifdef D_GTK
-	if( !g_flg_init )
-		return;
-	if( !g_flg_gui )
-		return;
-
-	gdk_threads_enter();
-
-	gPcgDun.draw( map_x, map_y, map_w, map_h, bFlagForce );
-
-	gdk_flush();
-	gdk_threads_leave();
-#endif // D_GTK
+	gui_end();
+#endif
 
 #ifdef D_MFC
 	if( !g_flg_init )
@@ -881,6 +878,40 @@ void	call_pcg_dun_draw(
 #endif // D_MFC
 }
 
+/***************************************************************
+* ƥȡ⡼ɤλޥåפʸ
+* long scrn_x : X ɸ
+* long scrn_y : Y ɸ
+* const char *s : եޥåʸ
+* ... : եޥåȤΰ
+* return : 顼̵ä
+***************************************************************/
+
+void	call_pcg_dun_draw_string(
+	long scrn_x, long scrn_y,
+	const char *s, ... )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	va_list	argptr;
+	static char	buf[SCREEN_WIDTH * 2 + 1];
+
+	va_start( argptr, s );
+	vsn_printf( buf, SCREEN_WIDTH * 2, s, argptr );
+	va_end( argptr );
+
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gui_begin();
+
+	gPcgDun.drawString( scrn_x, scrn_y, MSG_S, buf );
+
+	gui_end();
+#endif
+}
+
 /***************************************************************
 * ޥåפΥ
 * long map_x : ޥåפ X ɸ
@@ -889,44 +920,18 @@ void	call_pcg_dun_draw(
 
 void	call_pcg_dun_scroll( long map_x, long map_y )
 {
-#ifdef D_WS
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( !g_flg_init )
 		return;
 	if( !g_flg_gui )
 		return;
 
-	WSGIappDev()->lock();
+	gui_begin();
 
 	gPcgDun.scrollTile( map_x, map_y );
 
-	WSGIappDev()->unlock();
-#endif // D_WS
-
-#ifdef D_GTK
-	if( !g_flg_init )
-		return;
-	if( !g_flg_gui )
-		return;
-
-	gdk_threads_enter();
-
-	gPcgDun.scrollTile( map_x, map_y );
-
-	gdk_flush();
-	gdk_threads_leave();
-#endif // D_GTK
-
-#ifdef D_MFC
-	if( !g_flg_init )
-		return;
-	if( !g_flg_gui )
-		return;
-
-	TRY {
-		gPcgDun.scrollTile( map_x, map_y );
-	} CATCH( CException, e ){
-	} END_CATCH
-#endif // D_MFC
+	gui_end();
+#endif
 }
 
 /***************************************************************
@@ -937,38 +942,27 @@ void	call_pcg_dun_scroll( long map_x, long map_y )
 
 long	call_pcg_dun_get_chr_draw_left( chr_t *chr, bool_t flagPre )
 {
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	bool bFlagPre;
 	if( flagPre )
 		bFlagPre = true;
 	else
 		bFlagPre = false;
 
-#ifdef D_WS
+	if( g_flg_text_mode ){
+		if( flagPre )
+			return get_chr_left( chr->pre_draw_x, chr->dx );
+		else
+			return get_chr_left( chr->x, chr->dx );
+	}
+
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
 	long n = gPcgDun.getChrDrawLeft( chr, pPcg, bFlagPre );
 	n = n / gPcgDun.getTileSizeX();
 
 	return n;
-#endif // D_WS
-
-#ifdef D_GTK
-	Pcg *pPcg = gPcgDun.getChrPcg( chr );
-
-	long n = gPcgDun.getChrDrawLeft( chr, pPcg, bFlagPre );
-	n = n / gPcgDun.getTileSizeX();
-
-	return n;
-#endif // D_GTK
-
-#ifdef D_MFC
-	Pcg *pPcg = gPcgDun.getChrPcg( chr );
-
-	long n = gPcgDun.getChrDrawLeft( chr, pPcg, bFlagPre );
-	n = n / gPcgDun.getTileSizeX();
-
-	return n;
-#endif // D_MFC
+#endif
 
 	if( flagPre )
 		return get_chr_left( chr->pre_draw_x, chr->dx );
@@ -984,38 +978,27 @@ long	call_pcg_dun_get_chr_draw_left( chr_t *chr, bool_t flagPre )
 
 long	call_pcg_dun_get_chr_draw_right( chr_t *chr, bool_t flagPre )
 {
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	bool bFlagPre;
 	if( flagPre )
 		bFlagPre = true;
 	else
 		bFlagPre = false;
 
-#ifdef D_WS
+	if( g_flg_text_mode ){
+		if( flagPre )
+			return get_chr_right( chr->pre_draw_x, chr->dx );
+		else
+			return get_chr_right( chr->x, chr->dx );
+	}
+
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
 	long n = gPcgDun.getChrDrawRight( chr, pPcg, bFlagPre );
 	n = (n + gPcgDun.getTileSizeX() - 1) / gPcgDun.getTileSizeX();
 
 	return n;
-#endif // D_WS
-
-#ifdef D_GTK
-	Pcg *pPcg = gPcgDun.getChrPcg( chr );
-
-	long n = gPcgDun.getChrDrawRight( chr, pPcg, bFlagPre );
-	n = (n + gPcgDun.getTileSizeX() - 1) / gPcgDun.getTileSizeX();
-
-	return n;
-#endif // D_GTK
-
-#ifdef D_MFC
-	Pcg *pPcg = gPcgDun.getChrPcg( chr );
-
-	long n = gPcgDun.getChrDrawRight( chr, pPcg, bFlagPre );
-	n = (n + gPcgDun.getTileSizeX() - 1) / gPcgDun.getTileSizeX();
-
-	return n;
-#endif // D_MFC
+#endif
 
 	if( flagPre )
 		return get_chr_right( chr->pre_draw_x, chr->dx );
@@ -1031,38 +1014,27 @@ long	call_pcg_dun_get_chr_draw_right( chr_t *chr, bool_t flagPre )
 
 long	call_pcg_dun_get_chr_draw_top( chr_t *chr, bool_t flagPre )
 {
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	bool bFlagPre;
 	if( flagPre )
 		bFlagPre = true;
 	else
 		bFlagPre = false;
 
-#ifdef D_WS
+	if( g_flg_text_mode ){
+		if( flagPre )
+			return get_chr_top( chr->pre_draw_y, chr->dy );
+		else
+			return get_chr_top( chr->y, chr->dy );
+	}
+
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
 	long n = gPcgDun.getChrDrawTop( chr, pPcg, bFlagPre );
 	n = n / gPcgDun.getTileSizeY();
 
 	return n;
-#endif // D_WS
-
-#ifdef D_GTK
-	Pcg *pPcg = gPcgDun.getChrPcg( chr );
-
-	long n = gPcgDun.getChrDrawTop( chr, pPcg, bFlagPre );
-	n = n / gPcgDun.getTileSizeY();
-
-	return n;
-#endif // D_GTK
-
-#ifdef D_MFC
-	Pcg *pPcg = gPcgDun.getChrPcg( chr );
-
-	long n = gPcgDun.getChrDrawTop( chr, pPcg, bFlagPre );
-	n = n / gPcgDun.getTileSizeY();
-
-	return n;
-#endif // D_MFC
+#endif
 
 	if( flagPre )
 		return get_chr_top( chr->pre_draw_y, chr->dy );
@@ -1078,38 +1050,27 @@ long	call_pcg_dun_get_chr_draw_top( chr_t *chr, bool_t flagPre )
 
 long	call_pcg_dun_get_chr_draw_bottom( chr_t *chr, bool_t flagPre )
 {
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	bool bFlagPre;
 	if( flagPre )
 		bFlagPre = true;
 	else
 		bFlagPre = false;
 
-#ifdef D_WS
+	if( g_flg_text_mode ){
+		if( flagPre )
+			return get_chr_bottom( chr->pre_draw_y, chr->dy );
+		else
+			return get_chr_bottom( chr->y, chr->dy );
+	}
+
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
 	long n = gPcgDun.getChrDrawBottom( chr, pPcg, bFlagPre );
 	n = (n + gPcgDun.getTileSizeY() - 1) / gPcgDun.getTileSizeY();
 
 	return n;
-#endif // D_WS
-
-#ifdef D_GTK
-	Pcg *pPcg = gPcgDun.getChrPcg( chr );
-
-	long n = gPcgDun.getChrDrawBottom( chr, pPcg, bFlagPre );
-	n = (n + gPcgDun.getTileSizeY() - 1) / gPcgDun.getTileSizeY();
-
-	return n;
-#endif // D_GTK
-
-#ifdef D_MFC
-	Pcg *pPcg = gPcgDun.getChrPcg( chr );
-
-	long n = gPcgDun.getChrDrawBottom( chr, pPcg, bFlagPre );
-	n = (n + gPcgDun.getTileSizeY() - 1) / gPcgDun.getTileSizeY();
-
-	return n;
-#endif // D_MFC
+#endif
 
 	if( flagPre )
 		return get_chr_bottom( chr->pre_draw_y, chr->dy );
@@ -1126,13 +1087,9 @@ long	call_pcg_dun_get_chr_draw_bottom( chr_t *chr, bool_t flagPre )
 
 bool_t	call_pcg_dun_clip_win( long mapX, long mapY )
 {
-#ifdef D_GTK
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	return gPcgDun.clipWin( mapX, mapY );
-#endif // D_GTK
-
-#ifdef D_MFC
-	return gPcgDun.clipWin( mapX, mapY );
-#endif // D_MFC
+#endif
 
 	return true;
 }
@@ -1145,13 +1102,9 @@ bool_t	call_pcg_dun_clip_win( long mapX, long mapY )
 
 bool_t	call_pcg_dun_clip_win_x( long mapX )
 {
-#ifdef D_GTK
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	return gPcgDun.clipWinX( mapX );
-#endif // D_GTK
-
-#ifdef D_MFC
-	return gPcgDun.clipWinX( mapX );
-#endif // D_MFC
+#endif
 
 	return true;
 }
@@ -1164,58 +1117,55 @@ bool_t	call_pcg_dun_clip_win_x( long mapX )
 
 bool_t	call_pcg_dun_clip_win_y( long mapY )
 {
-#ifdef D_GTK
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	return gPcgDun.clipWinY( mapY );
-#endif // D_GTK
-
-#ifdef D_MFC
-	return gPcgDun.clipWinY( mapY );
-#endif // D_MFC
+#endif
 
 	return true;
 }
 
+/***************************************************************
+* ˹礻 BGM κ
+***************************************************************/
+
+void	call_game_music_play_scene( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	gMusic.playScene();
+#endif
+}
+
+/***************************************************************
+* BGM κ
+* music_kind_t kind : BGM μ
+* long idx : BGM ꥹȤΥǥå
+***************************************************************/
+
+void	call_game_music_play( long kind, long idx )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	gMusic.play( (music_kind_t)kind, idx );
+#endif
+}
+
 /***************************************************************
 * ơɥ
 ***************************************************************/
 
 void	call_gui_stat_redraw( void )
 {
-#ifdef D_WS
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( !g_flg_init )
 		return;
 	if( !g_flg_gui )
 		return;
 
-	WSGIappDev()->lock();
-
-	StatWin->redraw();
-
-	WSGIappDev()->unlock();
-#endif // D_WS
-
-#ifdef D_GTK
-	if( !g_flg_init )
-		return;
-	if( !g_flg_gui )
-		return;
-
-	gdk_threads_enter();
+	gui_begin();
 
 	gGuiStat.redraw();
 
-	gdk_flush();
-	gdk_threads_leave();
-#endif // D_GTK
-
-#ifdef D_MFC
-	if( !g_flg_init )
-		return;
-	if( !g_flg_gui )
-		return;
-
-	gGuiStat.redraw();
-#endif // D_MFC
+	gui_end();
+#endif
 }
 
 /***************************************************************
@@ -1225,41 +1175,18 @@ void	call_gui_stat_redraw( void )
 
 void	call_gui_stat_draw( long n )
 {
-#ifdef D_WS
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( !g_flg_init )
 		return;
 	if( !g_flg_gui )
 		return;
 
-	WSGIappDev()->lock();
-
-	StatWin->draw( n );
-
-	WSGIappDev()->unlock();
-#endif // D_WS
-
-#ifdef D_GTK
-	if( !g_flg_init )
-		return;
-	if( !g_flg_gui )
-		return;
-
-	gdk_threads_enter();
+	gui_begin();
 
 	gGuiStat.draw( n );
 
-	gdk_flush();
-	gdk_threads_leave();
-#endif // D_GTK
-
-#ifdef D_MFC
-	if( !g_flg_init )
-		return;
-	if( !g_flg_gui )
-		return;
-
-	gGuiStat.draw( n );
-#endif // D_MFC
+	gui_end();
+#endif
 }
 
 /***************************************************************
@@ -1277,40 +1204,21 @@ void	call_win_pos_set(
 	long *pw, long *ph
 )
 {
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( k < WIN_KIND_NULL )
 		return;
 	if( k >= WIN_KIND_MAX_N )
 		return;
 
-#ifdef D_WS
 	if( !g_flg_gui )
 		return;
 
-	WSGIappDev()->lock();
+	gui_begin();
 
-	gWinPos[k].set( k, px, py, pw, ph, false );
+	gWinPos[k].set( k, px, py, pw, ph );
 
-	WSGIappDev()->unlock();
-#endif // D_WS
-
-#ifdef D_GTK
-	if( !g_flg_gui )
-		return;
-
-	gdk_threads_enter();
-
-	gWinPos[k].set( k, px, py, pw, ph, false );
-
-	gdk_flush();
-	gdk_threads_leave();
-#endif // D_GTK
-
-#ifdef D_MFC
-	if( !g_flg_gui )
-		return;
-
-	gWinPos[k].set( k, px, py, pw, ph, false );
-#endif // D_MFC
+	gui_end();
+#endif
 }
 
 /***************************************************************
@@ -1329,47 +1237,25 @@ bool_t	call_win_pos_get(
 	long *pw, long *ph
 )
 {
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( k < WIN_KIND_NULL )
 		return FALSE;
 	if( k >= WIN_KIND_MAX_N )
 		return FALSE;
 
-	bool_t result = FALSE;
-
-#ifdef D_WS
 	if( !g_flg_gui )
 		return TRUE;
 
-	WSGIappDev()->lock();
+	gui_begin();
 
-	if( gWinPos[k].get( k, px, py, pw, ph, false ) )
-		result = TRUE;
+	gWinPos[k].get( k, px, py, pw, ph );
 
-	WSGIappDev()->unlock();
-#endif // D_WS
+	gui_end();
 
-#ifdef D_GTK
-	if( !g_flg_gui )
-		return TRUE;
+	return TRUE;
+#endif
 
-	gdk_threads_enter();
-
-	if( gWinPos[k].get( k, px, py, pw, ph, false ) )
-		result = TRUE;
-
-	gdk_flush();
-	gdk_threads_leave();
-#endif // D_GTK
-
-#ifdef D_MFC
-	if( !g_flg_gui )
-		return TRUE;
-
-	if( gWinPos[k].get( k, px, py, pw, ph, false ) )
-		result = TRUE;
-#endif // D_MFC
-
-	return result;
+	return FALSE;
 }
 
 /***************************************************************
@@ -1379,45 +1265,24 @@ bool_t	call_win_pos_get(
 
 long	call_key_get_char( void )
 {
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	long	c = '\0';
 
-#ifdef D_WS
 	if( !g_flg_init )
 		return c;
 	if( !g_flg_gui )
 		return c;
 
-	WSGIappDev()->lock();
+	gui_begin();
 
 	c = gKey.getChar();
 
-	WSGIappDev()->unlock();
-#endif // D_WS
-
-#ifdef D_GTK
-	if( !g_flg_init )
-		return c;
-	if( !g_flg_gui )
-		return c;
-
-	gdk_threads_enter();
-
-	c = gKey.getChar();
-
-	gdk_flush();
-	gdk_threads_leave();
-#endif // D_GTK
-
-#ifdef D_MFC
-	if( !g_flg_init )
-		return c;
-	if( !g_flg_gui )
-		return c;
-
-	c = gKey.getChar();
-#endif // D_MFC
+	gui_end();
 
 	return c;
+#endif
+
+	return '\0';
 }
 
 /***************************************************************
