@@ -5,9 +5,11 @@ extern "C" {
 #endif
 
 void	init_draw( void );
+void	reset_static_draw( void );
 void	measure_clk_tck( void );
 void	print_wrn( const char *s, ... );
 void	print_err( const char *s, ... );
+void	print_lex_wrn( const char *s, ... );
 void	print_lex_err( const char *s, ... );
 void	print_words(
 	const char *name,
@@ -16,7 +18,9 @@ void	print_words(
 	const char *fmt_male,
 	...
 );
-char	*get_words_line( char *p, long max_len );
+const char	*get_words_line( const char *p, long draw_max_n );
+const char	*get_next_char_str( const char *p );
+long	get_next_char_len( const char *p );
 void	print_msg_mbr( chr_t *chr, flg_msg_t flg, const char *s, ... );
 void	print_msg_find( chr_t *chr, flg_msg_t flg, const char *s, ... );
 void	print_msg( flg_msg_t flg, const char *s, ... );
@@ -34,6 +38,7 @@ long	get_ls_msg_n( void );
 void	draw_ls_msg( long n );
 ls_msg_t	*get_ls_msg( long idx );
 void	print_str( long scrn_x, long scrn_y, const char *s, ... );
+void	print_vfx( long scrn_x, long scrn_y, const char *s, ... );
 bool_t	set_redraw_every_turn( bool_t flg );
 bool_t	chk_redraw_every_turn( void );
 void	wipe_all( void );
@@ -46,8 +51,10 @@ void	draw_map_sub(
 	bool_t flgForce
 );
 void	redraw_map( void );
+void	redraw_map_force( void );
+void	redraw_map_sub( bool_t flgForce );
 void	wipe_map( void );
-void	force_redraw_map( void );
+void	force_clr_redraw_map( void );
 void	draw_party( void );
 void	draw_mbr( mbr_t *p );
 void	draw_square( void );
@@ -98,20 +105,33 @@ void	vfx_arw_mul_line(
 	long frame, long clr_frame, bool_t flg_clr
 );
 void	vfx_num( chr_t *p, long n );
-void	draw_lev_up( long map_x, long map_y, long n, chr_t *chr );
+void	bgn_sync_vfx_num( void );
+void	end_sync_vfx_num( void );
+long	get_draw_num_frame( long len );
+long	get_draw_num_sync_max_len( void );
+void	draw_num_sync( long idx );
 void	draw_num( long map_x, long map_y, long n, chr_t *chr );
+void	draw_num_x_1(
+	long map_x, long map_y,
+	long n, long idx,
+	chr_t *chr
+);
+void	draw_lev_up( long map_x, long map_y, long n, chr_t *chr );
 void	draw_blast(
 	chr_kind_t kind,
 	long map_x, long map_y,
 	blast_t *p, char *str
 );
 void	draw_request( request_t *req );
+void	redraw_mbr_data( mbr_t *org, mbr_t *mbr, long page_n );
 void	draw_mbr_data_all( mbr_t *org, mbr_t *mbr, long page_n );
+void	draw_mbr_data_all_cui( mbr_t *org, mbr_t *mbr, long page_n );
 void	draw_mbr_data( mbr_t *org, mbr_t *mbr, data_n_t n, bool_t flg_rev );
 data_n_t	next_mbr_data(
 	long page_n, data_n_t n, long d,
 	mbr_data_edit_kind_t edit_kind
 );
+bool_t	chk_sel_data_n( data_n_t n, mbr_data_edit_kind_t edit_kind );
 bool_t	gets_mbr_name( mbr_t *mbr );
 bool_t	gets_mbr_face( mbr_t *mbr );
 bool_t	gets_race_name( mbr_t *mbr );
@@ -162,15 +182,18 @@ long	get_key_num( void );
 void	un_get_key( long c );
 long	get_key( bool_t flg_clr_key_buf );
 void	get_key_wait_cancel( bool_t flg_clr_key_buf );
-long	get_key_sub_1( bool_t flg_clr_key_buf );
-long	get_key_sub_2( bool_t flg_clr_key_buf );
-long	get_key_x68k( bool_t flg_clr_key_buf );
-long	get_key_dos( void );
-long	get_key_no_clr_dos( void );
-long	get_key_half_wait( void );
-long	get_key_std( void );
-long	get_key_no_clr( void );
-long	get_key_no_clr_default( void );
+void	get_key_wait_cancel_or_exec( bool_t flg_clr_key_buf );
+void	get_key_wait_cancel_sub( bool_t flg_clr_key_buf, bool_t flg_exec );
+long	get_key_sub( bool_t flg_clr_key_buf );
+long	get_key_sub_1( bool_t flg_clr_key_buf, bool_t *p_flg_cont_exec );
+long	get_key_sub_2( bool_t flg_clr_key_buf, bool_t *p_flg_cont_exec );
+long	get_key_x68k( bool_t flg_clr_key_buf, bool_t *p_flg_cont_exec );
+long	get_key_dos( bool_t *p_flg_cont_exec );
+long	get_key_no_clr_dos( bool_t *p_flg_cont_exec );
+long	get_key_half_wait( bool_t *p_flg_cont_exec );
+long	get_key_std( bool_t *p_flg_cont_exec );
+long	get_key_no_clr( bool_t *p_flg_cont_exec );
+long	get_key_no_clr_default( bool_t *p_flg_cont_exec );
 bool_t	chk_key_buf( void );
 long	get_key_buf_char( void );
 long	get_key_buf_char_sub( void );
