@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fight.c,v 1.130 2008/05/10 03:21:35 bowkenken Exp $
+* $Id: fight.c,v 1.133 2008/09/20 00:28:04 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -35,6 +35,17 @@
 #define	FIGHT_C
 #include	"inc.h"
 
+/***************************************************************
+* ٥ȹ
+***************************************************************/
+
+/* ٥ˤ빶Ψγ */
+#define	MON_ADD_ATTACK_RATE_BGN_N	((rate_t)20)
+/* ٥ˤ빶Ψνλ */
+#define	MON_ADD_ATTACK_RATE_END_N	((rate_t)1)
+/* ٥ˤ빶ΨѲ */
+#define	MON_ADD_ATTACK_RATE_ADD_N	((rate_t)-1)
+
 /***************************************************************
 * ٥ɶζ
 ***************************************************************/
@@ -823,7 +834,165 @@ ratio_t	calc_attack_sum(
 * return : ?
 ***************************************************************/
 
-bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack, long range )
+bool_t	fight(
+	chr_t *o_p, chr_t *d_p,
+	const attack_t *attack, long range
+)
+{
+	long	attack_n;
+	long	hit_n;
+	long	i;
+
+	attack_n = calc_attack_n( o_p, attack );
+	hit_n = 0;
+
+	/* ܤɽ */
+
+	if( (o_p != NULL) && (attack_n >= 2) ){
+		curs_attrset_chr( d_p, -1, FALSE );
+		print_msg( FLG_NULL, MSG_FIGHT_COMBO, o_p->name, attack_n );
+		curs_attrset_dflt();
+	}
+
+	/* begin */
+	bgn_sync_vfx_num();
+
+	for( i = 0; i < attack_n; i++ ){
+		if( fight_x_1( o_p, d_p, attack, range ) )
+			hit_n++;
+	}
+
+	/* end */
+	end_sync_vfx_num();
+
+	if( hit_n >= 1 )
+		return TRUE;
+	else
+		return FALSE;
+}
+
+/***************************************************************
+* ׻
+* chr_t *o_p : ¦饯
+* const attack_t *attack : ǡ
+* return : 
+***************************************************************/
+
+long	calc_attack_n( chr_t *o_p, const attack_t *attack )
+{
+	if( o_p == NULL )
+		return 0;
+	if( attack == NULL )
+		return 0;
+
+	if( attack->flg_throw )
+		return calc_attack_n_hun( o_p, attack );
+	else if( attack->flg_monk )
+		return calc_attack_n_mon( o_p, attack );
+	else
+		return calc_attack_n_fig( o_p, attack );
+}
+
+/***************************************************************
+* ׻ ()
+* chr_t *o_p : ¦饯
+* const attack_t *attack : ǡ
+* return : 
+***************************************************************/
+
+long	calc_attack_n_fig( chr_t *o_p, const attack_t *attack )
+{
+	if( o_p == NULL )
+		return 0;
+	if( attack == NULL )
+		return 0;
+
+	if( attack->flg_throw )
+		return 0;
+	if( attack->flg_monk )
+		return 0;
+
+	return 1;
+}
+
+/***************************************************************
+* ׻ (Ʈ)
+* chr_t *o_p : ¦饯
+* const attack_t *attack : ǡ
+* return : 
+***************************************************************/
+
+long	calc_attack_n_mon( chr_t *o_p, const attack_t *attack )
+{
+	rate_t	rate, add_rate;
+	long	lev;
+	rate_t	r;
+	long	n;
+
+	if( o_p == NULL )
+		return 0;
+	if( attack == NULL )
+		return 0;
+
+	if( !attack->flg_monk )
+		return 0;
+
+	rate = (rate_t)_100_PERCENT;
+	add_rate = MON_ADD_ATTACK_RATE_BGN_N;
+	lev = get_lev( o_p, ABL_KIND_MON );
+	for( ; lev > 0; lev-- ){
+		if( MON_ADD_ATTACK_RATE_ADD_N >= +1 )
+			if( add_rate >= MON_ADD_ATTACK_RATE_END_N )
+				break;
+		if( MON_ADD_ATTACK_RATE_ADD_N <= -1 )
+			if( add_rate <= MON_ADD_ATTACK_RATE_END_N )
+				break;
+
+		rate += add_rate;
+		add_rate += MON_ADD_ATTACK_RATE_ADD_N;
+	}
+	rate += lev * MON_ADD_ATTACK_RATE_END_N;
+
+	n = 0;
+	for( r = randm( rate ) + 1; r > 0; r -= _100_PERCENT )
+		n++;
+
+	return n;
+}
+
+/***************************************************************
+* ׻ (ͷ)
+* chr_t *o_p : ¦饯
+* const attack_t *attack : ǡ
+* return : 
+***************************************************************/
+
+long	calc_attack_n_hun( chr_t *o_p, const attack_t *attack )
+{
+	if( o_p == NULL )
+		return 0;
+	if( attack == NULL )
+		return 0;
+
+	if( !attack->flg_throw )
+		return 0;
+
+	return 1;
+}
+
+/***************************************************************
+* 1 ʬƮ
+* chr_t *o_p : ¦饯
+* chr_t *d_p : ɸ¦饯
+* const attack_t *attack : ǡ
+* long range : Υ
+* return : ?
+***************************************************************/
+
+bool_t	fight_x_1(
+	chr_t *o_p, chr_t *d_p,
+	const attack_t *attack, long range
+)
 {
 	chr_kind_t	o_k, d_k;
 	long	o_hit, o_dam;
@@ -1693,24 +1862,42 @@ bool_t	chk_magic_protect( chr_t *o_p, chr_t *d_p, bool_t flg_throw )
 		if( flg_throw ){
 			if( eq[EQUIP_KIND_ARW].kind != ITEM_KIND_WPN )
 				break;
-
-			if( eq[EQUIP_KIND_ARW].kind == ITEM_KIND_WPN )
-				if( eq[EQUIP_KIND_ARW].dat.wpn.add_hit <= 0 )
-					break;
-			if( eq[EQUIP_KIND_BOW].kind == ITEM_KIND_WPN )
-				if( eq[EQUIP_KIND_BOW].dat.wpn.add_hit <= 0 )
-					break;
+			if( eq[EQUIP_KIND_ARW].kind == ITEM_KIND_WPN ){
+				if( eq[EQUIP_KIND_ARW].dat.wpn.add_hit > 0 )
+					return FALSE;
+				if( eq[EQUIP_KIND_ARW].dat.wpn.add_crtcl > 0 )
+					return FALSE;
+				if( eq[EQUIP_KIND_ARW].dat.wpn.add_dam > 0 )
+					return FALSE;
+			}
+			if( eq[EQUIP_KIND_BOW].kind == ITEM_KIND_WPN ){
+				if( eq[EQUIP_KIND_BOW].dat.wpn.add_hit > 0 )
+					return FALSE;
+				if( eq[EQUIP_KIND_BOW].dat.wpn.add_crtcl > 0 )
+					return FALSE;
+				if( eq[EQUIP_KIND_BOW].dat.wpn.add_dam > 0 )
+					return FALSE;
+			}
+			break;
 		} else {
 			if( eq[EQUIP_KIND_WIELDING].kind != ITEM_KIND_WPN )
 				break;
-			if( eq[EQUIP_KIND_WIELDING].dat.wpn.add_hit <= 0 )
-				break;
+			if( eq[EQUIP_KIND_WIELDING].dat.wpn.add_hit > 0 )
+				return FALSE;
+			if( eq[EQUIP_KIND_WIELDING].dat.wpn.add_crtcl > 0 )
+				return FALSE;
+			if( eq[EQUIP_KIND_WIELDING].dat.wpn.add_dam > 0 )
+				return FALSE;
+			break;
 		}
 
 		return FALSE;
 	} while( 0 );
 
+	curs_attrset_chr( o_p, -1, FALSE );
 	print_msg( FLG_NULL, MSG_FIGHT_MAGIC_PROTECT, d_p->name );
+	curs_attrset_dflt();
+
 	return TRUE;
 }
 
