@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.c,v 1.80 2007/02/25 02:12:17 bowkenken Exp $
+* $Id: gmain.c,v 1.113 2008/09/22 05:30:00 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -60,12 +60,12 @@
 * ѿ
 ***************************************************************/
 
-long	flg_term;
+static long	flg_term;
 
-#if	HAVE_TERMIOS_H
-struct termios	pre_tbuf;
-#elif	HAVE_TERMIO_H
-struct termio	pre_tbuf;
+#if	defined( HAVE_TERMIOS_H )
+static struct termios	pre_tbuf;
+#elif	defined( HAVE_TERMIO_H )
+static struct termio	pre_tbuf;
 #endif
 
 /***************************************************************
@@ -73,15 +73,17 @@ struct termio	pre_tbuf;
 ***************************************************************/
 
 #define	OPT_ARG_MAX_LEN	128
-#define	STR_OPT	"GCUg:S:k:e:s:p:md:Vh"
+#define	STR_OPT	"GCUT:D:S:l:k:e:s:p:md:Vvh"
 
-#if	HAVE_GETOPT_LONG
+#ifdef	HAVE_GETOPT_LONG
 static struct option	long_opt[] = {
 	{ "gui",           no_argument,       NULL, 'G' },
 	{ "cui",           no_argument,       NULL, 'C' },
 	{ "gui-and-cui",   no_argument,       NULL, 'U' },
-	{ "sel-graph-dir", required_argument, NULL, 'g' },
-	{ "graph-scale",   required_argument, NULL, 'S' },
+	{ "text-mode",     required_argument, NULL, 'T' },
+	{ "sel-graph-dir", required_argument, NULL, 'D' },
+	{ "map-scale",     required_argument, NULL, 'S' },
+	{ "language",      required_argument, NULL, 'l' },
 	{ "clear-key-buf", required_argument, NULL, 'k' },
 	{ "echo-key",      required_argument, NULL, 'e' },
 	{ "use-curses",    required_argument, NULL, 's' },
@@ -104,27 +106,219 @@ char	str_usage[] = {
 	"  -G, --gui                set GUI mode\n"
 	"  -C, --cui                set CUI mode\n"
 	"  -U, --gui-and-cui        set GUI and CUI mode\n"
-	"  -g, --sel-graph-dir=DIR  select graphic directory\n"
+#if	defined( DEBUG ) || !defined( NDEBUG )
+	"  -T, --text-mode=POINT    set TEXT mode:\n"
+	"                             point of font, ON or OFF\n"
+	"  -D, --sel-graph-dir=DIR  select graphic directory:\n"
 	"                             graphic directory\n"
-	"  -S, --graph-scale        set graphic scale\n"
+	"  -S, --map-scale=N        set scale of map character:\n"
 	"                             scale(%%)\n"
+#endif
+	"  -l, --language=LANGUAGE  set language:\n"
+	"                             language\n"
+#if	defined( DEBUG ) || !defined( NDEBUG )
 	"  -k, --clear-key-buf=FLAG clear key buffer:\n"
-	"                             ON, OFF\n"
+	"                             ON or OFF\n"
+#endif
 	"  -e, --echo-key=FLAG      echo key:\n"
-	"                             ON, OFF\n"
+	"                             ON or OFF\n"
 	"  -s, --use-curses=FLAG    use curses library:\n"
-	"                             ON, OFF\n"
+	"                             ON or OFF\n"
 	"  -p, --use-keypad=FLAG    use cursor key (call keypad):\n"
-	"                             ON, OFF\n"
+	"                             ON or OFF\n"
 	"  -m, --measure-clock      measure frame rate\n"
 #if	defined( DEBUG ) || !defined( NDEBUG )
 	"  -d, --debug=FLAG         set debug mode:\n"
-	"                             ON, OFF\n"
+	"                             ON or OFF\n"
 #endif
-	"  -V, --version            display version and exit\n"
+	"  -V, -v, --version        display version and exit\n"
 	"  -h, --help               display this help and exit\n"
 };
 
+/***************************************************************
+* Τν
+***************************************************************/
+
+void	init_game( void )
+{
+	dun_t	*dun;
+
+	/* ƽθƤֽ֤˵դ */
+
+	g_flg_init = FALSE;
+
+	reset_static();
+
+	init_signal();
+	init_scrn();
+
+	srandm( (long)time( NULL ) );
+
+	init_scene();
+	init_turn();
+
+	init_msg();
+	init_draw();
+	init_replay();
+
+	init_game_file();
+
+	init_var_menu();
+	init_var_main_menu();
+	init_var_misc_menu();
+
+	if( !load_game_conf() )
+		g_flg_measure_clk_tck = TRUE;
+	overwrite_arg();
+
+	ena_scrn( TRUE );
+	ena_curs_draw();
+	wipe_all();
+
+	init_dun();
+	init_item();
+	init_trap();
+	init_fx();
+	init_spell();
+	init_chr();
+	init_town();
+	init_menu();
+	init_town_menu();
+	init_auto_menu();
+	init_misc_menu();
+	init_main_menu();
+	init_request();
+
+	init_mbr_formation();
+
+	if( g_flg_debug )
+		init_spell_debug();
+	else
+		init_spell_dflt();
+	init_spell_nin();
+
+	if( g_flg_debug )
+		set_flg_no_save( TRUE );
+
+	if( g_flg_measure_clk_tck )
+		measure_clk_tck();
+
+	dun = get_dun();
+	dun->lev = 0;
+	up_dun( 0 );
+
+	g_flg_init = TRUE;
+}
+
+/***************************************************************
+* ⥸塼Υƥåѿꥻå
+***************************************************************/
+
+void	reset_static( void )
+{
+	reset_static_auto_menu();
+	reset_static_chr();
+	reset_static_curs();
+	reset_static_draw();
+	reset_static_dun();
+	reset_static_fight();
+	reset_static_fx();
+	reset_static_game_file();
+	reset_static_game_main();
+	reset_static_misc_menu();
+	reset_static_item();
+	reset_static_menu();
+	reset_static_misc();
+	reset_static_main_menu();
+	reset_static_mnstr_act();
+	reset_static_mnstr();
+	reset_static_msg();
+	reset_static_nest_flg();
+	reset_static_party();
+	reset_static_pet();
+	reset_static_replay();
+	reset_static_request();
+	reset_static_scene();
+	reset_static_spell();
+	reset_static_town_menu();
+	reset_static_town();
+	reset_static_trap();
+	reset_static_turn();
+
+#if	defined( D_GTK )
+#elif	defined( D_WS )
+#elif	defined( D_MFC )
+#elif	defined( D_DOS )
+	reset_static_main_dos();
+#else
+	reset_static_main_unix();
+#endif
+}
+
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_game_main( void )
+{
+}
+
+/***************************************************************
+* ᥤ󡦥롼
+***************************************************************/
+
+void	game_main( void )
+{
+	chk_scroll( TRUE );
+	redraw_all();
+
+	if( !g_flg_debug ){
+		print_msg( FLG_NULL, MSG_HINT_CANCEL_MENU_1 );
+		print_msg( FLG_NULL, MSG_HINT_CANCEL_MENU_2 );
+
+		menu_load_bar();
+
+		party_exit_bar();
+	}
+
+	while( 1 ){
+		chk_key( g_flg_clr_key_buf, TRUE );
+	}
+}
+
+/***************************************************************
+* ࡦС
+***************************************************************/
+
+void	game_over( void )
+{
+	change_scene( SCENE_N_GAME_OVER );
+
+	print_msg( FLG_MSG_NO_MORE_PREV, MSG_S, MSG_GAME_OVER );
+	while( 1 ){
+		switch( get_key( FALSE ) ){
+		case CASE_EXIT:
+			exit_game( EXIT_SUCCESS );
+		}
+	}
+}
+
+/***************************************************************
+* ǥ
+***************************************************************/
+
+void	ending( void )
+{
+	change_scene( SCENE_N_ENDING );
+
+	while( 1 ){
+		switch( get_key( FALSE ) ){
+		case CASE_EXIT:
+			exit_game( EXIT_SUCCESS );
+		}
+	}
+}
+
 /***************************************************************
 * ν
 ***************************************************************/
@@ -141,13 +335,19 @@ void	init_arg( void )
 
 	g_flg_cui = TRUE;
 	g_flg_gui = FALSE;
+
+	g_flg_text_mode = FALSE;
+	g_text_mode_point = 0;
+
 	g_graph_scale_rate = _100_PERCENT;
 	g_gui_key_kind = GUI_KEY_KIND_CONSOLE;
 
+	g_language = NULL;
+
 	g_flg_clr_key_buf_arg_overwrite = FALSE;
 	g_flg_clr_key_buf_arg = FALSE;
-	g_flg_clr_key_buf = FALSE;
-	g_flg_clr_key_buf_menu = FALSE;
+	g_flg_clr_key_buf = TRUE;
+	g_flg_clr_key_buf_menu = TRUE;
 
 	g_flg_echo_key = FALSE;
 
@@ -155,6 +355,8 @@ void	init_arg( void )
 	g_flg_use_keypad = FALSE;
 
 	g_flg_measure_clk_tck = FALSE;
+
+	g_flg_send_item_exec_turn = FALSE;
 }
 
 /***************************************************************
@@ -165,6 +367,8 @@ void	init_arg( void )
 
 void	chk_arg( int argc, char **argv )
 {
+	long	len;
+	long	mem_size;
 #if	(!HAVE_GETOPT && !HAVE_GETOPT_LONG)
 	long	n = 0;
 	char	*optarg;
@@ -176,17 +380,17 @@ void	chk_arg( int argc, char **argv )
 
 	while( 1 ){
 		long	c;
-#if	HAVE_GETOPT_LONG
+#ifdef	HAVE_GETOPT_LONG
 		int	opt_idx;
 #endif	/* HAVE_GETOPT_LONG */
 
-#if	HAVE_GETOPT_LONG
+#if	defined( HAVE_GETOPT_LONG )
 		c = getopt_long( argc, argv, STR_OPT, long_opt, &opt_idx );
-#elif	HAVE_GETOPT
+#elif	defined( HAVE_GETOPT )
 		c = getopt( argc, argv, STR_OPT );
 #else	/* HAVE_GETOPT_LONG */
 		n++;
-		if( c > argc - 1 )
+		if( n > argc - 1 )
 			break;
 		optarg = argv[n + 1];
 
@@ -211,38 +415,59 @@ void	chk_arg( int argc, char **argv )
 			g_flg_cui = TRUE;
 			g_flg_gui = TRUE;
 			break;
-		case 'g':
-			set_str_dir_sel_graph( optarg );
+		case 'T':
+			if( chk_opt_flg( optarg, &g_flg_text_mode,
+					FALSE ) ){
+				g_text_mode_point = 0;
+			} else {
+				g_flg_text_mode = TRUE;
+				chk_opt_num( optarg, &g_text_mode_point,
+						TRUE );
+			}
+			break;
+		case 'D':
+			call_set_str_dir_sel_graph( optarg );
 			break;
 		case 'S':
-			g_graph_scale_rate = strtol( optarg, NULL, 0 );
+			chk_opt_num( optarg, &g_graph_scale_rate, TRUE );
+			break;
+		case 'l':
+			if( g_language != NULL )
+				free_mem( g_language );
+
+			len = str_len_std( optarg );
+			mem_size = len * sizeof( char );
+			g_language = (char *)alloc_mem( mem_size, TRUE );
+
+			str_nz_cpy( g_language, optarg, len );
 			break;
 		case 'k':
 			g_flg_clr_key_buf_arg_overwrite = TRUE;
-			g_flg_clr_key_buf_arg = chk_opt_flg( optarg );
+			chk_opt_flg( optarg, &g_flg_clr_key_buf_arg, TRUE );
 			break;
 		case 'e':
-			g_flg_echo_key = chk_opt_flg( optarg );
+			chk_opt_flg( optarg, &g_flg_echo_key, TRUE );
 			break;
 		case 's':
-			g_flg_use_curs = chk_opt_flg( optarg );
+			chk_opt_flg( optarg, &g_flg_use_curs, TRUE );
 			break;
 		case 'p':
-			g_flg_use_keypad = chk_opt_flg( optarg );
+			chk_opt_flg( optarg, &g_flg_use_keypad, TRUE );
 			break;
 		case 'm':
 			g_flg_measure_clk_tck = TRUE;
 			break;
 		case 'd':
-			g_flg_debug = chk_opt_flg( optarg );
+			chk_opt_flg( optarg, &g_flg_debug, TRUE );
 			break;
 		case 'V':
+		case 'v':
 			version( stdout );
-			exit( EXIT_SUCCESS );
+			gexit( EXIT_SUCCESS );
 			break;
 		case 'h':
 			usage( stdout );
-			exit( EXIT_SUCCESS );
+			gexit( EXIT_SUCCESS );
 			break;
 		case '\0':
 			break;
@@ -250,30 +475,78 @@ void	chk_arg( int argc, char **argv )
 		case ':':
 		default:
 			usage( stderr );
-			exit( EXIT_FAILURE );
+			gexit( EXIT_FAILURE );
 			break;
 		}
 	}
 
 	if( (argc - optind) > 0 ){
 		usage( stderr );
-		exit( EXIT_FAILURE );
+		gexit( EXIT_FAILURE );
 	}
 }
 
+/***************************************************************
+* ͤΰå
+* const char *optarg : ץʸ
+* long *pn : ֤ͤ
+* bool_t flg_err_exit : 顼ǽλ뤫?
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	chk_opt_num(
+	const char *optarg, long *pn, bool_t flg_err_exit
+)
+{
+	do {
+		if( optarg == NULL )
+			break;
+		if( pn == NULL )
+			break;
+		if( !isdigit( optarg[0] ) )
+			break;
+
+		/* ͤꤵ줿 */
+
+		*pn = strtol( optarg, NULL, 0 );
+
+		return TRUE;
+		break;
+	} while( 0 );
+
+	/* 顼 */
+
+	if( flg_err_exit ){
+		usage( stderr );
+		gexit( EXIT_FAILURE );
+	}
+
+	return FALSE;
+}
+
 /***************************************************************
 * Υ󡿥դΥե饰å
 * const char *optarg : ץʸ
-* return : ե饰?
+* bool_t *flg : ե饰󤫤ɤ֤
+* bool_t flg_err_exit : 顼ǽλ뤫?
+* return : 顼̵ä?
 ***************************************************************/
 
-bool_t	chk_opt_flg( const char *optarg )
+bool_t	chk_opt_flg(
+	const char *optarg, bool_t *flg, bool_t flg_err_exit
+)
 {
 	static char	str[OPT_ARG_MAX_LEN + 1];
 	long	i;
 
-	if( optarg == NULL )
+	if( optarg == NULL ){
+		if( flg_err_exit ){
+			usage( stderr );
+			gexit( EXIT_FAILURE );
+		}
+
 		return FALSE;
+	}
 
 	for( i = 0; i < OPT_ARG_MAX_LEN; i++ ){
 		if( optarg[i] == '\0' )
@@ -282,6 +555,7 @@ bool_t	chk_opt_flg( const char *optarg )
 	}
 	str[i] = '\0';
 
+	*flg = TRUE;
 	if( strcmp( str, "ON" ) == 0 )
 		return TRUE;
 	if( strcmp( str, "TRUE" ) == 0 )
@@ -293,19 +567,22 @@ bool_t	chk_opt_flg( const char *optarg )
 	if( strcmp( str, "1" ) == 0 )
 		return TRUE;
 
+	*flg = FALSE;
 	if( strcmp( str, "OFF" ) == 0 )
-		return FALSE;
+		return TRUE;
 	if( strcmp( str, "FALSE" ) == 0 )
-		return FALSE;
+		return TRUE;
 	if( strcmp( str, "NIL" ) == 0 )
-		return FALSE;
+		return TRUE;
 	if( strcmp( str, "NO" ) == 0 )
-		return FALSE;
+		return TRUE;
 	if( strcmp( str, "0" ) == 0 )
-		return FALSE;
+		return TRUE;
 
-	usage( stderr );
-	exit( EXIT_FAILURE );
+	if( flg_err_exit ){
+		usage( stderr );
+		gexit( EXIT_FAILURE );
+	}
 
 	return FALSE;
 }
@@ -329,104 +606,10 @@ void	overwrite_arg()
 
 void	usage( FILE *fp )
 {
-	if( !g_flg_cui )
-		return;
-
 	fprintf( fp, str_usage, STR_FILE_NAME_GAME );
 	fflush( fp );
 }
 
-/***************************************************************
-* Τν
-***************************************************************/
-
-void	init_game( void )
-{
-	dun_t	*dun;
-
-	/* ƽθƤֽ֤˵դ */
-
-	g_flg_init = FALSE;
-
-	init_signal();
-	init_scrn();
-
-	srandm( time( NULL ) );
-	init_turn();
-
-	init_msg();
-	init_draw();
-
-	init_game_file();
-
-	init_var_menu();
-	init_var_main_menu();
-	init_var_misc_menu();
-
-	if( !load_game_conf() )
-		g_flg_measure_clk_tck = TRUE;
-	overwrite_arg();
-
-	ena_scrn( TRUE );
-	ena_curs_draw();
-	wipe_all();
-
-	init_dun();
-	init_item();
-	init_trap();
-	init_fx();
-	init_chr();
-	init_spell();
-	init_town();
-	init_menu();
-	init_tmenu();
-	init_auto_menu();
-	init_misc_menu();
-	init_main_menu();
-	init_request();
-
-	init_mbr_formation();
-	init_spell_nin();
-
-	if( g_flg_debug )
-		set_flg_no_save( TRUE );
-
-	if( g_flg_measure_clk_tck )
-		measure_clk_tck();
-
-	dun = get_dun();
-	dun->lev = 0;
-	up_dun( 0 );
-
-	g_flg_init = TRUE;
-}
-
-/***************************************************************
-* ᥤ󡦥롼
-***************************************************************/
-
-void	game_main( void )
-{
-	if( !g_flg_debug ){
-		door_t	*dr;
-
-		print_msg( FLG_NULL, MSG_HINT_CANCEL_MENU_1 );
-		print_msg( FLG_NULL, MSG_HINT_CANCEL_MENU_2 );
-
-		menu_bar_load();
-
-		dr = get_shop_door( SHOP_N_BAR );
-		if( dr != NULL ){
-			open_door_shop( dr->n );
-			exec_all_phase();
-		}
-	}
-
-	while( 1 ){
-		chk_key( g_flg_clr_key_buf, TRUE );
-	}
-}
-
 /***************************************************************
 * νλ
 * long code : λ
@@ -436,7 +619,7 @@ void	exit_game( long code )
 {
 	close_game( code );
 
-	exit( code );
+	gexit( code );
 }
 
 /***************************************************************
@@ -446,28 +629,49 @@ void	exit_game( long code )
 
 void	close_game( long code )
 {
-	FILE	*fp;
-
-	curs_move( WIN_MSG_DRAW_MIN_Y, SCREEN_MIN_X );
+	close_item();
 
+	curs_move( get_max_line() - 1, SCREEN_MIN_X );
 	reset_scrn();
 
-	if( code == 0 )
-		fp = stdout;
-	else
-		fp = stderr;
+	fflush( stdout );
+	fflush( stderr );
 
-	version( fp );
+	if( code == 0 )
+		version( stdout );
+	else
+		version( stderr );
+
+	fflush( stdout );
+	fflush( stderr );
 }
 
 /***************************************************************
 * ɽ
 ***************************************************************/
 
-void	about_game( void )
+void	about_game( bool_t flg_init )
 {
 	static char	tmp[1023 + 1];
 
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_DOWS )
+	if( flg_init )
+		return;
+#endif
+
+	if( g_flg_gui ){
+		const long	max_len = 80 * 40;
+		static char	str[80 * 40 + 1];
+
+		sn_printf( str, max_len, MSG_FMT_COPYRIGHT,
+				LS_STR_COPYRIGHT );
+		str_max_n_cat( str, MSG_ABOUT_GAME, max_len );
+
+		call_gui_words_draw_width( str, 80 );
+
+		return;
+	}
+
 	curs_move( WIN_MSG_DRAW_MIN_Y, SCREEN_MIN_X );
 
 	dis_scrn();
@@ -524,7 +728,7 @@ void	init_signal( void )
 	signal( SIGSEGV, signal_handler );
 	signal( SIGABRT, signal_handler );
 	signal( SIGTERM, signal_handler );
-#else	/* D_X68K */
+#else
 	signal( SIGHUP, signal_handler );
 	signal( SIGINT, signal_handler );
 	signal( SIGKILL, signal_handler );
@@ -532,7 +736,7 @@ void	init_signal( void )
 	signal( SIGSEGV, signal_handler );
 	signal( SIGABRT, signal_handler );
 	signal( SIGTERM, signal_handler );
-#endif	/* D_X68K */
+#endif
 }
 
 /***************************************************************
@@ -544,7 +748,7 @@ void	signal_handler( int sig )
 {
 	reset_scrn();
 
-	exit( EXIT_FAILURE );
+	exit_game( EXIT_FAILURE );
 }
 
 /***************************************************************
@@ -762,16 +966,16 @@ void	ena_term_unix( void )
 #if	(HAVE_TERMIOS_H || HAVE_TERMIO_H)
 	if( flg_term == 1 ){
 		/* ¤Τ */
-# if	HAVE_TERMIOS_H
+# if	defined( HAVE_TERMIOS_H )
 		struct termios	tbuf;
-# elif	HAVE_TERMIO_H
+# elif	defined( HAVE_TERMIO_H )
 		struct termio	tbuf;
 # endif
 
 		/* Υå */
-# if	HAVE_TERMIOS_H
+# if	defined( HAVE_TERMIOS_H )
 		tcgetattr( fileno( stdin ), &tbuf );
-# elif	HAVE_TERMIO_H
+# elif	defined( HAVE_TERMIO_H )
 		ioctl( 0, TCGETA, &tbuf );
 # endif
 
@@ -793,12 +997,12 @@ void	ena_term_unix( void )
 		}
 
 		/* Υå */
-# if	HAVE_TERMIOS_H
+# if	defined( HAVE_TERMIOS_H )
 		if( tcsetattr( fileno( stdin ), TCSANOW, &tbuf ) != 0 ){
 			fprintf( stderr, MSG_S, MSG_ERR_SET_TTY );
 			exit_game( EXIT_FAILURE );
 		}
-# elif	HAVE_TERMIO_H
+# elif	defined( HAVE_TERMIO_H )
 		if( ioctl( 0, TCSETAF, &tbuf ) != 0 ){
 			fprintf( stderr, MSG_S, MSG_ERR_SET_TTY );
 			exit_game( EXIT_FAILURE );
@@ -818,9 +1022,9 @@ void	dis_term_unix( void )
 		return;
 
 	if( flg_term == 1 ){
-#if	HAVE_TERMIOS_H
+#if	defined( HAVE_TERMIOS_H )
 		tcsetattr( fileno( stdin ), TCSANOW, &pre_tbuf );
-#elif	HAVE_TERMIO_H
+#elif	defined( HAVE_TERMIO_H )
 		ioctl( 0, TCSETAF, &pre_tbuf );
 #endif
 	}
@@ -855,9 +1059,9 @@ void	set_key_wait_vtime( long wait_vtime )
 {
 #if	(HAVE_TERMIOS_H || HAVE_TERMIO_H)
 	/* ¤Τ */
-# if	HAVE_TERMIOS_H
+# if	defined( HAVE_TERMIOS_H )
 	struct termios	tbuf;
-# elif	HAVE_TERMIO_H
+# elif	defined( HAVE_TERMIO_H )
 	struct termio	tbuf;
 # endif
 
@@ -865,9 +1069,9 @@ void	set_key_wait_vtime( long wait_vtime )
 		return;
 
 	/* Υå */
-# if	HAVE_TERMIOS_H
+# if	defined( HAVE_TERMIOS_H )
 	tcgetattr( fileno( stdin ), &tbuf );
-# elif	HAVE_TERMIO_H
+# elif	defined( HAVE_TERMIO_H )
 	ioctl( 0, TCGETA, &tbuf );
 # endif
 
@@ -875,12 +1079,12 @@ void	set_key_wait_vtime( long wait_vtime )
 	tbuf.c_cc[VTIME] = wait_vtime;
 
 	/* Υå */
-# if	HAVE_TERMIOS_H
+# if	defined( HAVE_TERMIOS_H )
 	if( tcsetattr( fileno( stdin ), TCSANOW, &tbuf ) != 0 ){
 		fprintf( stderr, MSG_S, MSG_ERR_SET_TTY );
 		exit_game( EXIT_FAILURE );
 	}
-# elif	HAVE_TERMIO_H
+# elif	defined( HAVE_TERMIO_H )
 	if( ioctl( 0, TCSETAF, &tbuf ) != 0 ){
 		fprintf( stderr, MSG_S, MSG_ERR_SET_TTY );
 		exit_game( EXIT_FAILURE );
