@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-gtk.cpp,v 1.41 2008/05/05 12:43:59 bowkenken Exp $
+* $Id: main-gtk.cpp,v 1.51 2008/09/22 07:51:26 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -54,6 +54,8 @@ GtkWidget *btnMapExec;
 GtkWidget *btnMapAutoMark;
 GtkWidget *btnMapUserMenu;
 GtkWidget *btnMapSpell;
+GtkWidget *btnMapCancel;
+GtkWidget *btnMapOk;
 
 GtkWidget *statBarMap;
 guint statBarMapContextId;
@@ -129,11 +131,11 @@ void	init_gtk_win( int argc, char **argv )
 
 	init_main_win();
 
-	// ե졼ࡦ졼Ȥ
+	gMusic.init();
 
-	ghTimer = gtk_timeout_add( 1000 * 2 / 60,
-			handle_map_draw,
-			(gpointer)gMapDrawingArea );
+	// ޡ
+
+	ena_timer();
 
 	// ȥ
 
@@ -147,6 +149,17 @@ void	init_gtk_win( int argc, char **argv )
 	gSelConf.draw();
 }
 
+////////////////////////////////////////////////////////////////
+// ޡͭˤ
+////////////////////////////////////////////////////////////////
+
+void	ena_timer( void )
+{
+	ghTimer = gtk_timeout_add( 1000 * 4 / 60,
+			handle_map_draw,
+			(gpointer)gMapDrawingArea );
+}
+
 ////////////////////////////////////////////////////////////////
 // եåν
 ////////////////////////////////////////////////////////////////
@@ -158,7 +171,7 @@ void	init_main_sel_conf( GraphConf *cnf )
 	gPcgDun.init( cnf );
 	configure_map();
 
-	gtk_timeout_remove( ghTimer );
+//@@@	gtk_timeout_remove( ghTimer );
 	change_scene( SCENE_N_TOWN );
 
 	gGuiMenu.init();
@@ -229,6 +242,10 @@ void	init_main_win( void )
 			MSG_GUI_MAP_USER_MENU );
 	btnMapSpell = gtk_button_new_with_label(
 			MSG_GUI_MAP_SPELL );
+	btnMapCancel = gtk_button_new_with_label(
+			MSG_GUI_MAP_CANCEL );
+	btnMapOk = gtk_button_new_with_label(
+			MSG_GUI_MAP_OK );
 
 	gtk_toolbar_append_widget( GTK_TOOLBAR( toolBar ),
 			btnMapExec,
@@ -250,12 +267,22 @@ void	init_main_win( void )
 			btnMapSpell,
 			MSG_GUI_MAP_TOOL_TIP_SPELL,
 			NULL );
+	gtk_toolbar_append_widget( GTK_TOOLBAR( toolBar ),
+			btnMapCancel,
+			MSG_GUI_MAP_TOOL_TIP_CANCEL,
+			NULL );
+	gtk_toolbar_append_widget( GTK_TOOLBAR( toolBar ),
+			btnMapOk,
+			MSG_GUI_MAP_TOOL_TIP_OK,
+			NULL );
 
 	gtk_widget_show( btnMapExec );
 	gtk_widget_show( gMapButtonContExec );
 	gtk_widget_show( btnMapAutoMark );
 	gtk_widget_show( btnMapUserMenu );
 	gtk_widget_show( btnMapSpell );
+	gtk_widget_show( btnMapCancel );
+	gtk_widget_show( btnMapOk );
 
 	// ġ롦СؤΥ٥ȡϥɥ
 
@@ -279,6 +306,14 @@ void	init_main_win( void )
 			"clicked",
 			GTK_SIGNAL_FUNC( handle_spell_clicked ),
 			NULL );
+	gtk_signal_connect( GTK_OBJECT( btnMapCancel ),
+			"clicked",
+			GTK_SIGNAL_FUNC( handle_cancel_clicked ),
+			NULL );
+	gtk_signal_connect( GTK_OBJECT( btnMapOk ),
+			"clicked",
+			GTK_SIGNAL_FUNC( handle_ok_clicked ),
+			NULL );
 
 	// 襨ꥢ
 
@@ -441,22 +476,11 @@ void	init_main_win( void )
 
 	// ᥤ󡦥ɥɽ
 
-	gtk_widget_show( gMapWin );
+	gWinPos[WIN_KIND_MAP].draw( WIN_KIND_MAP );
 
 	gtk_drawing_area_size( GTK_DRAWING_AREA( gMapDrawingArea ),
 			MAP_WIN_MIN_WIDTH(),
 			MAP_WIN_MIN_HEIGHT() );
-
-	// ᥤ󡦥ɥκɸ
-
-	long ix, iy, iw, ih;
-	if( gWinPos[WIN_KIND_MAP].get(
-			WIN_KIND_MAP,
-			&ix, &iy, &iw, &ih, true ) ){
-		gWinPos[WIN_KIND_MAP].set(
-				WIN_KIND_MAP,
-				&ix, &iy, &iw, &ih, true );
-	}
 }
 
 ////////////////////////////////////////////////////////////////
@@ -619,6 +643,12 @@ void	handle_map_scroll_changed(
 	GtkAdjustment *hAdj = GTK_ADJUSTMENT( gMapHScrollBarAdjustment );
 	GtkAdjustment *vAdj = GTK_ADJUSTMENT( gMapVScrollBarAdjustment );
 
+	if( chk_scene_group( SCENE_GROUP_N_DEMO ) ){
+		hAdj->value = 0;
+		vAdj->value = 0;
+		return;
+	}
+
 	long x = (long)hAdj->value;
 	long y = (long)vAdj->value;
 	long w = (long)hAdj->page_size;
@@ -658,11 +688,18 @@ gint	handle_map_draw( gpointer p )
 			0, 0,
 			w, h );
 #else
-	if( chk_scene_group( SCENE_GROUP_N_TITLE ) )
+	if( chk_scene_group( SCENE_GROUP_N_TITLE ) ){
 		gPcgDun.drawTitle();
-	if( chk_scene_group( SCENE_GROUP_N_SEL_GRAPH ) )
+	} else if( chk_scene_group( SCENE_GROUP_N_ENDING ) ){
+		gPcgDun.drawEnding();
+	} else if( chk_scene_group( SCENE_GROUP_N_GAME_OVER ) ){
+		gPcgDun.drawGameOver();
+	} else if( chk_scene_group( SCENE_GROUP_N_SEL_GRAPH ) ){
 		if( gSelMbrGraph != NULL )
 			gSelMbrGraph->redraw();
+	} else {
+		return TRUE;
+	}
 
 	GtkWidget *drawingArea = (GtkWidget *)p;
 	GdkRectangle rect;
@@ -770,6 +807,38 @@ void	handle_spell_clicked(
 	gKey.setChar( '-', TRUE );
 }
 
+////////////////////////////////////////////////////////////////
+// ޥåסɥΥܥΥå٥Ƚ
+// GtkWidget *widget : ܥ
+// gpointer data : ϿϤ줿ǡ
+////////////////////////////////////////////////////////////////
+
+void	handle_cancel_clicked(
+	GtkWidget *widget, gpointer *data
+)
+{
+	if( chk_scene_group( SCENE_GROUP_N_SEL_GRAPH ) )
+		gSelMbrGraph->cancel();
+	else
+		gKey.setChar( '0' );
+}
+
+////////////////////////////////////////////////////////////////
+// ޥåסɥΥܥΥå٥Ƚ
+// GtkWidget *widget : ܥ
+// gpointer data : ϿϤ줿ǡ
+////////////////////////////////////////////////////////////////
+
+void	handle_ok_clicked(
+	GtkWidget *widget, gpointer *data
+)
+{
+	if( chk_scene_group( SCENE_GROUP_N_SEL_GRAPH ) )
+		gSelMbrGraph->ok();
+	else
+		gKey.setChar( 'M' - '@' );
+}
+
 ////////////////////////////////////////////////////////////////
 // ޥåסɥΥޥץ쥹٥Ƚ
 // GtkWidget *widget : ޥåפΥɥ󥰡ꥢ
@@ -906,76 +975,3 @@ gint	handle_map_scroll(
 
 	return TRUE;
 }
-
-////////////////////////////////////////////////////////////////
-// ¸ɸ˥ɥɽ
-// GtkWidget *widget : ɥ
-// gint *nPreX : X ɸ¸
-// gint *nPreY : Y ɸ¸
-////////////////////////////////////////////////////////////////
-
-void	showWin(
-	GtkWidget *mMenuWin,
-	gint *nPreX, gint *nPreY,
-	gint *nPreW, gint *nPreH
-)
-{
-	if( mMenuWin == NULL )
-		return;
-
-	if( !GTK_WIDGET_VISIBLE( mMenuWin ) ){
-		if( (nPreX != NULL) && (nPreY != NULL)
-				&& (*nPreX > -1) && (*nPreY > -1) ){
-			gtk_widget_set_uposition(
-					mMenuWin, *nPreX, *nPreY );
-		}
-	}
-
-	if( (nPreW != NULL) && (nPreH != NULL)
-			&& (*nPreW > -1) && (*nPreH > -1) ){
-		mMenuWin->allocation.width = *nPreW;
-		mMenuWin->allocation.height = *nPreH;
-		gtk_widget_set_size_request(
-				mMenuWin, *nPreW, *nPreH );
-	}
-
-	gtk_widget_show( mMenuWin );
-}
-
-////////////////////////////////////////////////////////////////
-// ɥκɸ¸Ĥ
-// GtkWidget *widget : ɥ
-// gint *nPreX : X ɸ¸
-// gint *nPreY : Y ɸ¸
-////////////////////////////////////////////////////////////////
-
-void	wipeWin(
-	GtkWidget *mMenuWin,
-	gint *nPreX, gint *nPreY,
-	gint *nPreW, gint *nPreH
-)
-{
-	if( mMenuWin == NULL )
-		return;
-
-	if( (nPreX != NULL) && (nPreY != NULL) ){
-		gint bgnX, bgnY, endX, endY;
-
-		gdk_window_get_position( mMenuWin->window,
-				nPreX, nPreY );
-		gdk_window_get_root_origin( mMenuWin->window,
-				&bgnX, &bgnY );
-		gdk_window_get_origin( mMenuWin->window,
-				&endX, &endY );
-
-		*nPreX -= endX - bgnX;
-		*nPreY -= endY - bgnY;
-	}
-
-	if( nPreW != NULL )
-		*nPreW = mMenuWin->allocation.width;
-	if( nPreH != NULL )
-		*nPreH = mMenuWin->allocation.height;
-
-	gtk_widget_hide( mMenuWin );
-}
