@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: menu.h,v 1.44 2007/11/28 00:36:26 bowkenken Exp $
+* $Id: menu.h,v 1.47 2008/04/18 23:05:34 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MENU_H
@@ -158,7 +158,7 @@ typedef unsigned long	flg_scroll_t;
 /**** ե󥯥󡦥 ****/
 
 /* ե󥯥󡦥κ */
-#define	FUNC_KEY_MAX	50
+#define	FUNC_KEY_MAX	80
 
 /**** ޥ⡼бե󥯥󡦥 ****/
 
@@ -168,10 +168,25 @@ typedef enum {
 	FUNC_N_CLICK_R,
 	FUNC_N_CLICK_0 = FUNC_N_CLICK_L,
 
-	FUNC_N_PRESS_L_CLICK_R = 31,
+	FUNC_N_DBL_CLICK_L = 31,
+	FUNC_N_DBL_CLICK_M,
+	FUNC_N_DBL_CLICK_R,
+	FUNC_N_DBL_CLICK_0 = FUNC_N_DBL_CLICK_L,
+
+	FUNC_N_PRESS_L_CLICK_R = 41,
 	FUNC_N_PRESS_R_CLICK_L,
 
-	FUNC_N_MOTION_LEFT = 41,
+	FUNC_N_PRESS_L = 51,
+	FUNC_N_PRESS_M,
+	FUNC_N_PRESS_R,
+	FUNC_N_PRESS_0 = FUNC_N_PRESS_L,
+
+	FUNC_N_RELEASE_L = 61,
+	FUNC_N_RELEASE_M,
+	FUNC_N_RELEASE_R,
+	FUNC_N_RELEASE_0 = FUNC_N_RELEASE_L,
+
+	FUNC_N_MOTION_LEFT = 71,
 	FUNC_N_MOTION_RIGHT,
 	FUNC_N_MOTION_UP,
 	FUNC_N_MOTION_DOWN,
