@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: misc.c,v 1.41 2008/01/11 09:12:57 bowkenken Exp $
+* $Id: misc.c,v 1.44 2008/09/18 23:32:56 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -40,6 +40,15 @@
 /* μ */
 
 static long	randm_seed = 1;
+static long	randm_seed_gui = 1;
+
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_misc( void )
+{
+}
 
 /***************************************************************
 * ߤ򥳥ޡեޥåʸѴ
@@ -80,7 +89,7 @@ char	*fmt_num( long n )
 
 		n1 = labs( n ) % 10;
 
-		sprintf( str_tmp, "%1ld", (long)n1 );
+		sn_printf( str_tmp, 4, "%1ld", (long)n1 );
 		head--;
 		*head = str_tmp[0];
 
@@ -139,6 +148,29 @@ long	un_fmt_num( const char *s )
 	return n;
 }
 
+/***************************************************************
+* sprintf Υѥǥ󥰤˻ꤹեĴ
+* const char *s : եޥåȤ˻ꤹ
+* long min_len : Ǿե
+* return : Ĵ줿Ǿե
+***************************************************************/
+
+long	get_pading_len( const char *s, long min_len )
+{
+	long	len;
+
+	if( s == NULL )
+		return 0;
+
+	len = str_len_draw( s );
+	if( len >= min_len )
+		return min_len;
+
+	len = min_len - len;
+	len += str_len_std( s );
+	return len;
+}
+
 /***************************************************************
 * long ͤ +- ֤
 * long n : 
@@ -193,6 +225,7 @@ long	max_l( long n1, long n2 )
 void	srandm( long n )
 {
 	randm_seed = n;
+	randm_seed_gui = n;
 }
 
 /***************************************************************
@@ -268,6 +301,30 @@ bool_t	per_randm( long per )
 	return( randm( per ) == 0 );
 }
 
+/***************************************************************
+* 0 ̤֤ (ץ쥤˱ƶʤ GUI )
+* long n : 
+* return : 
+***************************************************************/
+
+long	gui_randm( long n )
+{
+	long	a;
+
+	randm_seed_gui += 15349;
+	randm_seed_gui *= 3793;
+	randm_seed_gui += 598393;
+	a = (randm_seed_gui & 0xffff0000) >> 16;
+	randm_seed_gui = ((randm_seed_gui & 0x0000ffff) << 16) + a;
+	randm_seed_gui += 379;
+	randm_seed_gui = labs( randm_seed_gui );
+
+	if( n > 0 )
+		return( randm_seed_gui % n );
+	else
+		return 0;
+}
+
 /***************************************************************
 * ͤΨ(%)
 * rate_t rate : Ψ(%)
@@ -418,6 +475,56 @@ void	str_trim_tail( char *str, const char *spc_char )
 	str[idx] = '\0';
 }
 
+/***************************************************************
+* ʸΥեޥå
+* char *s : ʸ
+* long n : ʸĹ
+* const char *fmt : եޥåʸ
+* ... : եޥåȤΰ
+***************************************************************/
+
+void	sn_printf( char *s, long n, const char *fmt, ... )
+{
+	va_list	argptr;
+
+	if( s == NULL )
+		return;
+	if( fmt == NULL )
+		return;
+
+	va_start( argptr, fmt );
+#ifdef	D_GTK
+	g_vsnprintf( s, n, fmt, argptr );
+	s[n] = '\0';
+#else
+	vsprintf( s, fmt, argptr );
+#endif
+	va_end( argptr );
+}
+
+/***************************************************************
+* ʸΥեޥå
+* char *s : ʸ
+* long n : ʸĹ
+* const char *fmt : եޥåʸ
+* va_list argptr : եޥåȤΰ
+***************************************************************/
+
+void	vsn_printf( char *s, long n, const char *fmt, va_list argptr )
+{
+	if( s == NULL )
+		return;
+	if( fmt == NULL )
+		return;
+
+#ifdef	D_GTK
+	g_vsnprintf( s, n, fmt, argptr );
+	s[n] = '\0';
+#else
+	vsprintf( s, fmt, argptr );
+#endif
+}
+
 /***************************************************************
 * ե饰λꤷӥåȤΩäƤ뤫Ĵ٤
 * unsigned long var : ե饰
