@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr-act.c,v 1.14 2007/01/11 17:31:35 bowkenken Exp $
+* $Id: mnstr-act.c,v 1.16 2008/04/16 16:12:34 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -59,6 +59,19 @@
 /* ν̱ɥФΨΣܡ */
 #define	TOWNER_EXIT_DOOR_RATE_NIGHT	((rate_t)1)
 
+/***************************************************************/
+
+static long	static_set_act_mnstr_giant_rat__increase_turn;
+
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_mnstr_act( void )
+{
+	static_set_act_mnstr_giant_rat__increase_turn = -1;
+}
+
 /***************************************************************
 * ƥ󥹥ζ̤Υ
 ***************************************************************/
@@ -584,7 +597,9 @@ void	set_act_mnstr_spore( mnstr_t *p )
 
 void	set_act_mnstr_giant_rat( mnstr_t *p )
 {
-	static long	increase_turn = -1;
+	long	increase_turn = -1;
+
+	increase_turn = static_set_act_mnstr_giant_rat__increase_turn;
 
 	if( p == NULL )
 		return;
