@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.c,v 1.205 2008/04/27 05:07:25 bowkenken Exp $
+* $Id: party.c,v 1.213 2008/09/21 00:58:16 bowkenken Exp $
 ***************************************************************/
 
 #define	PARTY_C
@@ -286,6 +286,7 @@ void	init_party_dflt( void )
 
 	for( i = 0; i < MBR_MAX_N; i++ ){
 		sub_kind.light = LIGHT_KIND_TORCH;
+		sub_kind.wish_level = WISH_LEVEL_NULL;
 		init_mbr_item( ls_mbr[i], ITEM_KIND_LIGHT, &sub_kind,
 				TRUE, FALSE, TRUE );
 	}
@@ -514,6 +515,7 @@ void	init_party_debug( void )
 				TRUE, FALSE, TRUE );
 
 		sub_kind.light = LIGHT_KIND_LANTERN;
+		sub_kind.wish_level = WISH_LEVEL_NULL;
 		init_mbr_item( ls_mbr[i], ITEM_KIND_LIGHT, &sub_kind,
 				TRUE, FALSE, TRUE );
 
@@ -899,6 +901,24 @@ void	init_party_debug( void )
 	init_mbr_item( ls_mbr[i], ITEM_KIND_CHEST, NULL,
 			TRUE, FALSE, FALSE );
 
+	i = 4;
+	sub_kind.light = LIGHT_KIND_LAMP;
+	sub_kind.wish_level = WISH_LEVEL_ARMAGEDDON;
+	init_mbr_item( ls_mbr[i], ITEM_KIND_LIGHT, &sub_kind,
+			FALSE, FALSE, FALSE );
+
+	i = 4;
+	sub_kind.light = LIGHT_KIND_LAMP;
+	sub_kind.wish_level = WISH_LEVEL_DAEMON;
+	init_mbr_item( ls_mbr[i], ITEM_KIND_LIGHT, &sub_kind,
+			FALSE, FALSE, FALSE );
+
+	i = 4;
+	sub_kind.light = LIGHT_KIND_LAMP;
+	sub_kind.wish_level = WISH_LEVEL_DJINNI;
+	init_mbr_item( ls_mbr[i], ITEM_KIND_LIGHT, &sub_kind,
+			FALSE, FALSE, FALSE );
+
 	/**/
 
 #if	0
@@ -1001,7 +1021,8 @@ item_t	*init_mbr_item(
 		break;
 	case ITEM_KIND_LIGHT:
 		tab_n = get_light_tab_n( get_light_tab(
-				sub_kind->light ) );
+				sub_kind->light,
+				sub_kind->wish_level ) );
 		break;
 	case ITEM_KIND_SPIKE:
 		break;
@@ -1290,6 +1311,8 @@ void	new_mbr(
 
 	mbr->fx_data.bless = 0;
 
+	mbr->contribution = 0;
+
 	mbr->mnstr_kind = MNSTR_KIND_NULL;
 	mbr->mnstr_tab = NULL;
 
@@ -1297,12 +1320,18 @@ void	new_mbr(
 	mbr->work.caught = 0;
 	mbr->work.catch_chr = NULL;
 	mbr->work.link_chr = NULL;
+	mbr->work.teleport_n = 0;
+	mbr->work.teleport_party_n = 0;
+	mbr->work.flg_can_wish = TRUE;
 	mbr->work.request = NULL;
 	mbr->work.towner_dx = 0;
 	mbr->work.towner_dy = 0;
 	mbr->work.enter_door = NULL;
 	mbr->work.dismissal_turn = 0;
 	mbr->work.flg_used_energy_drain = FALSE;
+	mbr->work.sync_vfx_num = 0;
+	mbr->work.sync_vfx_x = MAP_DEL_X;
+	mbr->work.sync_vfx_y = MAP_DEL_Y;
 
 	mbr->graph_name[0] = '\0';
 
@@ -1812,15 +1841,8 @@ void	die_mbr( mbr_t *mbr, bool_t flg_chk_game_over )
 
 		break;
 	}
-	if( i >= MBR_MAX_N ){
-		print_msg( FLG_MSG_NO_MORE_PREV, MSG_S, MSG_GAME_OVER );
-		while( 1 ){
-			switch( get_key( g_flg_clr_key_buf ) ){
-			case CASE_EXIT:
-				exit_game( EXIT_SUCCESS );
-			}
-		}
-	}
+	if( i >= MBR_MAX_N )
+		game_over();
 }
 
 /**/
@@ -2802,10 +2824,13 @@ char	*get_race_str( race_t *race )
 	str_nz_cpy( str_main, get_race_str_main( race ), RACE_STR_MAX_LEN );
 	str_nz_cpy( str_sub, get_race_str_sub( race ), RACE_STR_MAX_LEN );
 
-	if( race->sub == SUB_RACE_NULL )
-		sprintf( str_tmp, MSG_RACE_STR_PUREBRED, str_main );
-	else
-		sprintf( str_tmp, MSG_RACE_STR_MIXED, str_main, str_sub );
+	if( race->sub == SUB_RACE_NULL ){
+		sn_printf( str_tmp, RACE_STR_MAX_LEN,
+				MSG_RACE_STR_PUREBRED, str_main );
+	} else {
+		sn_printf( str_tmp, RACE_STR_MAX_LEN,
+				MSG_RACE_STR_MIXED, str_main, str_sub );
+	}
 
 	str_nz_cpy( str_name, str_tmp, RACE_STR_MAX_LEN );
 
@@ -3065,6 +3090,32 @@ bool_t	cmp_class( class_t *org, class_t *dst )
 
 /**/
 
+void	arrange_class_1( long class_n, long d )
+{
+	mbr_t	**ls_mbr = get_ls_mbr();
+	class_t	*p = get_class_tab();
+	class_t	tmp;
+	long	i;
+
+	if( (class_n + d) < 0 )
+		return;
+	if( (class_n + d) >= CLASS_MAX_N )
+		return;
+
+	tmp = p[class_n];
+	p[class_n] = p[class_n + d];
+	p[class_n + d] = tmp;
+
+	for( i = 0; i < LS_MBR_MAX_N; i++ ){
+		if( ls_mbr[i]->class_n == class_n )
+			ls_mbr[i]->class_n = (class_n + d);
+		else if( ls_mbr[i]->class_n == (class_n + d) )
+			ls_mbr[i]->class_n = class_n;
+	}
+}
+
+/**/
+
 void	arrange_class( long class_n, long d )
 {
 	mbr_t	**ls_mbr = get_ls_mbr();
@@ -3148,25 +3199,15 @@ void	set_square_pos( long x, long y )
 
 void	unset_square_pos( void )
 {
-	long	x, y;
-	square_dir_t	dir;
-
 	if( !clip_pos( party.square.pre_x, party.square.pre_y ) )
 		return;
 
-	x = party.square.x;
-	y = party.square.y;
-	dir = party.square.dir;
-
 	party.square.x = party.square.pre_x;
 	party.square.y = party.square.pre_y;
 	party.square.dir = party.square.pre_dir;
 
-	party.square.pre_x = x;
-	party.square.pre_y = y;
-	party.square.pre_dir = dir;
-
 	set_mbr_dir();
 }
 
 /**/
+
