@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: replay.c,v 1.14 2008/01/11 09:12:57 bowkenken Exp $
+* $Id: replay.c,v 1.18 2008/09/01 09:41:46 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -79,6 +79,14 @@ void	init_replay( void )
 	g_play_replay_idx_draw = 0;
 }
 
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_replay( void )
+{
+}
+
 /***************************************************************
 * ץ쥤ꥻå
 * long n : ǡåֹ
@@ -428,6 +436,39 @@ bool_t	get_draw_replay( char *buf, long *idx, long *len )
 	return flg_redraw;
 }
 
+/***************************************************************
+* ץ쥤ѥǡ֤ (GUI )
+* char *buf : ꥹȤ֤
+* long len : Ĺ
+***************************************************************/
+
+void	get_draw_replay_gui( char *buf, long len )
+{
+	replay_t	*p;
+	long	idx;
+	long	i;
+
+	if( buf == NULL )
+		return;
+
+	buf[0] = '\0';
+	p = g_replay_cur[REPLAY_SLOT_PLAY];
+	if( p == NULL )
+		return;
+	idx = g_play_replay_idx;
+
+	for( i = 0; i < len; i++ ){
+		char	tmp[1 + 1];
+
+		tmp[0] = get_replay_next_key( &p, &idx );
+		tmp[1] = '\0';
+		if( tmp[0] == '\0' )
+			break;
+
+		str_max_n_cat( buf, cv_esc_ctrl_str( tmp ), len );
+	}
+}
+
 /***************************************************************
 * ץ쥤Υå
 * g_play_replay_turn, g_play_replay_count, g_play_replay_char
@@ -455,12 +496,12 @@ void	chk_replay_key( long c )
 		g_play_replay_count = 10;
 		break;
 	case '\0':
-	case '|':
-		g_play_replay_char = '|';
+	case CMD_KEY_IDLE:
+		g_play_replay_char = CMD_KEY_IDLE;
 		break;
-	case ',':
-		set_continue_exec_mode();
-		g_play_replay_char = '|';
+	case CMD_KEY_CONT_EXEC:
+		toggle_continue_exec_mode();
+		g_play_replay_char = CMD_KEY_IDLE;
 		break;
 	case CASE_CANCEL:
 	case CASE_EXIT:
@@ -510,6 +551,8 @@ long	get_replay_key( void )
 
 /***************************************************************
 * Υץ쥤֤
+* replay_t **pp : 
+* long *idx : ߤΥΰ֤֤
 * return : ץ쥤
 ***************************************************************/
 
@@ -569,9 +612,17 @@ void	set_flg_play_replay( bool_t flg )
 
 		g_play_replay_idx = 0;
 		g_play_replay_idx_draw = 0;
+
+		if( g_flg_gui )
+			call_gui_replay_bgn();
 	} else {
 		g_play_replay_turn = -1;
 		g_play_replay_count = 0;
+
+		redraw_all();
+
+		if( g_flg_gui )
+			call_gui_replay_end();
 	}
 }
 
