@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: scene.h,v 1.2 2008/01/11 09:12:57 bowkenken Exp $
+* $Id: scene.h,v 1.8 2008/09/18 23:51:33 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	SCENE_H
@@ -49,10 +49,18 @@ typedef enum {
 
 	SCENE_N_DUN,
 	SCENE_N_BATTLE,
+	SCENE_N_BATTLE_BOSS,
+
+	SCENE_N_GAME_OVER,
+	SCENE_N_GAME_OVER_WAIT,
+	SCENE_N_GAME_OVER_END,
 
 	SCENE_N_ENDING,
+	SCENE_N_ENDING_EPILOGUE,
+	SCENE_N_ENDING_SPACE,
 	SCENE_N_ENDING_END,
-	SCENE_N_GAME_OVER,
+
+	SCENE_N_SEL_MBR_GRAPH,
 
 	SCENE_N_MAX_N,
 } scene_n_t;
@@ -62,9 +70,18 @@ typedef enum {
 
 	SCENE_GROUP_N_INIT,
 	SCENE_GROUP_N_TITLE,
+
 	SCENE_GROUP_N_PLAYING,
+	SCENE_GROUP_N_BATTLE,
+
+	SCENE_GROUP_N_GAME_OVER,
+	SCENE_GROUP_N_ENDING,
 	SCENE_GROUP_N_GAME_END,
 
+	SCENE_GROUP_N_SEL_GRAPH,
+
+	SCENE_GROUP_N_DEMO,
+
 	SCENE_GROUP_N_CAN_SKIP,
 	SCENE_GROUP_N_CAN_NOT_SKIP,
 
