@@ -25,17 +25,23 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: town.c,v 1.133 2008/04/16 16:12:34 bowkenken Exp $
+* $Id: town.c,v 1.139 2008/09/23 00:27:39 bowkenken Exp $
 ***************************************************************/
 
 #define	TOWN_C
 #include	"inc.h"
 
-/**/
+/***************************************************************
+* 
+***************************************************************/
 
 #define	TOWNER_AVE_N	64
 
-/**/
+#define	FLOOR_IS_FIND_NIGHT	1
+
+/***************************************************************
+* ŹαĶȻ
+***************************************************************/
 
 #define	OPEN_TURN_BAR	( 0 * TURN_PER_HOUR)
 #define	CLOSE_TURN_BAR	(24 * TURN_PER_HOUR)
@@ -64,7 +70,9 @@
 #define	OPEN_TURN_PET_SHOP	( 7 * TURN_PER_HOUR)
 #define	CLOSE_TURN_PET_SHOP	(19 * TURN_PER_HOUR)
 
-/**/
+/***************************************************************
+* ʪΥƥζµܤγؤ˴
+***************************************************************/
 
 #define	ART_LEVEL_WPN	-20
 #define	ART_LEVEL_ARMOR	-10
@@ -82,13 +90,17 @@
 #define	ART_LEVEL_DISPOSAL	-10
 #define	ART_LEVEL_SPIKE	-10
 
-/**/
+/***************************************************************
+* ʪ
+***************************************************************/
 
 #define	PRICE_NOT_IDENTIFIED_RATE	((rate_t)80)
 
 #define	CHARGE_STAY_INN_STAY	((gold_t)50)
 #define	CHARGE_STAY_INN_SHORT_STAY	((gold_t)50)
 
+/*  */
+
 #define	PRICE_WPN_MIN	50
 #define	PRICE_WPN_RATE	((rate_t)10)
 #define	PRICE_WPN_BASE	-3000
@@ -118,7 +130,7 @@
 #define	PRICE_ARW_DIV	500
 #define	PRICE_WPN_NOT_SPEND	500
 
-/**/
+/*  */
 
 #define	PRICE_ARW_ADD_HIT_MUL	1
 #define	PRICE_ARW_ADD_CRTCL_MUL	1
@@ -128,7 +140,7 @@
 
 #define	PRICE_ARW_SLAYER	10
 
-/**/
+/* ɶ */
 
 #define	PRICE_ARMOR_RATE	((rate_t)4)
 #define	PRICE_ARMOR_BASE	0
@@ -149,20 +161,20 @@
 #define	PRICE_ARMOR_ADD_CRTCL_BASE	0
 #define	PRICE_ARMOR_ADD_AC_BASE	0
 
-/**/
+/* ڴ */
 
 #define	PRICE_INST_BASE	1000
 #define	PRICE_INST_LIMIT	3000
 #define	PRICE_INST_SPELL	5000
 
-/**/
+/* ¾ */
 
 #define	PRICE_ANTHOLOGY	2000
 #define	PRICE_SPIKE	10
 #define	PRICE_CHEST	500
 #define	PRICE_DISPOSAL	10
 
-/**/
+/*  */
 
 #define	PRICE_TEMPLE_REMOVE_CURSE	50
 #define	PRICE_TEMPLE_CURE_STATUS_MUL	10
@@ -186,7 +198,9 @@
 
 discount_queue_t	g_discount_queue;
 
-/**/
+/***************************************************************
+* ¾
+***************************************************************/
 
 /* ϤΤΨ */
 #define	MBR_IS_MOLESTED_RATE	((rate_t)10)
@@ -194,24 +208,29 @@ discount_queue_t	g_discount_queue;
 /* µܤؤγʤȾ */
 #define	TOWN_STAIRS_R	1
 
-/**/
-
+/* XPM βƩ */
 #define	STR_XPM_COL_NONE	"None"
 
-/***************************************************************/
+/***************************************************************
+* ƥǡơ֥
+***************************************************************/
 
 #include	"town-ptn.xpm"
 #include	"town-tab.h"
 #include	"rumor-tab.h"
 
-/***************************************************************/
+/***************************************************************
+* Хѿ
+***************************************************************/
 
 static town_ptn_t	town_ptn, town_ptn_trans;
 
 static long	g_morning_glow_n, g_evening_glow_n;
 static bool_t	g_flg_night;
 
-/**/
+/***************************************************************
+* 
+***************************************************************/
 
 void	init_town( void )
 {
@@ -226,8 +245,6 @@ void	init_town( void )
 	clr_discount();
 }
 
-/**/
-
 /***************************************************************
 * ƥåѿꥻå
 ***************************************************************/
@@ -236,7 +253,9 @@ void	reset_static_town( void )
 {
 }
 
-/**/
+/***************************************************************
+* īƤͼƤꥻå
+***************************************************************/
 
 void	reset_glow( void )
 {
@@ -248,7 +267,9 @@ void	reset_glow( void )
 	chk_evening_glow( get_turn() );
 }
 
-/**/
+/***************************************************************
+* ѥοơ֥
+***************************************************************/
 
 void	init_town_ptn_col_tab( void )
 {
@@ -269,7 +290,11 @@ void	init_town_ptn_col_tab( void )
 		town_ptn_col_tab_max_n = 0;
 }
 
-/**/
+/***************************************************************
+* ѥǥեȤǾ
+* town_ptn_t *ptn : ѥ
+* return : 顼̵ä
+***************************************************************/
 
 bool_t	set_town_ptn_dflt( town_ptn_t *ptn )
 {
@@ -306,7 +331,11 @@ bool_t	set_town_ptn_dflt( town_ptn_t *ptn )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ѥ
+* town_ptn_t *ptn : ѥ
+* return : 顼̵ä
+***************************************************************/
 
 bool_t	set_town_ptn_init( town_ptn_t *ptn )
 {
@@ -323,7 +352,12 @@ bool_t	set_town_ptn_init( town_ptn_t *ptn )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ѥΥإåɤ߹
+* town_ptn_t *ptn : ѥ
+* char *s : إåʸ
+* return : 顼̵ä
+***************************************************************/
 
 bool_t	set_town_ptn_head( town_ptn_t *ptn, char *s )
 {
@@ -356,7 +390,12 @@ bool_t	set_town_ptn_head( town_ptn_t *ptn, char *s )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ѥοơ֥ɤ߹
+* town_ptn_t *ptn : ѥ
+* char *s : ơ֥ʸ (1 ʬ)
+* return : 顼̵ä
+***************************************************************/
 
 bool_t	set_town_ptn_col( town_ptn_t *ptn, char *s )
 {
@@ -402,7 +441,11 @@ bool_t	set_town_ptn_col( town_ptn_t *ptn, char *s )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ѥο
+* town_ptn_t *ptn : ѥ
+* return : 顼̵ä
+***************************************************************/
 
 bool_t	set_town_ptn_col_count( town_ptn_t *ptn )
 {
@@ -427,7 +470,13 @@ bool_t	set_town_ptn_col_count( town_ptn_t *ptn )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ѥΥޥåסǡɤ߹
+* town_ptn_t *ptn : ѥ
+* char *s : ޥåסǡʸ (1 ʬ)
+* long y : ޥåפ Y ɸ (Կ)
+* return : 顼̵ä
+***************************************************************/
 
 bool_t	set_town_ptn_map( town_ptn_t *ptn, char *s, long y )
 {
@@ -454,7 +503,13 @@ bool_t	set_town_ptn_map( town_ptn_t *ptn, char *s, long y )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ѥΥޥåסǡ 1 饯ʸ
+* 1 ʸ 2 ʸѴ
+* town_ptn_t *dst : ѴΥѥ
+* town_ptn_t *src : ѴΥѥ
+* return : 顼̵ä
+***************************************************************/
 
 bool_t	trans_town_ptn( town_ptn_t *dst, town_ptn_t *src )
 {
@@ -675,7 +730,11 @@ void	make_field_town( town_ptn_t *ptn, long x, long y )
 		break;
 	case FACE_MJR_FLOOR:
 		if( chk_night() ){
+#if	FLOOR_IS_FIND_NIGHT
+			flg |= FLG_MAP_OBJ_FIND;
+#else
 			flg &= ~(FLG_MAP_OBJ_FIND);
+#endif
 			flg_light = FALSE;
 		}
 		flg |= FLG_MAP_OBJ_PASS;
@@ -1013,7 +1072,8 @@ bool_t	make_art_town( shop_n_t shop_n, void *art_ls )
 			return FALSE;
 		break;
 	case ITEM_KIND_LIGHT:
-		tab_n = get_light_tab_n( get_light_tab( light_kind ) );
+		tab_n = get_light_tab_n( get_light_tab(
+				light_kind, WISH_LEVEL_NULL ) );
 		if( tab_n <= -1 )
 			return TRUE;
 		item = make_item_light( ART_LEVEL_LIGHT, tab_n );
@@ -1370,6 +1430,9 @@ bool_t	enter_shop( void )
 	clr_map_all_mbr();
 	clr_map_all_pet();
 
+	set_cur_shop_n( shop_n );
+	change_scene( SCENE_N_SHOP );
+
 	say_welcome_shop_msg( shop_n );
 
 	while( 1 ){
@@ -1494,6 +1557,8 @@ void	party_exit_shop( long dr_n )
 		appear_all_pet();
 	}
 
+	next_pos_square( 0 );
+	scroll_center_appear_party();
 	set_flg_find_all_mnstr();
 	wipe_menu();
 
@@ -1501,6 +1566,8 @@ void	party_exit_shop( long dr_n )
 
 	if( dun->door[dr_n].mnr != FACE_MNR_SHOP_BAR )
 		add_turn( SHOP_ADD_TURN_N );
+
+	change_scene( SCENE_N_TOWN );
 }
 
 /**/
@@ -2097,7 +2164,8 @@ bool_t	set_art_name_equip( mbr_t *mbr, item_t *art, equip_kind_t eq )
 		break;
 	}
 	if( eq_name != NULL ){
-		sprintf( art->art_name, MSG_FMT_ART_NAME_EQUIP,
+		sn_printf( art->art_name, ITEM_ART_NAME_MAX_LEN,
+				MSG_FMT_ART_NAME_EQUIP,
 				get_equip_ttl_max_len(), eq_name,
 				art->name );
 	} else {
