@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: ver.h,v 1.55 2008/04/25 04:10:04 bowkenken Exp $
+* $Id: ver.h,v 1.57 2008/09/15 07:15:52 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	VER_H
@@ -52,10 +52,17 @@
 #define	STR_TITLE_3	" "
 #define	STR_HANDLE_3	"kokusi(yujyu), hiyo and URARA"
 
+#define	STR_TITLE_4	"Photograph"
+#define	STR_HANDLE_4	"Yoshinori Kamimura"
+
+#define	STR_TITLE_5	"Music Production"
+#define	STR_HANDLE_5	"Presence of Music"
+
 #define	STR_TITLE_THANKS	"Special Thanks"
 #define	STR_HANDLE_THANKS	"t-oikawa, TeaMiKL, nnn and you"
 
 #define	STR_FMT_COPYRIGHT	\
+		"\n" \
 		"--------------------------------" \
 		"--------------------------------\n" \
 		"%s : version %s  \n" \
@@ -70,6 +77,8 @@
 		"%20s  %-42s\n" \
 		"%20s  %-42s\n" \
 		"%20s  %-42s\n" \
+		"%20s  %-42s\n" \
+		"%20s  %-42s\n" \
 		"--------------------------------" \
 		"--------------------------------\n" \
 		""
@@ -82,6 +91,8 @@
 		STR_TITLE_1, STR_HANDLE_1, \
 		STR_TITLE_2, STR_HANDLE_2, \
 		STR_TITLE_3, STR_HANDLE_3, \
+		STR_TITLE_4, STR_HANDLE_4, \
+		STR_TITLE_5, STR_HANDLE_5, \
 		STR_TITLE_THANKS, STR_HANDLE_THANKS
 
 #endif	/* VER_H */
